Class: OursprivacyIngest::Models::BatchCreateParams::Event

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/oursprivacy_ingest/models/batch_create_params.rb

Defined Under Namespace

Classes: DefaultProperties, IdentityContext, UserProperties

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ip:, user_agent:) ⇒ Object

End-user network context for server-side calls. Required for probabilistic identity resolution when the caller is a backend server rather than an end-user browser.

Parameters:

  • ip (String)

    The end-user IP address (not the server IP).

  • user_agent (String)

    The end-user User-Agent string (not the server UA).



30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 30

class Event < OursprivacyIngest::Internal::Type::BaseModel
  # @!attribute event
  #   The name of the event you're tracking. This must be whitelisted in the Ours
  #   dashboard.
  #
  #   @return [String]
  required :event, String

  # @!attribute token
  #   The token for your Source. You can find this in the dashboard.
  #
  #   @return [String, nil]
  optional :token, String

  # @!attribute default_properties
  #   These properties are used throughout the Ours app to pass known values onto
  #   destinations
  #
  #   @return [OursprivacyIngest::Models::BatchCreateParams::Event::DefaultProperties, nil]
  optional :default_properties,
           -> { OursprivacyIngest::BatchCreateParams::Event::DefaultProperties },
           api_name: :defaultProperties,
           nil?: true

  # @!attribute distinct_id
  #   A unique identifier for the event. This helps prevent duplicate events.
  #
  #   @return [String, nil]
  optional :distinct_id, String, api_name: :distinctId, nil?: true

  # @!attribute email
  #   The email address of a user. We will associate this event with the user or
  #   create a user. Used for lookup if externalId and userId are not included in the
  #   request.
  #
  #   @return [String, nil]
  optional :email, String, nil?: true

  # @!attribute event_properties
  #   Any additional event properties you want to pass along.
  #
  #   @return [Hash{Symbol=>String, nil}, nil]
  optional :event_properties,
           OursprivacyIngest::Internal::Type::HashOf[String, nil?: true],
           api_name: :eventProperties,
           nil?: true

  # @!attribute external_id
  #   The externalId (the ID in your system) of a user. We will associate this event
  #   with the user or create a user. If included in the request, email lookup is
  #   ignored.
  #
  #   @return [String, nil]
  optional :external_id, String, api_name: :externalId, nil?: true

  # @!attribute identity_context
  #   End-user network context for server-side calls. Required for probabilistic
  #   identity resolution when the caller is a backend server rather than an end-user
  #   browser.
  #
  #   @return [OursprivacyIngest::Models::BatchCreateParams::Event::IdentityContext, nil]
  optional :identity_context,
           -> { OursprivacyIngest::BatchCreateParams::Event::IdentityContext },
           api_name: :identityContext,
           nil?: true

  # @!attribute time
  #   The time at which the event occurred in milliseconds since UTC epoch. The time
  #   must be in the past and within the last 7 days.
  #
  #   @return [Float, nil]
  optional :time, Float, nil?: true

  # @!attribute user_id
  #   The Ours user id stored in local storage and cookies on your web properties. If
  #   userId is included in the request, we do not lookup the user by email or
  #   externalId.
  #
  #   @return [String, nil]
  optional :user_id, String, api_name: :userId, nil?: true

  # @!attribute user_properties
  #   Properties to set on the visitor. (optional) You can also update these
  #   properties via the identify endpoint.
  #
  #   @return [OursprivacyIngest::Models::BatchCreateParams::Event::UserProperties, nil]
  optional :user_properties,
           -> { OursprivacyIngest::BatchCreateParams::Event::UserProperties },
           api_name: :userProperties,
           nil?: true

  # @!method initialize(event:, token: nil, default_properties: nil, distinct_id: nil, email: nil, event_properties: nil, external_id: nil, identity_context: nil, time: nil, user_id: nil, user_properties: nil)
  #   Some parameter documentations has been truncated, see
  #   {OursprivacyIngest::Models::BatchCreateParams::Event} for more details.
  #
  #   @param event [String] The name of the event you're tracking. This must be whitelisted in the Ours dash
  #
  #   @param token [String] The token for your Source. You can find this in the dashboard.
  #
  #   @param default_properties [OursprivacyIngest::Models::BatchCreateParams::Event::DefaultProperties, nil] These properties are used throughout the Ours app to pass known values onto dest
  #
  #   @param distinct_id [String, nil] A unique identifier for the event. This helps prevent duplicate events.
  #
  #   @param email [String, nil] The email address of a user. We will associate this event with the user or creat
  #
  #   @param event_properties [Hash{Symbol=>String, nil}, nil] Any additional event properties you want to pass along.
  #
  #   @param external_id [String, nil] The externalId (the ID in your system) of a user. We will associate this event w
  #
  #   @param identity_context [OursprivacyIngest::Models::BatchCreateParams::Event::IdentityContext, nil] End-user network context for server-side calls. Required for probabilistic ident
  #
  #   @param time [Float, nil] The time at which the event occurred in milliseconds since UTC epoch. The time m
  #
  #   @param user_id [String, nil] The Ours user id stored in local storage and cookies on your web properties. If
  #
  #   @param user_properties [OursprivacyIngest::Models::BatchCreateParams::Event::UserProperties, nil] Properties to set on the visitor. (optional) You can also update these propertie

  # @see OursprivacyIngest::Models::BatchCreateParams::Event#default_properties
  class DefaultProperties < OursprivacyIngest::Internal::Type::BaseModel
    # @!attribute active_duration
    #   The active time in milliseconds that the user had this tab active
    #
    #   @return [Float, nil]
    optional :active_duration, Float, api_name: :activeDuration, nil?: true

    # @!attribute ad_id
    #   The ad id for detected in the session. This is set by the web sdk automatically.
    #
    #   @return [String, nil]
    optional :ad_id, String, nil?: true

    # @!attribute admitad_uid
    #   The Admitad (Mitgo) affiliate Click ID. Ex: admitad_uid_abc123
    #
    #   @return [String, nil]
    optional :admitad_uid, String, nil?: true

    # @!attribute adset_id
    #   The adset id for detected in the session. This is set by the web sdk
    #   automatically.
    #
    #   @return [String, nil]
    optional :adset_id, String, nil?: true

    # @!attribute alart
    #   The AppLovin alart query parameter. Ex: alart123
    #
    #   @return [String, nil]
    optional :alart, String, nil?: true

    # @!attribute aleid
    #   The AppLovin aleid query parameter. Ex: aleid123
    #
    #   @return [String, nil]
    optional :aleid, String, nil?: true

    # @!attribute axwrt
    #   The AppLovin Axon pixel cookie value (\_axwrt). Web-only.
    #
    #   @return [String, nil]
    optional :axwrt, String, nil?: true

    # @!attribute basis_cid
    #   The Basis DSP Click ID. Ex: basis_cid123
    #
    #   @return [String, nil]
    optional :basis_cid, String, nil?: true

    # @!attribute browser_language
    #   The language of the browser. Ex: en-US
    #
    #   @return [String, nil]
    optional :browser_language, String, nil?: true

    # @!attribute browser_name
    #   The name of the browser. Ex: Chrome
    #
    #   @return [String, nil]
    optional :browser_name, String, nil?: true

    # @!attribute browser_version
    #   The version of the browser. Ex: 114.0
    #
    #   @return [String, nil]
    optional :browser_version, String, nil?: true

    # @!attribute campaign_id
    #   The campaign id for detected in the session. This is set by the web sdk
    #   automatically.
    #
    #   @return [String, nil]
    optional :campaign_id, String, nil?: true

    # @!attribute clickid
    #   The Click ID. Ex: clickid123
    #
    #   @return [String, nil]
    optional :clickid, String, nil?: true

    # @!attribute clid
    #   The Generic Click ID. Ex: clid123
    #
    #   @return [String, nil]
    optional :clid, String, nil?: true

    # @!attribute cpu_architecture
    #   The architecture of the CPU. Ex: x64
    #
    #   @return [String, nil]
    optional :cpu_architecture, String, nil?: true

    # @!attribute current_url
    #   The full url (including query params) of the current page
    #
    #   @return [String, nil]
    optional :current_url, String, nil?: true

    # @!attribute dclid
    #   The DoubleClick Click ID. Ex: dclid123
    #
    #   @return [String, nil]
    optional :dclid, String, nil?: true

    # @!attribute device_model
    #   The model of the device. Ex: iPhone 13
    #
    #   @return [String, nil]
    optional :device_model, String, nil?: true

    # @!attribute device_type
    #   The type of device the user is using. Ex: mobile
    #
    #   @return [String, nil]
    optional :device_type, String, nil?: true

    # @!attribute device_vendor
    #   The vendor of the device. Ex: Apple
    #
    #   @return [String, nil]
    optional :device_vendor, String, nil?: true

    # @!attribute duration
    #   The time in milliseconds since the page was loaded // script was loaded
    #
    #   @return [Float, nil]
    optional :duration, Float, nil?: true

    # @!attribute encoding
    #   The browsers encoding. Ex: UTF-8
    #
    #   @return [String, nil]
    optional :encoding, String, nil?: true

    # @!attribute engine_name
    #   The name of the browser engine. Ex: Blink
    #
    #   @return [String, nil]
    optional :engine_name, String, nil?: true

    # @!attribute engine_version
    #   The version of the browser engine. Ex: 114.0
    #
    #   @return [String, nil]
    optional :engine_version, String, nil?: true

    # @!attribute epik
    #   The Pinterest Click ID. Ex: epik456
    #
    #   @return [String, nil]
    optional :epik, String, nil?: true

    # @!attribute fbc
    #   Facebook Click ID with prefix format for Conversions API tracking. Ex:
    #   fb.1.1554763741205.AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
    #
    #   @return [String, nil]
    optional :fbc, String, nil?: true

    # @!attribute fbclid
    #   Raw Facebook Click ID query parameter without prefix from ad clicks. Ex:
    #   AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
    #
    #   @return [String, nil]
    optional :fbclid, String, nil?: true

    # @!attribute fbp
    #   Facebook Browser ID parameter for identifying browsers and attributing events.
    #   Ex: fb.1.1554763741205.1098115397
    #
    #   @return [String, nil]
    optional :fbp, String, nil?: true

    # @!attribute fv
    #   Deprecated
    #
    #   @return [Boolean, nil]
    optional :fv, OursprivacyIngest::Internal::Type::Boolean, nil?: true

    # @!attribute gad_source
    #   The Google Ad Source. Ex: google
    #
    #   @return [String, nil]
    optional :gad_source, String, nil?: true

    # @!attribute gbraid
    #   The Google Braid ID. Ex: gbraid123
    #
    #   @return [String, nil]
    optional :gbraid, String, nil?: true

    # @!attribute gclid
    #   The Google Click ID. Ex: gclid123
    #
    #   @return [String, nil]
    optional :gclid, String, nil?: true

    # @!attribute host
    #   The host of the current page. Ex: example.com
    #
    #   @return [String, nil]
    optional :host, String, nil?: true

    # @!attribute iframe
    #   Whether the user is in an iframe. Ex: true
    #
    #   @return [Boolean, nil]
    optional :iframe, OursprivacyIngest::Internal::Type::Boolean, nil?: true

    # @!attribute im_ref
    #   The Impact Click ID reference. Ex: im_ref123
    #
    #   @return [String, nil]
    optional :im_ref, String, nil?: true

    # @!attribute ip
    #   The IP address of the user. Ex: 127.0.0.1
    #
    #   @return [String, nil]
    optional :ip, String, nil?: true

    # @!attribute irclickid
    #   The Impact Click ID. Ex: irclickid123
    #
    #   @return [String, nil]
    optional :irclickid, String, nil?: true

    # @!attribute is_bot
    #   Whether we have detected that the user is a bot. This is set automatically by
    #   the Ours server primarily for events tracked through the web SDK.
    #
    #   @return [String, nil]
    optional :is_bot, String, nil?: true

    # @!attribute li_fat_id
    #   The LinkedIn Click ID. Ex: li_fat_id123
    #
    #   @return [String, nil]
    optional :li_fat_id, String, nil?: true

    # @!attribute msclkid
    #   The Microsoft Click ID. Ex: msclkid123
    #
    #   @return [String, nil]
    optional :msclkid, String, nil?: true

    # @!attribute ndclid
    #   The NextDoor Click ID. Ex: ndclid123
    #
    #   @return [String, nil]
    optional :ndclid, String, nil?: true

    # @!attribute new_s
    #   Deprecated
    #
    #   @return [Boolean, nil]
    optional :new_s, OursprivacyIngest::Internal::Type::Boolean, nil?: true

    # @!attribute os_name
    #   The name of the operating system. Ex: Windows
    #
    #   @return [String, nil]
    optional :os_name, String, nil?: true

    # @!attribute os_version
    #   The version of the operating system. Ex: 10.0
    #
    #   @return [String, nil]
    optional :os_version, String, nil?: true

    # @!attribute page_hash
    #   A random set of numbers for the page load
    #
    #   @return [Float, nil]
    optional :page_hash, Float, nil?: true

    # @!attribute pathname
    #   The pathname of the current page. Ex: /home
    #
    #   @return [String, nil]
    optional :pathname, String, nil?: true

    # @!attribute qclid
    #   The Quora Click ID. Ex: qclid123
    #
    #   @return [String, nil]
    optional :qclid, String, nil?: true

    # @!attribute rdt_cid
    #   The Reddit Click ID. Ex: rdt_cid123
    #
    #   @return [String, nil]
    optional :rdt_cid, String, nil?: true

    # @!attribute received_at
    #   The time the event was received by an Ours server in ISO format
    #
    #   @return [String, nil]
    optional :received_at, String, nil?: true

    # @!attribute referrer
    #   The referrer URL of the current page
    #
    #   @return [String, nil]
    optional :referrer, String, nil?: true

    # @!attribute referring_domain
    #   The referring domain of the current page
    #
    #   @return [String, nil]
    optional :referring_domain, String, nil?: true

    # @!attribute sacid
    #   The StackAdapt Tracking ID. Ex: sacid123
    #
    #   @return [String, nil]
    optional :sacid, String, nil?: true

    # @!attribute sccid
    #   The SnapChat Click ID. Ex: sccid123
    #
    #   @return [String, nil]
    optional :sccid, String, nil?: true

    # @!attribute screen_height
    #   The height of the screen. Ex: 1080
    #
    #   @return [Float, nil]
    optional :screen_height, Float, nil?: true

    # @!attribute screen_width
    #   The width of the screen. Ex: 1920
    #
    #   @return [Float, nil]
    optional :screen_width, Float, nil?: true

    # @!attribute session_count
    #   The number of sessions the user has had. Ex: 3
    #
    #   @return [Float, nil]
    optional :session_count, Float, api_name: :sessionCount, nil?: true

    # @!attribute sid
    #   The session ID as assigned automatically by the web SDK. This is required for
    #   session replay
    #
    #   @return [String, nil]
    optional :sid, String, nil?: true

    # @!attribute sr
    #
    #   @return [String, nil]
    optional :sr, String, nil?: true

    # @!attribute title
    #   The title of the current page
    #
    #   @return [String, nil]
    optional :title, String, nil?: true

    # @!attribute ttclid
    #   The TikTok Click ID. Ex: ttclid123
    #
    #   @return [String, nil]
    optional :ttclid, String, nil?: true

    # @!attribute twclid
    #   The Twitter Click ID. Ex: twclid123
    #
    #   @return [String, nil]
    optional :twclid, String, nil?: true

    # @!attribute uafvl
    #   User agent as a full list of strings.
    #
    #   @return [String, nil]
    optional :uafvl, String, nil?: true

    # @!attribute user_agent
    #   The user agent of the browser
    #
    #   @return [String, nil]
    optional :user_agent, String, nil?: true

    # @!attribute utm_campaign
    #   The UTM Campaign. The web SDK automatically captures this from the query params.
    #
    #   @return [String, nil]
    optional :utm_campaign, String, nil?: true

    # @!attribute utm_content
    #   The UTM Content. The web SDK automatically captures this from the query params.
    #
    #   @return [String, nil]
    optional :utm_content, String, nil?: true

    # @!attribute utm_medium
    #   The UTM Medium. The web SDK automatically captures this from the query params.
    #
    #   @return [String, nil]
    optional :utm_medium, String, nil?: true

    # @!attribute utm_name
    #   The UTM Name. The web SDK automatically captures this from the query params.
    #
    #   @return [String, nil]
    optional :utm_name, String, nil?: true

    # @!attribute utm_source
    #   The UTM Source. The web SDK automatically captures this from the query params.
    #
    #   @return [String, nil]
    optional :utm_source, String, nil?: true

    # @!attribute utm_term
    #   The UTM Term. The web SDK automatically captures this from the query params.
    #
    #   @return [String, nil]
    optional :utm_term, String, nil?: true

    # @!attribute version
    #   The version of the web SDK
    #
    #   @return [String, nil]
    optional :version, String, nil?: true

    # @!attribute wbraid
    #   The WBRAID Identifier. The web SDK automatically captures this from the query
    #   params.
    #
    #   @return [String, nil]
    optional :wbraid, String, nil?: true

    # @!attribute webview
    #   Whether the user is in a webview. Ex: true
    #
    #   @return [Boolean, nil]
    optional :webview, OursprivacyIngest::Internal::Type::Boolean, nil?: true

    # @!method initialize(active_duration: nil, ad_id: nil, admitad_uid: nil, adset_id: nil, alart: nil, aleid: nil, axwrt: nil, basis_cid: nil, browser_language: nil, browser_name: nil, browser_version: nil, campaign_id: nil, clickid: nil, clid: nil, cpu_architecture: nil, current_url: nil, dclid: nil, device_model: nil, device_type: nil, device_vendor: nil, duration: nil, encoding: nil, engine_name: nil, engine_version: nil, epik: nil, fbc: nil, fbclid: nil, fbp: nil, fv: nil, gad_source: nil, gbraid: nil, gclid: nil, host: nil, iframe: nil, im_ref: nil, ip: nil, irclickid: nil, is_bot: nil, li_fat_id: nil, msclkid: nil, ndclid: nil, new_s: nil, os_name: nil, os_version: nil, page_hash: nil, pathname: nil, qclid: nil, rdt_cid: nil, received_at: nil, referrer: nil, referring_domain: nil, sacid: nil, sccid: nil, screen_height: nil, screen_width: nil, session_count: nil, sid: nil, sr: nil, title: nil, ttclid: nil, twclid: nil, uafvl: nil, user_agent: nil, utm_campaign: nil, utm_content: nil, utm_medium: nil, utm_name: nil, utm_source: nil, utm_term: nil, version: nil, wbraid: nil, webview: nil)
    #   Some parameter documentations has been truncated, see
    #   {OursprivacyIngest::Models::BatchCreateParams::Event::DefaultProperties} for
    #   more details.
    #
    #   These properties are used throughout the Ours app to pass known values onto
    #   destinations
    #
    #   @param active_duration [Float, nil] The active time in milliseconds that the user had this tab active
    #
    #   @param ad_id [String, nil] The ad id for detected in the session. This is set by the web sdk automatically.
    #
    #   @param admitad_uid [String, nil] The Admitad (Mitgo) affiliate Click ID. Ex: admitad_uid_abc123
    #
    #   @param adset_id [String, nil] The adset id for detected in the session. This is set by the web sdk automatical
    #
    #   @param alart [String, nil] The AppLovin alart query parameter. Ex: alart123
    #
    #   @param aleid [String, nil] The AppLovin aleid query parameter. Ex: aleid123
    #
    #   @param axwrt [String, nil] The AppLovin Axon pixel cookie value (\_axwrt). Web-only.
    #
    #   @param basis_cid [String, nil] The Basis DSP Click ID. Ex: basis_cid123
    #
    #   @param browser_language [String, nil] The language of the browser. Ex: en-US
    #
    #   @param browser_name [String, nil] The name of the browser. Ex: Chrome
    #
    #   @param browser_version [String, nil] The version of the browser. Ex: 114.0
    #
    #   @param campaign_id [String, nil] The campaign id for detected in the session. This is set by the web sdk automati
    #
    #   @param clickid [String, nil] The Click ID. Ex: clickid123
    #
    #   @param clid [String, nil] The Generic Click ID. Ex: clid123
    #
    #   @param cpu_architecture [String, nil] The architecture of the CPU. Ex: x64
    #
    #   @param current_url [String, nil] The full url (including query params) of the current page
    #
    #   @param dclid [String, nil] The DoubleClick Click ID. Ex: dclid123
    #
    #   @param device_model [String, nil] The model of the device. Ex: iPhone 13
    #
    #   @param device_type [String, nil] The type of device the user is using. Ex: mobile
    #
    #   @param device_vendor [String, nil] The vendor of the device. Ex: Apple
    #
    #   @param duration [Float, nil] The time in milliseconds since the page was loaded // script was loaded
    #
    #   @param encoding [String, nil] The browsers encoding. Ex: UTF-8
    #
    #   @param engine_name [String, nil] The name of the browser engine. Ex: Blink
    #
    #   @param engine_version [String, nil] The version of the browser engine. Ex: 114.0
    #
    #   @param epik [String, nil] The Pinterest Click ID. Ex: epik456
    #
    #   @param fbc [String, nil] Facebook Click ID with prefix format for Conversions API tracking. Ex: fb.1.1554
    #
    #   @param fbclid [String, nil] Raw Facebook Click ID query parameter without prefix from ad clicks. Ex: AbCdEfG
    #
    #   @param fbp [String, nil] Facebook Browser ID parameter for identifying browsers and attributing events. E
    #
    #   @param fv [Boolean, nil] Deprecated
    #
    #   @param gad_source [String, nil] The Google Ad Source. Ex: google
    #
    #   @param gbraid [String, nil] The Google Braid ID. Ex: gbraid123
    #
    #   @param gclid [String, nil] The Google Click ID. Ex: gclid123
    #
    #   @param host [String, nil] The host of the current page. Ex: example.com
    #
    #   @param iframe [Boolean, nil] Whether the user is in an iframe. Ex: true
    #
    #   @param im_ref [String, nil] The Impact Click ID reference. Ex: im_ref123
    #
    #   @param ip [String, nil] The IP address of the user. Ex: 127.0.0.1
    #
    #   @param irclickid [String, nil] The Impact Click ID. Ex: irclickid123
    #
    #   @param is_bot [String, nil] Whether we have detected that the user is a bot. This is set automatically by th
    #
    #   @param li_fat_id [String, nil] The LinkedIn Click ID. Ex: li_fat_id123
    #
    #   @param msclkid [String, nil] The Microsoft Click ID. Ex: msclkid123
    #
    #   @param ndclid [String, nil] The NextDoor Click ID. Ex: ndclid123
    #
    #   @param new_s [Boolean, nil] Deprecated
    #
    #   @param os_name [String, nil] The name of the operating system. Ex: Windows
    #
    #   @param os_version [String, nil] The version of the operating system. Ex: 10.0
    #
    #   @param page_hash [Float, nil] A random set of numbers for the page load
    #
    #   @param pathname [String, nil] The pathname of the current page. Ex: /home
    #
    #   @param qclid [String, nil] The Quora Click ID. Ex: qclid123
    #
    #   @param rdt_cid [String, nil] The Reddit Click ID. Ex: rdt_cid123
    #
    #   @param received_at [String, nil] The time the event was received by an Ours server in ISO format
    #
    #   @param referrer [String, nil] The referrer URL of the current page
    #
    #   @param referring_domain [String, nil] The referring domain of the current page
    #
    #   @param sacid [String, nil] The StackAdapt Tracking ID. Ex: sacid123
    #
    #   @param sccid [String, nil] The SnapChat Click ID. Ex: sccid123
    #
    #   @param screen_height [Float, nil] The height of the screen. Ex: 1080
    #
    #   @param screen_width [Float, nil] The width of the screen. Ex: 1920
    #
    #   @param session_count [Float, nil] The number of sessions the user has had. Ex: 3
    #
    #   @param sid [String, nil] The session ID as assigned automatically by the web SDK. This is required for se
    #
    #   @param sr [String, nil]
    #
    #   @param title [String, nil] The title of the current page
    #
    #   @param ttclid [String, nil] The TikTok Click ID. Ex: ttclid123
    #
    #   @param twclid [String, nil] The Twitter Click ID. Ex: twclid123
    #
    #   @param uafvl [String, nil] User agent as a full list of strings.
    #
    #   @param user_agent [String, nil] The user agent of the browser
    #
    #   @param utm_campaign [String, nil] The UTM Campaign. The web SDK automatically captures this from the query params.
    #
    #   @param utm_content [String, nil] The UTM Content. The web SDK automatically captures this from the query params.
    #
    #   @param utm_medium [String, nil] The UTM Medium. The web SDK automatically captures this from the query params.
    #
    #   @param utm_name [String, nil] The UTM Name. The web SDK automatically captures this from the query params.
    #
    #   @param utm_source [String, nil] The UTM Source. The web SDK automatically captures this from the query params.
    #
    #   @param utm_term [String, nil] The UTM Term. The web SDK automatically captures this from the query params.
    #
    #   @param version [String, nil] The version of the web SDK
    #
    #   @param wbraid [String, nil] The WBRAID Identifier. The web SDK automatically captures this from the query pa
    #
    #   @param webview [Boolean, nil] Whether the user is in a webview. Ex: true
  end

  # @see OursprivacyIngest::Models::BatchCreateParams::Event#identity_context
  class IdentityContext < OursprivacyIngest::Internal::Type::BaseModel
    # @!attribute ip
    #   The end-user IP address (not the server IP).
    #
    #   @return [String]
    required :ip, String

    # @!attribute user_agent
    #   The end-user User-Agent string (not the server UA).
    #
    #   @return [String]
    required :user_agent, String, api_name: :userAgent

    # @!method initialize(ip:, user_agent:)
    #   End-user network context for server-side calls. Required for probabilistic
    #   identity resolution when the caller is a backend server rather than an end-user
    #   browser.
    #
    #   @param ip [String] The end-user IP address (not the server IP).
    #
    #   @param user_agent [String] The end-user User-Agent string (not the server UA).
  end

  # @see OursprivacyIngest::Models::BatchCreateParams::Event#user_properties
  class UserProperties < OursprivacyIngest::Internal::Type::BaseModel
    # @!attribute ad_id
    #
    #   @return [String, nil]
    optional :ad_id, String, nil?: true

    # @!attribute admitad_uid
    #
    #   @return [String, nil]
    optional :admitad_uid, String, nil?: true

    # @!attribute adset_id
    #
    #   @return [String, nil]
    optional :adset_id, String, nil?: true

    # @!attribute alart
    #
    #   @return [String, nil]
    optional :alart, String, nil?: true

    # @!attribute aleid
    #
    #   @return [String, nil]
    optional :aleid, String, nil?: true

    # @!attribute axwrt
    #
    #   @return [String, nil]
    optional :axwrt, String, nil?: true

    # @!attribute basis_cid
    #
    #   @return [String, nil]
    optional :basis_cid, String, nil?: true

    # @!attribute campaign_id
    #
    #   @return [String, nil]
    optional :campaign_id, String, nil?: true

    # @!attribute city
    #
    #   @return [String, nil]
    optional :city, String, nil?: true

    # @!attribute clickid
    #
    #   @return [String, nil]
    optional :clickid, String, nil?: true

    # @!attribute clid
    #
    #   @return [String, nil]
    optional :clid, String, nil?: true

    # @!attribute company_name
    #
    #   @return [String, nil]
    optional :company_name, String, nil?: true

    # @!attribute consent
    #
    #   @return [Hash{Symbol=>String, nil}, nil]
    optional :consent, OursprivacyIngest::Internal::Type::HashOf[String, nil?: true], nil?: true

    # @!attribute country
    #
    #   @return [String, nil]
    optional :country, String, nil?: true

    # @!attribute custom_properties
    #
    #   @return [Hash{Symbol=>String, nil}, nil]
    optional :custom_properties,
             OursprivacyIngest::Internal::Type::HashOf[String, nil?: true],
             nil?: true

    # @!attribute date_of_birth
    #
    #   @return [String, nil]
    optional :date_of_birth, String, nil?: true

    # @!attribute dclid
    #
    #   @return [String, nil]
    optional :dclid, String, nil?: true

    # @!attribute email
    #
    #   @return [String, nil]
    optional :email, String, nil?: true

    # @!attribute epik
    #
    #   @return [String, nil]
    optional :epik, String, nil?: true

    # @!attribute external_id
    #
    #   @return [String, nil]
    optional :external_id, String, nil?: true

    # @!attribute fbc
    #
    #   @return [String, nil]
    optional :fbc, String, nil?: true

    # @!attribute fbclid
    #
    #   @return [String, nil]
    optional :fbclid, String, nil?: true

    # @!attribute fbp
    #
    #   @return [String, nil]
    optional :fbp, String, nil?: true

    # @!attribute first_name
    #
    #   @return [String, nil]
    optional :first_name, String, nil?: true

    # @!attribute gad_source
    #
    #   @return [String, nil]
    optional :gad_source, String, nil?: true

    # @!attribute gbraid
    #
    #   @return [String, nil]
    optional :gbraid, String, nil?: true

    # @!attribute gclid
    #
    #   @return [String, nil]
    optional :gclid, String, nil?: true

    # @!attribute gender
    #
    #   @return [String, nil]
    optional :gender, String, nil?: true

    # @!attribute im_ref
    #
    #   @return [String, nil]
    optional :im_ref, String, nil?: true

    # @!attribute ip
    #   The IP address of the user
    #
    #   @return [String, nil]
    optional :ip, String, nil?: true

    # @!attribute irclickid
    #
    #   @return [String, nil]
    optional :irclickid, String, nil?: true

    # @!attribute is_bot
    #
    #   @return [String, nil]
    optional :is_bot, String, nil?: true

    # @!attribute job_title
    #
    #   @return [String, nil]
    optional :job_title, String, nil?: true

    # @!attribute last_name
    #
    #   @return [String, nil]
    optional :last_name, String, nil?: true

    # @!attribute li_fat_id
    #
    #   @return [String, nil]
    optional :li_fat_id, String, nil?: true

    # @!attribute msclkid
    #
    #   @return [String, nil]
    optional :msclkid, String, nil?: true

    # @!attribute ndclid
    #
    #   @return [String, nil]
    optional :ndclid, String, nil?: true

    # @!attribute phone_number
    #
    #   @return [String, nil]
    optional :phone_number, String, nil?: true

    # @!attribute qclid
    #
    #   @return [String, nil]
    optional :qclid, String, nil?: true

    # @!attribute rdt_cid
    #
    #   @return [String, nil]
    optional :rdt_cid, String, nil?: true

    # @!attribute referrer
    #
    #   @return [String, nil]
    optional :referrer, String, nil?: true

    # @!attribute referring_domain
    #
    #   @return [String, nil]
    optional :referring_domain, String, nil?: true

    # @!attribute sacid
    #
    #   @return [String, nil]
    optional :sacid, String, nil?: true

    # @!attribute sccid
    #
    #   @return [String, nil]
    optional :sccid, String, nil?: true

    # @!attribute sid
    #
    #   @return [String, nil]
    optional :sid, String, nil?: true

    # @!attribute state
    #
    #   @return [String, nil]
    optional :state, String, nil?: true

    # @!attribute ttclid
    #
    #   @return [String, nil]
    optional :ttclid, String, nil?: true

    # @!attribute twclid
    #
    #   @return [String, nil]
    optional :twclid, String, nil?: true

    # @!attribute user_agent
    #
    #   @return [String, nil]
    optional :user_agent, String, nil?: true

    # @!attribute user_agent_full_list
    #
    #   @return [String, nil]
    optional :user_agent_full_list, String, nil?: true

    # @!attribute utm_campaign
    #
    #   @return [String, nil]
    optional :utm_campaign, String, nil?: true

    # @!attribute utm_content
    #
    #   @return [String, nil]
    optional :utm_content, String, nil?: true

    # @!attribute utm_medium
    #
    #   @return [String, nil]
    optional :utm_medium, String, nil?: true

    # @!attribute utm_name
    #
    #   @return [String, nil]
    optional :utm_name, String, nil?: true

    # @!attribute utm_source
    #
    #   @return [String, nil]
    optional :utm_source, String, nil?: true

    # @!attribute utm_term
    #
    #   @return [String, nil]
    optional :utm_term, String, nil?: true

    # @!attribute wbraid
    #
    #   @return [String, nil]
    optional :wbraid, String, nil?: true

    # @!attribute zip
    #
    #   @return [String, nil]
    optional :zip, String, nil?: true

    # @!method initialize(ad_id: nil, admitad_uid: nil, adset_id: nil, alart: nil, aleid: nil, axwrt: nil, basis_cid: nil, campaign_id: nil, city: nil, clickid: nil, clid: nil, company_name: nil, consent: nil, country: nil, custom_properties: nil, date_of_birth: nil, dclid: nil, email: nil, epik: nil, external_id: nil, fbc: nil, fbclid: nil, fbp: nil, first_name: nil, gad_source: nil, gbraid: nil, gclid: nil, gender: nil, im_ref: nil, ip: nil, irclickid: nil, is_bot: nil, job_title: nil, last_name: nil, li_fat_id: nil, msclkid: nil, ndclid: nil, phone_number: nil, qclid: nil, rdt_cid: nil, referrer: nil, referring_domain: nil, sacid: nil, sccid: nil, sid: nil, state: nil, ttclid: nil, twclid: nil, user_agent: nil, user_agent_full_list: nil, utm_campaign: nil, utm_content: nil, utm_medium: nil, utm_name: nil, utm_source: nil, utm_term: nil, wbraid: nil, zip: nil)
    #   Properties to set on the visitor. (optional) You can also update these
    #   properties via the identify endpoint.
    #
    #   @param ad_id [String, nil]
    #
    #   @param admitad_uid [String, nil]
    #
    #   @param adset_id [String, nil]
    #
    #   @param alart [String, nil]
    #
    #   @param aleid [String, nil]
    #
    #   @param axwrt [String, nil]
    #
    #   @param basis_cid [String, nil]
    #
    #   @param campaign_id [String, nil]
    #
    #   @param city [String, nil]
    #
    #   @param clickid [String, nil]
    #
    #   @param clid [String, nil]
    #
    #   @param company_name [String, nil]
    #
    #   @param consent [Hash{Symbol=>String, nil}, nil]
    #
    #   @param country [String, nil]
    #
    #   @param custom_properties [Hash{Symbol=>String, nil}, nil]
    #
    #   @param date_of_birth [String, nil]
    #
    #   @param dclid [String, nil]
    #
    #   @param email [String, nil]
    #
    #   @param epik [String, nil]
    #
    #   @param external_id [String, nil]
    #
    #   @param fbc [String, nil]
    #
    #   @param fbclid [String, nil]
    #
    #   @param fbp [String, nil]
    #
    #   @param first_name [String, nil]
    #
    #   @param gad_source [String, nil]
    #
    #   @param gbraid [String, nil]
    #
    #   @param gclid [String, nil]
    #
    #   @param gender [String, nil]
    #
    #   @param im_ref [String, nil]
    #
    #   @param ip [String, nil] The IP address of the user
    #
    #   @param irclickid [String, nil]
    #
    #   @param is_bot [String, nil]
    #
    #   @param job_title [String, nil]
    #
    #   @param last_name [String, nil]
    #
    #   @param li_fat_id [String, nil]
    #
    #   @param msclkid [String, nil]
    #
    #   @param ndclid [String, nil]
    #
    #   @param phone_number [String, nil]
    #
    #   @param qclid [String, nil]
    #
    #   @param rdt_cid [String, nil]
    #
    #   @param referrer [String, nil]
    #
    #   @param referring_domain [String, nil]
    #
    #   @param sacid [String, nil]
    #
    #   @param sccid [String, nil]
    #
    #   @param sid [String, nil]
    #
    #   @param state [String, nil]
    #
    #   @param ttclid [String, nil]
    #
    #   @param twclid [String, nil]
    #
    #   @param user_agent [String, nil]
    #
    #   @param user_agent_full_list [String, nil]
    #
    #   @param utm_campaign [String, nil]
    #
    #   @param utm_content [String, nil]
    #
    #   @param utm_medium [String, nil]
    #
    #   @param utm_name [String, nil]
    #
    #   @param utm_source [String, nil]
    #
    #   @param utm_term [String, nil]
    #
    #   @param wbraid [String, nil]
    #
    #   @param zip [String, nil]
  end
end

Instance Attribute Details

#default_propertiesOursprivacyIngest::Models::BatchCreateParams::Event::DefaultProperties?

These properties are used throughout the Ours app to pass known values onto destinations



49
50
51
52
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 49

optional :default_properties,
-> { OursprivacyIngest::BatchCreateParams::Event::DefaultProperties },
api_name: :defaultProperties,
nil?: true

#distinct_idString?

A unique identifier for the event. This helps prevent duplicate events.

Returns:

  • (String, nil)


58
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 58

optional :distinct_id, String, api_name: :distinctId, nil?: true

#emailString?

The email address of a user. We will associate this event with the user or create a user. Used for lookup if externalId and userId are not included in the request.

Returns:

  • (String, nil)


66
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 66

optional :email, String, nil?: true

#eventString

The name of the event you’re tracking. This must be whitelisted in the Ours dashboard.

Returns:

  • (String)


36
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 36

required :event, String

#event_propertiesHash{Symbol=>String, nil}?

Any additional event properties you want to pass along.

Returns:

  • (Hash{Symbol=>String, nil}, nil)


72
73
74
75
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 72

optional :event_properties,
OursprivacyIngest::Internal::Type::HashOf[String, nil?: true],
api_name: :eventProperties,
nil?: true

#external_idString?

The externalId (the ID in your system) of a user. We will associate this event with the user or create a user. If included in the request, email lookup is ignored.

Returns:

  • (String, nil)


83
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 83

optional :external_id, String, api_name: :externalId, nil?: true

#identity_contextOursprivacyIngest::Models::BatchCreateParams::Event::IdentityContext?

End-user network context for server-side calls. Required for probabilistic identity resolution when the caller is a backend server rather than an end-user browser.



91
92
93
94
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 91

optional :identity_context,
-> { OursprivacyIngest::BatchCreateParams::Event::IdentityContext },
api_name: :identityContext,
nil?: true

#timeFloat?

The time at which the event occurred in milliseconds since UTC epoch. The time must be in the past and within the last 7 days.

Returns:

  • (Float, nil)


101
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 101

optional :time, Float, nil?: true

#tokenString?

The token for your Source. You can find this in the dashboard.

Returns:

  • (String, nil)


42
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 42

optional :token, String

#user_idString?

The Ours user id stored in local storage and cookies on your web properties. If userId is included in the request, we do not lookup the user by email or externalId.

Returns:

  • (String, nil)


109
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 109

optional :user_id, String, api_name: :userId, nil?: true

#user_propertiesOursprivacyIngest::Models::BatchCreateParams::Event::UserProperties?

Properties to set on the visitor. (optional) You can also update these properties via the identify endpoint.



116
117
118
119
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 116

optional :user_properties,
-> { OursprivacyIngest::BatchCreateParams::Event::UserProperties },
api_name: :userProperties,
nil?: true