Class: OursprivacyIngest::Models::BatchCreateParams::Event::DefaultProperties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OursprivacyIngest::Models::BatchCreateParams::Event::DefaultProperties
- Defined in:
- lib/oursprivacy_ingest/models/batch_create_params.rb,
sig/oursprivacy_ingest/models/batch_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#_ef_transaction_id ⇒ String?
The Everflow affiliate Click (Transaction) ID, captured from the
_ef_transaction_idURL parameter. -
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active.
-
#ad_id ⇒ String?
The ad id for detected in the session.
-
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID.
-
#adset_id ⇒ String?
The adset id for detected in the session.
-
#alart ⇒ String?
The AppLovin alart query parameter.
-
#aleid ⇒ String?
The AppLovin aleid query parameter.
-
#axwrt ⇒ String?
The AppLovin pixel cookie value (_axwrt).
-
#basis_cid ⇒ String?
The Basis DSP Click ID.
-
#beeswax_auction_id ⇒ String?
The Beeswax (FreeWheel Buyer Cloud) auction ID, captured from the
{{AUCTION_ID}}macro on creative click URLs. -
#browser_language ⇒ String?
The language of the browser.
-
#browser_name ⇒ String?
The name of the browser.
-
#browser_version ⇒ String?
The version of the browser.
-
#campaign_id ⇒ String?
The campaign id for detected in the session.
-
#clickid ⇒ String?
The Click ID.
-
#clid ⇒ String?
The Generic Click ID.
-
#cpu_architecture ⇒ String?
The architecture of the CPU.
-
#current_url ⇒ String?
The full url (including query params) of the current page.
-
#dclid ⇒ String?
The DoubleClick Click ID.
-
#device_model ⇒ String?
The model of the device.
-
#device_type ⇒ String?
The type of device the user is using.
-
#device_vendor ⇒ String?
The vendor of the device.
-
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded.
-
#encoding ⇒ String?
The browsers encoding.
-
#engine_name ⇒ String?
The name of the browser engine.
-
#engine_version ⇒ String?
The version of the browser engine.
-
#epik ⇒ String?
The Pinterest Click ID.
-
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking.
-
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks.
-
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events.
-
#fv ⇒ Boolean?
Deprecated.
-
#gad_source ⇒ String?
The Google Ad Source.
-
#gbraid ⇒ String?
The Google Braid ID.
-
#gclid ⇒ String?
The Google Click ID.
-
#host ⇒ String?
The host of the current page.
-
#iframe ⇒ Boolean?
Whether the user is in an iframe.
-
#im_ref ⇒ String?
The Impact Click ID reference.
-
#ip ⇒ String?
The IP address of the user.
-
#irclickid ⇒ String?
The Impact Click ID.
-
#is_bot ⇒ String?
Whether we have detected that the user is a bot.
-
#li_fat_id ⇒ String?
The LinkedIn Click ID.
-
#msclkid ⇒ String?
The Microsoft Click ID.
-
#ndclid ⇒ String?
The NextDoor Click ID.
-
#new_s ⇒ Boolean?
Deprecated.
-
#ob_click_id ⇒ String?
The Outbrain click ID, captured from the
ob_click_idURL parameter (Outbrain{{ob_click_id}}macro) on the landing page. -
#oppref ⇒ String?
The OpenAI Ads privacy-preserving reference, captured from the
opprefURL parameter on landing pages (the OpenAI Pixel also stores it in a__opprefcookie). -
#os_name ⇒ String?
The name of the operating system.
-
#os_version ⇒ String?
The version of the operating system.
-
#page_hash ⇒ Float?
A random set of numbers for the page load.
-
#pathname ⇒ String?
The pathname of the current page.
-
#qclid ⇒ String?
The Quora Click ID.
-
#rdt_cid ⇒ String?
The Reddit Click ID.
-
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format.
-
#referrer ⇒ String?
The referrer URL of the current page.
-
#referring_domain ⇒ String?
The referring domain of the current page.
-
#sacid ⇒ String?
The StackAdapt Tracking ID.
-
#sccid ⇒ String?
The SnapChat Click ID.
-
#screen_height ⇒ Float?
The height of the screen.
-
#screen_width ⇒ Float?
The width of the screen.
-
#session_count ⇒ Float?
The number of sessions the user has had.
-
#sid ⇒ String?
The session ID as assigned automatically by the web SDK.
- #sr ⇒ String?
-
#title ⇒ String?
The title of the current page.
-
#ttclid ⇒ String?
The TikTok Click ID.
-
#twclid ⇒ String?
The Twitter Click ID.
-
#uafvl ⇒ String?
User agent as a full list of strings.
-
#user_agent ⇒ String?
The user agent of the browser.
-
#utm_campaign ⇒ String?
The UTM Campaign.
-
#utm_content ⇒ String?
The UTM Content.
-
#utm_medium ⇒ String?
The UTM Medium.
-
#utm_name ⇒ String?
The UTM Name.
-
#utm_source ⇒ String?
The UTM Source.
-
#utm_term ⇒ String?
The UTM Term.
-
#version ⇒ String?
The SDK version (e.g., web SDK or ingest-sdk-* via Stainless headers).
-
#viant_click_id ⇒ String?
The Viant (Adelphic) Click ID, captured from the
viant_click_idURL parameter (Viant${ADELPHIC_CLICKID}macro). -
#viant_impression_id ⇒ String?
The Viant (Adelphic) Impression ID, captured from the
viant_impression_idURL parameter (Viant${ADELPHIC_IMPRESSIONID}macro). -
#wbraid ⇒ String?
The WBRAID Identifier.
-
#webview ⇒ Boolean?
Whether the user is in a webview.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
330 |
# File 'sig/oursprivacy_ingest/models/batch_create_params.rbs', line 330
def initialize: (
|
Instance Attribute Details
#_ef_transaction_id ⇒ String?
The Everflow affiliate Click (Transaction) ID, captured from the
_ef_transaction_id URL parameter. Ex: ef_click_abc123
153 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 153 optional :_ef_transaction_id, String, nil?: true |
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active
159 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 159 optional :active_duration, Float, api_name: :activeDuration, nil?: true |
#ad_id ⇒ String?
The ad id for detected in the session. This is set by the web sdk automatically.
165 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 165 optional :ad_id, String, nil?: true |
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID. Ex: admitad_uid_abc123
171 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 171 optional :admitad_uid, String, nil?: true |
#adset_id ⇒ String?
The adset id for detected in the session. This is set by the web sdk automatically.
178 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 178 optional :adset_id, String, nil?: true |
#alart ⇒ String?
The AppLovin alart query parameter. Ex: alart123
184 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 184 optional :alart, String, nil?: true |
#aleid ⇒ String?
The AppLovin aleid query parameter. Ex: aleid123
190 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 190 optional :aleid, String, nil?: true |
#axwrt ⇒ String?
The AppLovin pixel cookie value (_axwrt). Web-only.
196 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 196 optional :axwrt, String, nil?: true |
#basis_cid ⇒ String?
The Basis DSP Click ID. Ex: basis_cid123
202 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 202 optional :basis_cid, String, nil?: true |
#beeswax_auction_id ⇒ String?
The Beeswax (FreeWheel Buyer Cloud) auction ID, captured from the
{{AUCTION_ID}} macro on creative click URLs. Ex: bx-auc-abc123
209 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 209 optional :beeswax_auction_id, String, nil?: true |
#browser_language ⇒ String?
The language of the browser. Ex: en-US
215 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 215 optional :browser_language, String, nil?: true |
#browser_name ⇒ String?
The name of the browser. Ex: Chrome
221 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 221 optional :browser_name, String, nil?: true |
#browser_version ⇒ String?
The version of the browser. Ex: 114.0
227 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 227 optional :browser_version, String, nil?: true |
#campaign_id ⇒ String?
The campaign id for detected in the session. This is set by the web sdk automatically.
234 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 234 optional :campaign_id, String, nil?: true |
#clickid ⇒ String?
The Click ID. Ex: clickid123
240 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 240 optional :clickid, String, nil?: true |
#clid ⇒ String?
The Generic Click ID. Ex: clid123
246 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 246 optional :clid, String, nil?: true |
#cpu_architecture ⇒ String?
The architecture of the CPU. Ex: x64
252 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 252 optional :cpu_architecture, String, nil?: true |
#current_url ⇒ String?
The full url (including query params) of the current page
258 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 258 optional :current_url, String, nil?: true |
#dclid ⇒ String?
The DoubleClick Click ID. Ex: dclid123
264 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 264 optional :dclid, String, nil?: true |
#device_model ⇒ String?
The model of the device. Ex: iPhone 13
270 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 270 optional :device_model, String, nil?: true |
#device_type ⇒ String?
The type of device the user is using. Ex: mobile
276 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 276 optional :device_type, String, nil?: true |
#device_vendor ⇒ String?
The vendor of the device. Ex: Apple
282 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 282 optional :device_vendor, String, nil?: true |
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded
288 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 288 optional :duration, Float, nil?: true |
#encoding ⇒ String?
The browsers encoding. Ex: UTF-8
294 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 294 optional :encoding, String, nil?: true |
#engine_name ⇒ String?
The name of the browser engine. Ex: Blink
300 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 300 optional :engine_name, String, nil?: true |
#engine_version ⇒ String?
The version of the browser engine. Ex: 114.0
306 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 306 optional :engine_version, String, nil?: true |
#epik ⇒ String?
The Pinterest Click ID. Ex: epik456
312 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 312 optional :epik, String, nil?: true |
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking. Ex: fb.1.1554763741205.AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
319 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 319 optional :fbc, String, nil?: true |
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks. Ex: AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
326 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 326 optional :fbclid, String, nil?: true |
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events. Ex: fb.1.1554763741205.1098115397
333 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 333 optional :fbp, String, nil?: true |
#fv ⇒ Boolean?
Deprecated
339 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 339 optional :fv, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#gad_source ⇒ String?
The Google Ad Source. Ex: google
345 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 345 optional :gad_source, String, nil?: true |
#gbraid ⇒ String?
The Google Braid ID. Ex: gbraid123
351 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 351 optional :gbraid, String, nil?: true |
#gclid ⇒ String?
The Google Click ID. Ex: gclid123
357 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 357 optional :gclid, String, nil?: true |
#host ⇒ String?
The host of the current page. Ex: example.com
363 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 363 optional :host, String, nil?: true |
#iframe ⇒ Boolean?
Whether the user is in an iframe. Ex: true
369 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 369 optional :iframe, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#im_ref ⇒ String?
The Impact Click ID reference. Ex: im_ref123
375 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 375 optional :im_ref, String, nil?: true |
#ip ⇒ String?
The IP address of the user. Ex: 127.0.0.1
381 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 381 optional :ip, String, nil?: true |
#irclickid ⇒ String?
The Impact Click ID. Ex: irclickid123
387 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 387 optional :irclickid, String, nil?: true |
#is_bot ⇒ String?
Whether we have detected that the user is a bot. This is set automatically by the Ours server primarily for events tracked through the web SDK.
394 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 394 optional :is_bot, String, nil?: true |
#li_fat_id ⇒ String?
The LinkedIn Click ID. Ex: li_fat_id123
400 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 400 optional :li_fat_id, String, nil?: true |
#msclkid ⇒ String?
The Microsoft Click ID. Ex: msclkid123
406 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 406 optional :msclkid, String, nil?: true |
#ndclid ⇒ String?
The NextDoor Click ID. Ex: ndclid123
412 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 412 optional :ndclid, String, nil?: true |
#new_s ⇒ Boolean?
Deprecated
418 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 418 optional :new_s, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#ob_click_id ⇒ String?
The Outbrain click ID, captured from the ob_click_id URL parameter (Outbrain
{{ob_click_id}} macro) on the landing page. Ex: ob_click_abc123
425 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 425 optional :ob_click_id, String, nil?: true |
#oppref ⇒ String?
The OpenAI Ads privacy-preserving reference, captured from the oppref URL
parameter on landing pages (the OpenAI Pixel also stores it in a __oppref
cookie). Sent to OpenAI Ads on Conversions API events for attribution. Ex:
oppref_abc
434 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 434 optional :oppref, String, nil?: true |
#os_name ⇒ String?
The name of the operating system. Ex: Windows
440 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 440 optional :os_name, String, nil?: true |
#os_version ⇒ String?
The version of the operating system. Ex: 10.0
446 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 446 optional :os_version, String, nil?: true |
#page_hash ⇒ Float?
A random set of numbers for the page load
452 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 452 optional :page_hash, Float, nil?: true |
#pathname ⇒ String?
The pathname of the current page. Ex: /home
458 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 458 optional :pathname, String, nil?: true |
#qclid ⇒ String?
The Quora Click ID. Ex: qclid123
464 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 464 optional :qclid, String, nil?: true |
#rdt_cid ⇒ String?
The Reddit Click ID. Ex: rdt_cid123
470 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 470 optional :rdt_cid, String, nil?: true |
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format
476 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 476 optional :received_at, String, nil?: true |
#referrer ⇒ String?
The referrer URL of the current page
482 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 482 optional :referrer, String, nil?: true |
#referring_domain ⇒ String?
The referring domain of the current page
488 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 488 optional :referring_domain, String, nil?: true |
#sacid ⇒ String?
The StackAdapt Tracking ID. Ex: sacid123
494 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 494 optional :sacid, String, nil?: true |
#sccid ⇒ String?
The SnapChat Click ID. Ex: sccid123
500 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 500 optional :sccid, String, nil?: true |
#screen_height ⇒ Float?
The height of the screen. Ex: 1080
506 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 506 optional :screen_height, Float, nil?: true |
#screen_width ⇒ Float?
The width of the screen. Ex: 1920
512 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 512 optional :screen_width, Float, nil?: true |
#session_count ⇒ Float?
The number of sessions the user has had. Ex: 3
518 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 518 optional :session_count, Float, api_name: :sessionCount, nil?: true |
#sid ⇒ String?
The session ID as assigned automatically by the web SDK. This is required for session replay
525 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 525 optional :sid, String, nil?: true |
#sr ⇒ String?
530 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 530 optional :sr, String, nil?: true |
#title ⇒ String?
The title of the current page
536 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 536 optional :title, String, nil?: true |
#ttclid ⇒ String?
The TikTok Click ID. Ex: ttclid123
542 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 542 optional :ttclid, String, nil?: true |
#twclid ⇒ String?
The Twitter Click ID. Ex: twclid123
548 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 548 optional :twclid, String, nil?: true |
#uafvl ⇒ String?
User agent as a full list of strings.
554 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 554 optional :uafvl, String, nil?: true |
#user_agent ⇒ String?
The user agent of the browser
560 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 560 optional :user_agent, String, nil?: true |
#utm_campaign ⇒ String?
The UTM Campaign. The web SDK automatically captures this from the query params.
566 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 566 optional :utm_campaign, String, nil?: true |
#utm_content ⇒ String?
The UTM Content. The web SDK automatically captures this from the query params.
572 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 572 optional :utm_content, String, nil?: true |
#utm_medium ⇒ String?
The UTM Medium. The web SDK automatically captures this from the query params.
578 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 578 optional :utm_medium, String, nil?: true |
#utm_name ⇒ String?
The UTM Name. The web SDK automatically captures this from the query params.
584 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 584 optional :utm_name, String, nil?: true |
#utm_source ⇒ String?
The UTM Source. The web SDK automatically captures this from the query params.
590 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 590 optional :utm_source, String, nil?: true |
#utm_term ⇒ String?
The UTM Term. The web SDK automatically captures this from the query params.
596 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 596 optional :utm_term, String, nil?: true |
#version ⇒ String?
The SDK version (e.g., web SDK or ingest-sdk-* via Stainless headers)
602 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 602 optional :version, String, nil?: true |
#viant_click_id ⇒ String?
The Viant (Adelphic) Click ID, captured from the viant_click_id URL parameter
(Viant ${ADELPHIC_CLICKID} macro). Sent as xid on Viant postbacks. Ex:
viant_click_abc123
610 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 610 optional :viant_click_id, String, nil?: true |
#viant_impression_id ⇒ String?
The Viant (Adelphic) Impression ID, captured from the viant_impression_id URL
parameter (Viant ${ADELPHIC_IMPRESSIONID} macro). Sent as imp_id on Viant
postbacks for post-view attribution. Ex: viant_imp_abc123
618 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 618 optional :viant_impression_id, String, nil?: true |
#wbraid ⇒ String?
The WBRAID Identifier. The web SDK automatically captures this from the query params.
625 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 625 optional :wbraid, String, nil?: true |
#webview ⇒ Boolean?
Whether the user is in a webview. Ex: true
631 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 631 optional :webview, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
Instance Method Details
#to_hash ⇒ {
411 |
# File 'sig/oursprivacy_ingest/models/batch_create_params.rbs', line 411
def to_hash: -> {
|