Class: OursprivacyIngest::Models::VisitorUpsertParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OursprivacyIngest::Models::VisitorUpsertParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/oursprivacy_ingest/models/visitor_upsert_params.rb,
sig/oursprivacy_ingest/models/visitor_upsert_params.rbs
Overview
Defined Under Namespace
Classes: DefaultProperties, IdentityContext, UserProperties
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::OursprivacyIngest
Instance Attribute Summary collapse
-
#default_properties ⇒ OursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties?
These properties are used throughout the Ours app to pass known values onto destinations.
-
#email ⇒ String?
The email address of a user.
-
#external_id ⇒ String?
Your system's unique identifier for this user.
-
#identity_context ⇒ OursprivacyIngest::Models::VisitorUpsertParams::IdentityContext?
End-user network context for server-side calls.
-
#token ⇒ String
The token for your Source.
-
#user_id ⇒ String?
The Ours Visitor ID stored in local storage and cookies on your web properties.
-
#user_properties ⇒ OursprivacyIngest::Models::VisitorUpsertParams::UserProperties
User properties to associate with this user.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(_ef_transaction_id: nil, active_duration: nil, ad_id: nil, admitad_uid: nil, adset_id: nil, alart: nil, aleid: nil, axwrt: nil, basis_cid: nil, beeswax_auction_id: nil, browser_language: nil, browser_name: nil, browser_version: nil, campaign_id: nil, clickid: nil, clid: nil, cpu_architecture: nil, current_url: nil, dclid: nil, device_model: nil, device_type: nil, device_vendor: nil, duration: nil, encoding: nil, engine_name: nil, engine_version: nil, epik: nil, fbc: nil, fbclid: nil, fbp: nil, fv: nil, gad_source: nil, gbraid: nil, gclid: nil, host: nil, iframe: nil, im_ref: nil, ip: nil, irclickid: nil, is_bot: nil, li_fat_id: nil, msclkid: nil, ndclid: nil, new_s: nil, ob_click_id: nil, oppref: nil, os_name: nil, os_version: nil, page_hash: nil, pathname: nil, qclid: nil, rdt_cid: nil, received_at: nil, referrer: nil, referring_domain: nil, sacid: nil, sccid: nil, screen_height: nil, screen_width: nil, session_count: nil, sid: nil, sr: nil, title: nil, ttclid: nil, twclid: nil, uafvl: nil, user_agent: nil, utm_campaign: nil, utm_content: nil, utm_medium: nil, utm_name: nil, utm_source: nil, utm_term: nil, version: nil, viant_click_id: nil, viant_impression_id: nil, wbraid: nil, webview: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see DefaultProperties for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(_ef_transaction_id: nil, active_duration: nil, ad_id: nil, admitad_uid: nil, adset_id: nil, alart: nil, aleid: nil, axwrt: nil, basis_cid: nil, beeswax_auction_id: nil, browser_language: nil, browser_name: nil, browser_version: nil, campaign_id: nil, clickid: nil, clid: nil, cpu_architecture: nil, current_url: nil, dclid: nil, device_model: nil, device_type: nil, device_vendor: nil, duration: nil, encoding: nil, engine_name: nil, engine_version: nil, epik: nil, fbc: nil, fbclid: nil, fbp: nil, fv: nil, gad_source: nil, gbraid: nil, gclid: nil, host: nil, iframe: nil, im_ref: nil, ip: nil, irclickid: nil, is_bot: nil, li_fat_id: nil, msclkid: nil, ndclid: nil, new_s: nil, ob_click_id: nil, oppref: nil, os_name: nil, os_version: nil, page_hash: nil, pathname: nil, qclid: nil, rdt_cid: nil, received_at: nil, referrer: nil, referring_domain: nil, sacid: nil, sccid: nil, screen_height: nil, screen_width: nil, session_count: nil, sid: nil, sr: nil, title: nil, ttclid: nil, twclid: nil, uafvl: nil, user_agent: nil, utm_campaign: nil, utm_content: nil, utm_medium: nil, utm_name: nil, utm_source: nil, utm_term: nil, version: nil, viant_click_id: nil, viant_impression_id: nil, wbraid: nil, webview: nil) ⇒ Object
Some parameter documentations has been truncated, see DefaultProperties for more details.
These properties are used throughout the Ours app to pass known values onto destinations
`_ef_transactio
|
|
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 417
|
Instance Attribute Details
#default_properties ⇒ OursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties?
These properties are used throughout the Ours app to pass known values onto destinations
31 32 33 34 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 31 optional :default_properties, -> { OursprivacyIngest::VisitorUpsertParams::DefaultProperties }, api_name: :defaultProperties, nil?: true |
#email ⇒ String?
The email address of a user. When userId is absent and externalId does not resolve a visitor, we search your account for a visitor with this email. If no match is found, we try userProperties.phone_number before creating a new visitor.
43 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 43 optional :email, String, nil?: true |
#external_id ⇒ String?
Your system's unique identifier for this user. When userId is absent, we search your account for an existing visitor with this externalId. If no match is found, we try email and then userProperties.phone_number before creating a new visitor. If you also have the userId from cookies or local storage, send both — it removes the lookup round-trip.
53 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 53 optional :external_id, String, api_name: :externalId, nil?: true |
#identity_context ⇒ OursprivacyIngest::Models::VisitorUpsertParams::IdentityContext?
End-user network context for server-side calls. Required for probabilistic identity resolution when the caller is a backend server rather than an end-user browser.
61 62 63 64 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 61 optional :identity_context, -> { OursprivacyIngest::VisitorUpsertParams::IdentityContext }, api_name: :identityContext, nil?: true |
#token ⇒ String
The token for your Source. You can find this in the dashboard.
14 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 14 required :token, String |
#user_id ⇒ String?
The Ours Visitor ID stored in local storage and cookies on your web properties. When present, this is used directly — no lookup by externalId, email, or phone is performed. If you have both a userId and an externalId, send both so the event is attached to the right visitor without any lookup overhead.
73 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 73 optional :user_id, String, api_name: :userId, nil?: true |
#user_properties ⇒ OursprivacyIngest::Models::VisitorUpsertParams::UserProperties
User properties to associate with this user. The existing user properties will be updated. And all future events will have these properties associated with them.
22 23 24 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 22 required :user_properties, -> { OursprivacyIngest::VisitorUpsertParams::UserProperties }, api_name: :userProperties |
Instance Method Details
#to_hash ⇒ {
44 |
# File 'sig/oursprivacy_ingest/models/visitor_upsert_params.rbs', line 44 def to_hash: -> { |