Class: OursprivacyIngest::Models::VisitorUpsertParams::UserProperties

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/oursprivacy_ingest/models/visitor_upsert_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, user_properties:, default_properties: nil, email: nil, external_id: nil, identity_context: nil, user_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OursprivacyIngest::Models::VisitorUpsertParams for more details.

Parameters:

  • token (String)

    The token for your Source. You can find this in the dashboard.

  • user_properties (OursprivacyIngest::Models::VisitorUpsertParams::UserProperties)

    User properties to associate with this user. The existing user properties will b

  • default_properties (OursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties, nil) (defaults to: nil)

    These properties are used throughout the Ours app to pass known values onto dest

  • email (String, nil) (defaults to: nil)

    The email address of a user. Used as a fallback lookup when neither userId nor e

  • external_id (String, nil) (defaults to: nil)

    Your system’s unique identifier for this user. We search your account for an exi

  • identity_context (OursprivacyIngest::Models::VisitorUpsertParams::IdentityContext, nil) (defaults to: nil)

    End-user network context for server-side calls. Required for probabilistic ident

  • user_id (String, nil) (defaults to: nil)

    The Ours Visitor ID stored in local storage and cookies on your web properties.

  • request_options (OursprivacyIngest::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 94

class UserProperties < OursprivacyIngest::Internal::Type::BaseModel
  # @!attribute ad_id
  #
  #   @return [String, nil]
  optional :ad_id, String, nil?: true

  # @!attribute admitad_uid
  #
  #   @return [String, nil]
  optional :admitad_uid, String, nil?: true

  # @!attribute adset_id
  #
  #   @return [String, nil]
  optional :adset_id, String, nil?: true

  # @!attribute alart
  #
  #   @return [String, nil]
  optional :alart, String, nil?: true

  # @!attribute aleid
  #
  #   @return [String, nil]
  optional :aleid, String, nil?: true

  # @!attribute axwrt
  #
  #   @return [String, nil]
  optional :axwrt, String, nil?: true

  # @!attribute basis_cid
  #
  #   @return [String, nil]
  optional :basis_cid, String, nil?: true

  # @!attribute campaign_id
  #
  #   @return [String, nil]
  optional :campaign_id, String, nil?: true

  # @!attribute city
  #
  #   @return [String, nil]
  optional :city, String, nil?: true

  # @!attribute clickid
  #
  #   @return [String, nil]
  optional :clickid, String, nil?: true

  # @!attribute clid
  #
  #   @return [String, nil]
  optional :clid, String, nil?: true

  # @!attribute company_name
  #
  #   @return [String, nil]
  optional :company_name, String, nil?: true

  # @!attribute consent
  #
  #   @return [Hash{Symbol=>String, nil}, nil]
  optional :consent, OursprivacyIngest::Internal::Type::HashOf[String, nil?: true], nil?: true

  # @!attribute country
  #
  #   @return [String, nil]
  optional :country, String, nil?: true

  # @!attribute custom_properties
  #
  #   @return [Hash{Symbol=>String, nil}, nil]
  optional :custom_properties, OursprivacyIngest::Internal::Type::HashOf[String, nil?: true], nil?: true

  # @!attribute date_of_birth
  #
  #   @return [String, nil]
  optional :date_of_birth, String, nil?: true

  # @!attribute dclid
  #
  #   @return [String, nil]
  optional :dclid, String, nil?: true

  # @!attribute email
  #
  #   @return [String, nil]
  optional :email, String, nil?: true

  # @!attribute epik
  #
  #   @return [String, nil]
  optional :epik, String, nil?: true

  # @!attribute external_id
  #
  #   @return [String, nil]
  optional :external_id, String, nil?: true

  # @!attribute fbc
  #
  #   @return [String, nil]
  optional :fbc, String, nil?: true

  # @!attribute fbclid
  #
  #   @return [String, nil]
  optional :fbclid, String, nil?: true

  # @!attribute fbp
  #
  #   @return [String, nil]
  optional :fbp, String, nil?: true

  # @!attribute first_name
  #
  #   @return [String, nil]
  optional :first_name, String, nil?: true

  # @!attribute gad_source
  #
  #   @return [String, nil]
  optional :gad_source, String, nil?: true

  # @!attribute gbraid
  #
  #   @return [String, nil]
  optional :gbraid, String, nil?: true

  # @!attribute gclid
  #
  #   @return [String, nil]
  optional :gclid, String, nil?: true

  # @!attribute gender
  #
  #   @return [String, nil]
  optional :gender, String, nil?: true

  # @!attribute im_ref
  #
  #   @return [String, nil]
  optional :im_ref, String, nil?: true

  # @!attribute ip
  #   The IP address of the user
  #
  #   @return [String, nil]
  optional :ip, String, nil?: true

  # @!attribute irclickid
  #
  #   @return [String, nil]
  optional :irclickid, String, nil?: true

  # @!attribute is_bot
  #
  #   @return [String, nil]
  optional :is_bot, String, nil?: true

  # @!attribute job_title
  #
  #   @return [String, nil]
  optional :job_title, String, nil?: true

  # @!attribute last_name
  #
  #   @return [String, nil]
  optional :last_name, String, nil?: true

  # @!attribute li_fat_id
  #
  #   @return [String, nil]
  optional :li_fat_id, String, nil?: true

  # @!attribute msclkid
  #
  #   @return [String, nil]
  optional :msclkid, String, nil?: true

  # @!attribute ndclid
  #
  #   @return [String, nil]
  optional :ndclid, String, nil?: true

  # @!attribute phone_number
  #
  #   @return [String, nil]
  optional :phone_number, String, nil?: true

  # @!attribute qclid
  #
  #   @return [String, nil]
  optional :qclid, String, nil?: true

  # @!attribute rdt_cid
  #
  #   @return [String, nil]
  optional :rdt_cid, String, nil?: true

  # @!attribute referrer
  #
  #   @return [String, nil]
  optional :referrer, String, nil?: true

  # @!attribute referring_domain
  #
  #   @return [String, nil]
  optional :referring_domain, String, nil?: true

  # @!attribute sacid
  #
  #   @return [String, nil]
  optional :sacid, String, nil?: true

  # @!attribute sccid
  #
  #   @return [String, nil]
  optional :sccid, String, nil?: true

  # @!attribute sid
  #
  #   @return [String, nil]
  optional :sid, String, nil?: true

  # @!attribute state
  #
  #   @return [String, nil]
  optional :state, String, nil?: true

  # @!attribute ttclid
  #
  #   @return [String, nil]
  optional :ttclid, String, nil?: true

  # @!attribute twclid
  #
  #   @return [String, nil]
  optional :twclid, String, nil?: true

  # @!attribute user_agent
  #
  #   @return [String, nil]
  optional :user_agent, String, nil?: true

  # @!attribute user_agent_full_list
  #
  #   @return [String, nil]
  optional :user_agent_full_list, String, nil?: true

  # @!attribute utm_campaign
  #
  #   @return [String, nil]
  optional :utm_campaign, String, nil?: true

  # @!attribute utm_content
  #
  #   @return [String, nil]
  optional :utm_content, String, nil?: true

  # @!attribute utm_medium
  #
  #   @return [String, nil]
  optional :utm_medium, String, nil?: true

  # @!attribute utm_name
  #
  #   @return [String, nil]
  optional :utm_name, String, nil?: true

  # @!attribute utm_source
  #
  #   @return [String, nil]
  optional :utm_source, String, nil?: true

  # @!attribute utm_term
  #
  #   @return [String, nil]
  optional :utm_term, String, nil?: true

  # @!attribute wbraid
  #
  #   @return [String, nil]
  optional :wbraid, String, nil?: true

  # @!attribute zip
  #
  #   @return [String, nil]
  optional :zip, String, nil?: true

  # @!method initialize(ad_id: nil, admitad_uid: nil, adset_id: nil, alart: nil, aleid: nil, axwrt: nil, basis_cid: nil, campaign_id: nil, city: nil, clickid: nil, clid: nil, company_name: nil, consent: nil, country: nil, custom_properties: nil, date_of_birth: nil, dclid: nil, email: nil, epik: nil, external_id: nil, fbc: nil, fbclid: nil, fbp: nil, first_name: nil, gad_source: nil, gbraid: nil, gclid: nil, gender: nil, im_ref: nil, ip: nil, irclickid: nil, is_bot: nil, job_title: nil, last_name: nil, li_fat_id: nil, msclkid: nil, ndclid: nil, phone_number: nil, qclid: nil, rdt_cid: nil, referrer: nil, referring_domain: nil, sacid: nil, sccid: nil, sid: nil, state: nil, ttclid: nil, twclid: nil, user_agent: nil, user_agent_full_list: nil, utm_campaign: nil, utm_content: nil, utm_medium: nil, utm_name: nil, utm_source: nil, utm_term: nil, wbraid: nil, zip: nil)
  #   User properties to associate with this user. The existing user properties will
  #   be updated. And all future events will have these properties associated with
  #   them.
  #
  #   @param ad_id [String, nil]
  #
  #   @param admitad_uid [String, nil]
  #
  #   @param adset_id [String, nil]
  #
  #   @param alart [String, nil]
  #
  #   @param aleid [String, nil]
  #
  #   @param axwrt [String, nil]
  #
  #   @param basis_cid [String, nil]
  #
  #   @param campaign_id [String, nil]
  #
  #   @param city [String, nil]
  #
  #   @param clickid [String, nil]
  #
  #   @param clid [String, nil]
  #
  #   @param company_name [String, nil]
  #
  #   @param consent [Hash{Symbol=>String, nil}, nil]
  #
  #   @param country [String, nil]
  #
  #   @param custom_properties [Hash{Symbol=>String, nil}, nil]
  #
  #   @param date_of_birth [String, nil]
  #
  #   @param dclid [String, nil]
  #
  #   @param email [String, nil]
  #
  #   @param epik [String, nil]
  #
  #   @param external_id [String, nil]
  #
  #   @param fbc [String, nil]
  #
  #   @param fbclid [String, nil]
  #
  #   @param fbp [String, nil]
  #
  #   @param first_name [String, nil]
  #
  #   @param gad_source [String, nil]
  #
  #   @param gbraid [String, nil]
  #
  #   @param gclid [String, nil]
  #
  #   @param gender [String, nil]
  #
  #   @param im_ref [String, nil]
  #
  #   @param ip [String, nil] The IP address of the user
  #
  #   @param irclickid [String, nil]
  #
  #   @param is_bot [String, nil]
  #
  #   @param job_title [String, nil]
  #
  #   @param last_name [String, nil]
  #
  #   @param li_fat_id [String, nil]
  #
  #   @param msclkid [String, nil]
  #
  #   @param ndclid [String, nil]
  #
  #   @param phone_number [String, nil]
  #
  #   @param qclid [String, nil]
  #
  #   @param rdt_cid [String, nil]
  #
  #   @param referrer [String, nil]
  #
  #   @param referring_domain [String, nil]
  #
  #   @param sacid [String, nil]
  #
  #   @param sccid [String, nil]
  #
  #   @param sid [String, nil]
  #
  #   @param state [String, nil]
  #
  #   @param ttclid [String, nil]
  #
  #   @param twclid [String, nil]
  #
  #   @param user_agent [String, nil]
  #
  #   @param user_agent_full_list [String, nil]
  #
  #   @param utm_campaign [String, nil]
  #
  #   @param utm_content [String, nil]
  #
  #   @param utm_medium [String, nil]
  #
  #   @param utm_name [String, nil]
  #
  #   @param utm_source [String, nil]
  #
  #   @param utm_term [String, nil]
  #
  #   @param wbraid [String, nil]
  #
  #   @param zip [String, nil]
end

Instance Attribute Details

#ad_idString?

Returns:

  • (String, nil)


98
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 98

optional :ad_id, String, nil?: true

#admitad_uidString?

Returns:

  • (String, nil)


103
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 103

optional :admitad_uid, String, nil?: true

#adset_idString?

Returns:

  • (String, nil)


108
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 108

optional :adset_id, String, nil?: true

#alartString?

Returns:

  • (String, nil)


113
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 113

optional :alart, String, nil?: true

#aleidString?

Returns:

  • (String, nil)


118
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 118

optional :aleid, String, nil?: true

#axwrtString?

Returns:

  • (String, nil)


123
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 123

optional :axwrt, String, nil?: true

#basis_cidString?

Returns:

  • (String, nil)


128
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 128

optional :basis_cid, String, nil?: true

#campaign_idString?

Returns:

  • (String, nil)


133
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 133

optional :campaign_id, String, nil?: true

#cityString?

Returns:

  • (String, nil)


138
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 138

optional :city, String, nil?: true

#clickidString?

Returns:

  • (String, nil)


143
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 143

optional :clickid, String, nil?: true

#clidString?

Returns:

  • (String, nil)


148
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 148

optional :clid, String, nil?: true

#company_nameString?

Returns:

  • (String, nil)


153
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 153

optional :company_name, String, nil?: true

Returns:

  • (Hash{Symbol=>String, nil}, nil)


158
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 158

optional :consent, OursprivacyIngest::Internal::Type::HashOf[String, nil?: true], nil?: true

#countryString?

Returns:

  • (String, nil)


163
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 163

optional :country, String, nil?: true

#custom_propertiesHash{Symbol=>String, nil}?

Returns:

  • (Hash{Symbol=>String, nil}, nil)


168
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 168

optional :custom_properties, OursprivacyIngest::Internal::Type::HashOf[String, nil?: true], nil?: true

#date_of_birthString?

Returns:

  • (String, nil)


173
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 173

optional :date_of_birth, String, nil?: true

#dclidString?

Returns:

  • (String, nil)


178
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 178

optional :dclid, String, nil?: true

#emailString?

Returns:

  • (String, nil)


183
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 183

optional :email, String, nil?: true

#epikString?

Returns:

  • (String, nil)


188
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 188

optional :epik, String, nil?: true

#external_idString?

Returns:

  • (String, nil)


193
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 193

optional :external_id, String, nil?: true

#fbcString?

Returns:

  • (String, nil)


198
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 198

optional :fbc, String, nil?: true

#fbclidString?

Returns:

  • (String, nil)


203
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 203

optional :fbclid, String, nil?: true

#fbpString?

Returns:

  • (String, nil)


208
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 208

optional :fbp, String, nil?: true

#first_nameString?

Returns:

  • (String, nil)


213
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 213

optional :first_name, String, nil?: true

#gad_sourceString?

Returns:

  • (String, nil)


218
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 218

optional :gad_source, String, nil?: true

#gbraidString?

Returns:

  • (String, nil)


223
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 223

optional :gbraid, String, nil?: true

#gclidString?

Returns:

  • (String, nil)


228
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 228

optional :gclid, String, nil?: true

#genderString?

Returns:

  • (String, nil)


233
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 233

optional :gender, String, nil?: true

#im_refString?

Returns:

  • (String, nil)


238
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 238

optional :im_ref, String, nil?: true

#ipString?

The IP address of the user

Returns:

  • (String, nil)


244
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 244

optional :ip, String, nil?: true

#irclickidString?

Returns:

  • (String, nil)


249
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 249

optional :irclickid, String, nil?: true

#is_botString?

Returns:

  • (String, nil)


254
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 254

optional :is_bot, String, nil?: true

#job_titleString?

Returns:

  • (String, nil)


259
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 259

optional :job_title, String, nil?: true

#last_nameString?

Returns:

  • (String, nil)


264
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 264

optional :last_name, String, nil?: true

#li_fat_idString?

Returns:

  • (String, nil)


269
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 269

optional :li_fat_id, String, nil?: true

#msclkidString?

Returns:

  • (String, nil)


274
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 274

optional :msclkid, String, nil?: true

#ndclidString?

Returns:

  • (String, nil)


279
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 279

optional :ndclid, String, nil?: true

#phone_numberString?

Returns:

  • (String, nil)


284
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 284

optional :phone_number, String, nil?: true

#qclidString?

Returns:

  • (String, nil)


289
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 289

optional :qclid, String, nil?: true

#rdt_cidString?

Returns:

  • (String, nil)


294
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 294

optional :rdt_cid, String, nil?: true

#referrerString?

Returns:

  • (String, nil)


299
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 299

optional :referrer, String, nil?: true

#referring_domainString?

Returns:

  • (String, nil)


304
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 304

optional :referring_domain, String, nil?: true

#sacidString?

Returns:

  • (String, nil)


309
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 309

optional :sacid, String, nil?: true

#sccidString?

Returns:

  • (String, nil)


314
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 314

optional :sccid, String, nil?: true

#sidString?

Returns:

  • (String, nil)


319
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 319

optional :sid, String, nil?: true

#stateString?

Returns:

  • (String, nil)


324
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 324

optional :state, String, nil?: true

#ttclidString?

Returns:

  • (String, nil)


329
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 329

optional :ttclid, String, nil?: true

#twclidString?

Returns:

  • (String, nil)


334
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 334

optional :twclid, String, nil?: true

#user_agentString?

Returns:

  • (String, nil)


339
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 339

optional :user_agent, String, nil?: true

#user_agent_full_listString?

Returns:

  • (String, nil)


344
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 344

optional :user_agent_full_list, String, nil?: true

#utm_campaignString?

Returns:

  • (String, nil)


349
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 349

optional :utm_campaign, String, nil?: true

#utm_contentString?

Returns:

  • (String, nil)


354
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 354

optional :utm_content, String, nil?: true

#utm_mediumString?

Returns:

  • (String, nil)


359
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 359

optional :utm_medium, String, nil?: true

#utm_nameString?

Returns:

  • (String, nil)


364
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 364

optional :utm_name, String, nil?: true

#utm_sourceString?

Returns:

  • (String, nil)


369
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 369

optional :utm_source, String, nil?: true

#utm_termString?

Returns:

  • (String, nil)


374
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 374

optional :utm_term, String, nil?: true

#wbraidString?

Returns:

  • (String, nil)


379
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 379

optional :wbraid, String, nil?: true

#zipString?

Returns:

  • (String, nil)


384
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 384

optional :zip, String, nil?: true