Class: OursprivacyIngest::Models::BatchCreateParams::Event::DefaultProperties

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/oursprivacy_ingest/models/batch_create_params.rb

Overview

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from OursprivacyIngest::Internal::Type::BaseModel

Instance Attribute Details

#_ef_transaction_idString?

The Everflow affiliate Click (Transaction) ID, captured from the ‘_ef_transaction_id` URL parameter. Ex: ef_click_abc123

Returns:

  • (String, nil)


152
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 152

optional :_ef_transaction_id, String, nil?: true

#active_durationFloat?

The active time in milliseconds that the user had this tab active

Returns:

  • (Float, nil)


158
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 158

optional :active_duration, Float, api_name: :activeDuration, nil?: true

#ad_idString?

The ad id for detected in the session. This is set by the web sdk automatically.

Returns:

  • (String, nil)


164
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 164

optional :ad_id, String, nil?: true

#admitad_uidString?

The Admitad (Mitgo) affiliate Click ID. Ex: admitad_uid_abc123

Returns:

  • (String, nil)


170
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 170

optional :admitad_uid, String, nil?: true

#adset_idString?

The adset id for detected in the session. This is set by the web sdk automatically.

Returns:

  • (String, nil)


177
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 177

optional :adset_id, String, nil?: true

#alartString?

The AppLovin alart query parameter. Ex: alart123

Returns:

  • (String, nil)


183
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 183

optional :alart, String, nil?: true

#aleidString?

The AppLovin aleid query parameter. Ex: aleid123

Returns:

  • (String, nil)


189
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 189

optional :aleid, String, nil?: true

#axwrtString?

The AppLovin Axon pixel cookie value (_axwrt). Web-only.

Returns:

  • (String, nil)


195
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 195

optional :axwrt, String, nil?: true

#basis_cidString?

The Basis DSP Click ID. Ex: basis_cid123

Returns:

  • (String, nil)


201
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 201

optional :basis_cid, String, nil?: true

#beeswax_auction_idString?

The Beeswax (FreeWheel Buyer Cloud) auction ID, captured from the ‘{AUCTION_ID}` macro on creative click URLs. Ex: bx-auc-abc123

Returns:

  • (String, nil)


208
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 208

optional :beeswax_auction_id, String, nil?: true

#browser_languageString?

The language of the browser. Ex: en-US

Returns:

  • (String, nil)


214
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 214

optional :browser_language, String, nil?: true

#browser_nameString?

The name of the browser. Ex: Chrome

Returns:

  • (String, nil)


220
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 220

optional :browser_name, String, nil?: true

#browser_versionString?

The version of the browser. Ex: 114.0

Returns:

  • (String, nil)


226
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 226

optional :browser_version, String, nil?: true

#campaign_idString?

The campaign id for detected in the session. This is set by the web sdk automatically.

Returns:

  • (String, nil)


233
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 233

optional :campaign_id, String, nil?: true

#clickidString?

The Click ID. Ex: clickid123

Returns:

  • (String, nil)


239
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 239

optional :clickid, String, nil?: true

#clidString?

The Generic Click ID. Ex: clid123

Returns:

  • (String, nil)


245
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 245

optional :clid, String, nil?: true

#cpu_architectureString?

The architecture of the CPU. Ex: x64

Returns:

  • (String, nil)


251
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 251

optional :cpu_architecture, String, nil?: true

#current_urlString?

The full url (including query params) of the current page

Returns:

  • (String, nil)


257
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 257

optional :current_url, String, nil?: true

#dclidString?

The DoubleClick Click ID. Ex: dclid123

Returns:

  • (String, nil)


263
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 263

optional :dclid, String, nil?: true

#device_modelString?

The model of the device. Ex: iPhone 13

Returns:

  • (String, nil)


269
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 269

optional :device_model, String, nil?: true

#device_typeString?

The type of device the user is using. Ex: mobile

Returns:

  • (String, nil)


275
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 275

optional :device_type, String, nil?: true

#device_vendorString?

The vendor of the device. Ex: Apple

Returns:

  • (String, nil)


281
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 281

optional :device_vendor, String, nil?: true

#durationFloat?

The time in milliseconds since the page was loaded // script was loaded

Returns:

  • (Float, nil)


287
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 287

optional :duration, Float, nil?: true

#encodingString?

The browsers encoding. Ex: UTF-8

Returns:

  • (String, nil)


293
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 293

optional :encoding, String, nil?: true

#engine_nameString?

The name of the browser engine. Ex: Blink

Returns:

  • (String, nil)


299
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 299

optional :engine_name, String, nil?: true

#engine_versionString?

The version of the browser engine. Ex: 114.0

Returns:

  • (String, nil)


305
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 305

optional :engine_version, String, nil?: true

#epikString?

The Pinterest Click ID. Ex: epik456

Returns:

  • (String, nil)


311
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 311

optional :epik, String, nil?: true

#fbcString?

Facebook Click ID with prefix format for Conversions API tracking. Ex: fb.1.1554763741205.AbCdEfGhIjKlMnOpQrStUvWxYz1234567890

Returns:

  • (String, nil)


318
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 318

optional :fbc, String, nil?: true

#fbclidString?

Raw Facebook Click ID query parameter without prefix from ad clicks. Ex: AbCdEfGhIjKlMnOpQrStUvWxYz1234567890

Returns:

  • (String, nil)


325
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 325

optional :fbclid, String, nil?: true

#fbpString?

Facebook Browser ID parameter for identifying browsers and attributing events. Ex: fb.1.1554763741205.1098115397

Returns:

  • (String, nil)


332
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 332

optional :fbp, String, nil?: true

#fvBoolean?

Deprecated

Returns:

  • (Boolean, nil)


338
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 338

optional :fv, OursprivacyIngest::Internal::Type::Boolean, nil?: true

#gad_sourceString?

The Google Ad Source. Ex: google

Returns:

  • (String, nil)


344
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 344

optional :gad_source, String, nil?: true

#gbraidString?

The Google Braid ID. Ex: gbraid123

Returns:

  • (String, nil)


350
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 350

optional :gbraid, String, nil?: true

#gclidString?

The Google Click ID. Ex: gclid123

Returns:

  • (String, nil)


356
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 356

optional :gclid, String, nil?: true

#hostString?

The host of the current page. Ex: example.com

Returns:

  • (String, nil)


362
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 362

optional :host, String, nil?: true

#iframeBoolean?

Whether the user is in an iframe. Ex: true

Returns:

  • (Boolean, nil)


368
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 368

optional :iframe, OursprivacyIngest::Internal::Type::Boolean, nil?: true

#im_refString?

The Impact Click ID reference. Ex: im_ref123

Returns:

  • (String, nil)


374
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 374

optional :im_ref, String, nil?: true

#ipString?

The IP address of the user. Ex: 127.0.0.1

Returns:

  • (String, nil)


380
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 380

optional :ip, String, nil?: true

#irclickidString?

The Impact Click ID. Ex: irclickid123

Returns:

  • (String, nil)


386
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 386

optional :irclickid, String, nil?: true

#is_botString?

Whether we have detected that the user is a bot. This is set automatically by the Ours server primarily for events tracked through the web SDK.

Returns:

  • (String, nil)


393
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 393

optional :is_bot, String, nil?: true

#li_fat_idString?

The LinkedIn Click ID. Ex: li_fat_id123

Returns:

  • (String, nil)


399
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 399

optional :li_fat_id, String, nil?: true

#msclkidString?

The Microsoft Click ID. Ex: msclkid123

Returns:

  • (String, nil)


405
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 405

optional :msclkid, String, nil?: true

#ndclidString?

The NextDoor Click ID. Ex: ndclid123

Returns:

  • (String, nil)


411
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 411

optional :ndclid, String, nil?: true

#new_sBoolean?

Deprecated

Returns:

  • (Boolean, nil)


417
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 417

optional :new_s, OursprivacyIngest::Internal::Type::Boolean, nil?: true

#opprefString?

The OpenAI Ads privacy-preserving reference, captured from the ‘oppref` URL parameter on landing pages (the OpenAI Pixel also stores it in a `__oppref` cookie). Sent to OpenAI Ads on Conversions API events for attribution. Ex: oppref_abc

Returns:

  • (String, nil)


426
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 426

optional :oppref, String, nil?: true

#os_nameString?

The name of the operating system. Ex: Windows

Returns:

  • (String, nil)


432
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 432

optional :os_name, String, nil?: true

#os_versionString?

The version of the operating system. Ex: 10.0

Returns:

  • (String, nil)


438
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 438

optional :os_version, String, nil?: true

#page_hashFloat?

A random set of numbers for the page load

Returns:

  • (Float, nil)


444
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 444

optional :page_hash, Float, nil?: true

#pathnameString?

The pathname of the current page. Ex: /home

Returns:

  • (String, nil)


450
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 450

optional :pathname, String, nil?: true

#qclidString?

The Quora Click ID. Ex: qclid123

Returns:

  • (String, nil)


456
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 456

optional :qclid, String, nil?: true

#rdt_cidString?

The Reddit Click ID. Ex: rdt_cid123

Returns:

  • (String, nil)


462
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 462

optional :rdt_cid, String, nil?: true

#received_atString?

The time the event was received by an Ours server in ISO format

Returns:

  • (String, nil)


468
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 468

optional :received_at, String, nil?: true

#referrerString?

The referrer URL of the current page

Returns:

  • (String, nil)


474
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 474

optional :referrer, String, nil?: true

#referring_domainString?

The referring domain of the current page

Returns:

  • (String, nil)


480
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 480

optional :referring_domain, String, nil?: true

#sacidString?

The StackAdapt Tracking ID. Ex: sacid123

Returns:

  • (String, nil)


486
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 486

optional :sacid, String, nil?: true

#sccidString?

The SnapChat Click ID. Ex: sccid123

Returns:

  • (String, nil)


492
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 492

optional :sccid, String, nil?: true

#screen_heightFloat?

The height of the screen. Ex: 1080

Returns:

  • (Float, nil)


498
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 498

optional :screen_height, Float, nil?: true

#screen_widthFloat?

The width of the screen. Ex: 1920

Returns:

  • (Float, nil)


504
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 504

optional :screen_width, Float, nil?: true

#session_countFloat?

The number of sessions the user has had. Ex: 3

Returns:

  • (Float, nil)


510
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 510

optional :session_count, Float, api_name: :sessionCount, nil?: true

#sidString?

The session ID as assigned automatically by the web SDK. This is required for session replay

Returns:

  • (String, nil)


517
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 517

optional :sid, String, nil?: true

#srString?

Returns:

  • (String, nil)


522
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 522

optional :sr, String, nil?: true

#titleString?

The title of the current page

Returns:

  • (String, nil)


528
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 528

optional :title, String, nil?: true

#ttclidString?

The TikTok Click ID. Ex: ttclid123

Returns:

  • (String, nil)


534
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 534

optional :ttclid, String, nil?: true

#twclidString?

The Twitter Click ID. Ex: twclid123

Returns:

  • (String, nil)


540
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 540

optional :twclid, String, nil?: true

#uafvlString?

User agent as a full list of strings.

Returns:

  • (String, nil)


546
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 546

optional :uafvl, String, nil?: true

#user_agentString?

The user agent of the browser

Returns:

  • (String, nil)


552
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 552

optional :user_agent, String, nil?: true

#utm_campaignString?

The UTM Campaign. The web SDK automatically captures this from the query params.

Returns:

  • (String, nil)


558
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 558

optional :utm_campaign, String, nil?: true

#utm_contentString?

The UTM Content. The web SDK automatically captures this from the query params.

Returns:

  • (String, nil)


564
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 564

optional :utm_content, String, nil?: true

#utm_mediumString?

The UTM Medium. The web SDK automatically captures this from the query params.

Returns:

  • (String, nil)


570
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 570

optional :utm_medium, String, nil?: true

#utm_nameString?

The UTM Name. The web SDK automatically captures this from the query params.

Returns:

  • (String, nil)


576
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 576

optional :utm_name, String, nil?: true

#utm_sourceString?

The UTM Source. The web SDK automatically captures this from the query params.

Returns:

  • (String, nil)


582
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 582

optional :utm_source, String, nil?: true

#utm_termString?

The UTM Term. The web SDK automatically captures this from the query params.

Returns:

  • (String, nil)


588
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 588

optional :utm_term, String, nil?: true

#versionString?

The version of the web SDK

Returns:

  • (String, nil)


594
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 594

optional :version, String, nil?: true

#viant_click_idString?

The Viant (Adelphic) Click ID, captured from the ‘viant_click_id` URL parameter (Viant `$ADELPHIC_CLICKID` macro). Sent as `xid` on Viant postbacks. Ex: viant_click_abc123

Returns:

  • (String, nil)


602
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 602

optional :viant_click_id, String, nil?: true

#viant_impression_idString?

The Viant (Adelphic) Impression ID, captured from the ‘viant_impression_id` URL parameter (Viant `$ADELPHIC_IMPRESSIONID` macro). Sent as `imp_id` on Viant postbacks for post-view attribution. Ex: viant_imp_abc123

Returns:

  • (String, nil)


610
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 610

optional :viant_impression_id, String, nil?: true

#wbraidString?

The WBRAID Identifier. The web SDK automatically captures this from the query params.

Returns:

  • (String, nil)


617
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 617

optional :wbraid, String, nil?: true

#webviewBoolean?

Whether the user is in a webview. Ex: true

Returns:

  • (Boolean, nil)


623
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 623

optional :webview, OursprivacyIngest::Internal::Type::Boolean, nil?: true