Class: OursprivacyIngest::Models::BatchCreateParams::Event::DefaultProperties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OursprivacyIngest::Models::BatchCreateParams::Event::DefaultProperties
- Defined in:
- lib/oursprivacy_ingest/models/batch_create_params.rb
Overview
Instance Attribute Summary collapse
-
#_ef_transaction_id ⇒ String?
The Everflow affiliate Click (Transaction) ID, captured from the ‘_ef_transaction_id` URL parameter.
-
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active.
-
#ad_id ⇒ String?
The ad id for detected in the session.
-
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID.
-
#adset_id ⇒ String?
The adset id for detected in the session.
-
#alart ⇒ String?
The AppLovin alart query parameter.
-
#aleid ⇒ String?
The AppLovin aleid query parameter.
-
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt).
-
#basis_cid ⇒ String?
The Basis DSP Click ID.
-
#beeswax_auction_id ⇒ String?
The Beeswax (FreeWheel Buyer Cloud) auction ID, captured from the ‘{AUCTION_ID}` macro on creative click URLs.
-
#browser_language ⇒ String?
The language of the browser.
-
#browser_name ⇒ String?
The name of the browser.
-
#browser_version ⇒ String?
The version of the browser.
-
#campaign_id ⇒ String?
The campaign id for detected in the session.
-
#clickid ⇒ String?
The Click ID.
-
#clid ⇒ String?
The Generic Click ID.
-
#cpu_architecture ⇒ String?
The architecture of the CPU.
-
#current_url ⇒ String?
The full url (including query params) of the current page.
-
#dclid ⇒ String?
The DoubleClick Click ID.
-
#device_model ⇒ String?
The model of the device.
-
#device_type ⇒ String?
The type of device the user is using.
-
#device_vendor ⇒ String?
The vendor of the device.
-
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded.
-
#encoding ⇒ String?
The browsers encoding.
-
#engine_name ⇒ String?
The name of the browser engine.
-
#engine_version ⇒ String?
The version of the browser engine.
-
#epik ⇒ String?
The Pinterest Click ID.
-
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking.
-
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks.
-
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events.
-
#fv ⇒ Boolean?
Deprecated.
-
#gad_source ⇒ String?
The Google Ad Source.
-
#gbraid ⇒ String?
The Google Braid ID.
-
#gclid ⇒ String?
The Google Click ID.
-
#host ⇒ String?
The host of the current page.
-
#iframe ⇒ Boolean?
Whether the user is in an iframe.
-
#im_ref ⇒ String?
The Impact Click ID reference.
-
#ip ⇒ String?
The IP address of the user.
-
#irclickid ⇒ String?
The Impact Click ID.
-
#is_bot ⇒ String?
Whether we have detected that the user is a bot.
-
#li_fat_id ⇒ String?
The LinkedIn Click ID.
-
#msclkid ⇒ String?
The Microsoft Click ID.
-
#ndclid ⇒ String?
The NextDoor Click ID.
-
#new_s ⇒ Boolean?
Deprecated.
-
#os_name ⇒ String?
The name of the operating system.
-
#os_version ⇒ String?
The version of the operating system.
-
#page_hash ⇒ Float?
A random set of numbers for the page load.
-
#pathname ⇒ String?
The pathname of the current page.
-
#qclid ⇒ String?
The Quora Click ID.
-
#rdt_cid ⇒ String?
The Reddit Click ID.
-
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format.
-
#referrer ⇒ String?
The referrer URL of the current page.
-
#referring_domain ⇒ String?
The referring domain of the current page.
-
#sacid ⇒ String?
The StackAdapt Tracking ID.
-
#sccid ⇒ String?
The SnapChat Click ID.
-
#screen_height ⇒ Float?
The height of the screen.
-
#screen_width ⇒ Float?
The width of the screen.
-
#session_count ⇒ Float?
The number of sessions the user has had.
-
#sid ⇒ String?
The session ID as assigned automatically by the web SDK.
- #sr ⇒ String?
-
#title ⇒ String?
The title of the current page.
-
#ttclid ⇒ String?
The TikTok Click ID.
-
#twclid ⇒ String?
The Twitter Click ID.
-
#uafvl ⇒ String?
User agent as a full list of strings.
-
#user_agent ⇒ String?
The user agent of the browser.
-
#utm_campaign ⇒ String?
The UTM Campaign.
-
#utm_content ⇒ String?
The UTM Content.
-
#utm_medium ⇒ String?
The UTM Medium.
-
#utm_name ⇒ String?
The UTM Name.
-
#utm_source ⇒ String?
The UTM Source.
-
#utm_term ⇒ String?
The UTM Term.
-
#version ⇒ String?
The version of the web SDK.
-
#wbraid ⇒ String?
The WBRAID Identifier.
-
#webview ⇒ Boolean?
Whether the user is in a webview.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OursprivacyIngest::Internal::Type::BaseModel
Instance Attribute Details
#_ef_transaction_id ⇒ String?
The Everflow affiliate Click (Transaction) ID, captured from the ‘_ef_transaction_id` URL parameter. Ex: ef_click_abc123
152 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 152 optional :_ef_transaction_id, String, nil?: true |
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active
158 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 158 optional :active_duration, Float, api_name: :activeDuration, nil?: true |
#ad_id ⇒ String?
The ad id for detected in the session. This is set by the web sdk automatically.
164 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 164 optional :ad_id, String, nil?: true |
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID. Ex: admitad_uid_abc123
170 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 170 optional :admitad_uid, String, nil?: true |
#adset_id ⇒ String?
The adset id for detected in the session. This is set by the web sdk automatically.
177 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 177 optional :adset_id, String, nil?: true |
#alart ⇒ String?
The AppLovin alart query parameter. Ex: alart123
183 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 183 optional :alart, String, nil?: true |
#aleid ⇒ String?
The AppLovin aleid query parameter. Ex: aleid123
189 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 189 optional :aleid, String, nil?: true |
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt). Web-only.
195 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 195 optional :axwrt, String, nil?: true |
#basis_cid ⇒ String?
The Basis DSP Click ID. Ex: basis_cid123
201 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 201 optional :basis_cid, String, nil?: true |
#beeswax_auction_id ⇒ String?
The Beeswax (FreeWheel Buyer Cloud) auction ID, captured from the ‘{AUCTION_ID}` macro on creative click URLs. Ex: bx-auc-abc123
208 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 208 optional :beeswax_auction_id, String, nil?: true |
#browser_language ⇒ String?
The language of the browser. Ex: en-US
214 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 214 optional :browser_language, String, nil?: true |
#browser_name ⇒ String?
The name of the browser. Ex: Chrome
220 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 220 optional :browser_name, String, nil?: true |
#browser_version ⇒ String?
The version of the browser. Ex: 114.0
226 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 226 optional :browser_version, String, nil?: true |
#campaign_id ⇒ String?
The campaign id for detected in the session. This is set by the web sdk automatically.
233 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 233 optional :campaign_id, String, nil?: true |
#clickid ⇒ String?
The Click ID. Ex: clickid123
239 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 239 optional :clickid, String, nil?: true |
#clid ⇒ String?
The Generic Click ID. Ex: clid123
245 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 245 optional :clid, String, nil?: true |
#cpu_architecture ⇒ String?
The architecture of the CPU. Ex: x64
251 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 251 optional :cpu_architecture, String, nil?: true |
#current_url ⇒ String?
The full url (including query params) of the current page
257 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 257 optional :current_url, String, nil?: true |
#dclid ⇒ String?
The DoubleClick Click ID. Ex: dclid123
263 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 263 optional :dclid, String, nil?: true |
#device_model ⇒ String?
The model of the device. Ex: iPhone 13
269 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 269 optional :device_model, String, nil?: true |
#device_type ⇒ String?
The type of device the user is using. Ex: mobile
275 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 275 optional :device_type, String, nil?: true |
#device_vendor ⇒ String?
The vendor of the device. Ex: Apple
281 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 281 optional :device_vendor, String, nil?: true |
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded
287 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 287 optional :duration, Float, nil?: true |
#encoding ⇒ String?
The browsers encoding. Ex: UTF-8
293 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 293 optional :encoding, String, nil?: true |
#engine_name ⇒ String?
The name of the browser engine. Ex: Blink
299 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 299 optional :engine_name, String, nil?: true |
#engine_version ⇒ String?
The version of the browser engine. Ex: 114.0
305 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 305 optional :engine_version, String, nil?: true |
#epik ⇒ String?
The Pinterest Click ID. Ex: epik456
311 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 311 optional :epik, String, nil?: true |
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking. Ex: fb.1.1554763741205.AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
318 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 318 optional :fbc, String, nil?: true |
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks. Ex: AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
325 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 325 optional :fbclid, String, nil?: true |
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events. Ex: fb.1.1554763741205.1098115397
332 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 332 optional :fbp, String, nil?: true |
#fv ⇒ Boolean?
Deprecated
338 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 338 optional :fv, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#gad_source ⇒ String?
The Google Ad Source. Ex: google
344 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 344 optional :gad_source, String, nil?: true |
#gbraid ⇒ String?
The Google Braid ID. Ex: gbraid123
350 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 350 optional :gbraid, String, nil?: true |
#gclid ⇒ String?
The Google Click ID. Ex: gclid123
356 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 356 optional :gclid, String, nil?: true |
#host ⇒ String?
The host of the current page. Ex: example.com
362 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 362 optional :host, String, nil?: true |
#iframe ⇒ Boolean?
Whether the user is in an iframe. Ex: true
368 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 368 optional :iframe, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#im_ref ⇒ String?
The Impact Click ID reference. Ex: im_ref123
374 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 374 optional :im_ref, String, nil?: true |
#ip ⇒ String?
The IP address of the user. Ex: 127.0.0.1
380 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 380 optional :ip, String, nil?: true |
#irclickid ⇒ String?
The Impact Click ID. Ex: irclickid123
386 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 386 optional :irclickid, String, nil?: true |
#is_bot ⇒ String?
Whether we have detected that the user is a bot. This is set automatically by the Ours server primarily for events tracked through the web SDK.
393 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 393 optional :is_bot, String, nil?: true |
#li_fat_id ⇒ String?
The LinkedIn Click ID. Ex: li_fat_id123
399 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 399 optional :li_fat_id, String, nil?: true |
#msclkid ⇒ String?
The Microsoft Click ID. Ex: msclkid123
405 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 405 optional :msclkid, String, nil?: true |
#ndclid ⇒ String?
The NextDoor Click ID. Ex: ndclid123
411 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 411 optional :ndclid, String, nil?: true |
#new_s ⇒ Boolean?
Deprecated
417 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 417 optional :new_s, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#os_name ⇒ String?
The name of the operating system. Ex: Windows
423 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 423 optional :os_name, String, nil?: true |
#os_version ⇒ String?
The version of the operating system. Ex: 10.0
429 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 429 optional :os_version, String, nil?: true |
#page_hash ⇒ Float?
A random set of numbers for the page load
435 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 435 optional :page_hash, Float, nil?: true |
#pathname ⇒ String?
The pathname of the current page. Ex: /home
441 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 441 optional :pathname, String, nil?: true |
#qclid ⇒ String?
The Quora Click ID. Ex: qclid123
447 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 447 optional :qclid, String, nil?: true |
#rdt_cid ⇒ String?
The Reddit Click ID. Ex: rdt_cid123
453 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 453 optional :rdt_cid, String, nil?: true |
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format
459 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 459 optional :received_at, String, nil?: true |
#referrer ⇒ String?
The referrer URL of the current page
465 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 465 optional :referrer, String, nil?: true |
#referring_domain ⇒ String?
The referring domain of the current page
471 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 471 optional :referring_domain, String, nil?: true |
#sacid ⇒ String?
The StackAdapt Tracking ID. Ex: sacid123
477 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 477 optional :sacid, String, nil?: true |
#sccid ⇒ String?
The SnapChat Click ID. Ex: sccid123
483 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 483 optional :sccid, String, nil?: true |
#screen_height ⇒ Float?
The height of the screen. Ex: 1080
489 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 489 optional :screen_height, Float, nil?: true |
#screen_width ⇒ Float?
The width of the screen. Ex: 1920
495 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 495 optional :screen_width, Float, nil?: true |
#session_count ⇒ Float?
The number of sessions the user has had. Ex: 3
501 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 501 optional :session_count, Float, api_name: :sessionCount, nil?: true |
#sid ⇒ String?
The session ID as assigned automatically by the web SDK. This is required for session replay
508 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 508 optional :sid, String, nil?: true |
#sr ⇒ String?
513 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 513 optional :sr, String, nil?: true |
#title ⇒ String?
The title of the current page
519 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 519 optional :title, String, nil?: true |
#ttclid ⇒ String?
The TikTok Click ID. Ex: ttclid123
525 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 525 optional :ttclid, String, nil?: true |
#twclid ⇒ String?
The Twitter Click ID. Ex: twclid123
531 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 531 optional :twclid, String, nil?: true |
#uafvl ⇒ String?
User agent as a full list of strings.
537 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 537 optional :uafvl, String, nil?: true |
#user_agent ⇒ String?
The user agent of the browser
543 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 543 optional :user_agent, String, nil?: true |
#utm_campaign ⇒ String?
The UTM Campaign. The web SDK automatically captures this from the query params.
549 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 549 optional :utm_campaign, String, nil?: true |
#utm_content ⇒ String?
The UTM Content. The web SDK automatically captures this from the query params.
555 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 555 optional :utm_content, String, nil?: true |
#utm_medium ⇒ String?
The UTM Medium. The web SDK automatically captures this from the query params.
561 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 561 optional :utm_medium, String, nil?: true |
#utm_name ⇒ String?
The UTM Name. The web SDK automatically captures this from the query params.
567 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 567 optional :utm_name, String, nil?: true |
#utm_source ⇒ String?
The UTM Source. The web SDK automatically captures this from the query params.
573 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 573 optional :utm_source, String, nil?: true |
#utm_term ⇒ String?
The UTM Term. The web SDK automatically captures this from the query params.
579 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 579 optional :utm_term, String, nil?: true |
#version ⇒ String?
The version of the web SDK
585 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 585 optional :version, String, nil?: true |
#wbraid ⇒ String?
The WBRAID Identifier. The web SDK automatically captures this from the query params.
592 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 592 optional :wbraid, String, nil?: true |
#webview ⇒ Boolean?
Whether the user is in a webview. Ex: true
598 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 598 optional :webview, OursprivacyIngest::Internal::Type::Boolean, nil?: true |