Class: OursprivacyIngest::Models::BatchCreateParams::Event::DefaultProperties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OursprivacyIngest::Models::BatchCreateParams::Event::DefaultProperties
- Defined in:
- lib/oursprivacy_ingest/models/batch_create_params.rb
Overview
Instance Attribute Summary collapse
-
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active.
-
#ad_id ⇒ String?
The ad id for detected in the session.
-
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID.
-
#adset_id ⇒ String?
The adset id for detected in the session.
-
#alart ⇒ String?
The AppLovin alart query parameter.
-
#aleid ⇒ String?
The AppLovin aleid query parameter.
-
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt).
-
#basis_cid ⇒ String?
The Basis DSP Click ID.
-
#browser_language ⇒ String?
The language of the browser.
-
#browser_name ⇒ String?
The name of the browser.
-
#browser_version ⇒ String?
The version of the browser.
-
#campaign_id ⇒ String?
The campaign id for detected in the session.
-
#clickid ⇒ String?
The Click ID.
-
#clid ⇒ String?
The Generic Click ID.
-
#cpu_architecture ⇒ String?
The architecture of the CPU.
-
#current_url ⇒ String?
The full url (including query params) of the current page.
-
#dclid ⇒ String?
The DoubleClick Click ID.
-
#device_model ⇒ String?
The model of the device.
-
#device_type ⇒ String?
The type of device the user is using.
-
#device_vendor ⇒ String?
The vendor of the device.
-
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded.
-
#encoding ⇒ String?
The browsers encoding.
-
#engine_name ⇒ String?
The name of the browser engine.
-
#engine_version ⇒ String?
The version of the browser engine.
-
#epik ⇒ String?
The Pinterest Click ID.
-
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking.
-
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks.
-
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events.
-
#fv ⇒ Boolean?
Deprecated.
-
#gad_source ⇒ String?
The Google Ad Source.
-
#gbraid ⇒ String?
The Google Braid ID.
-
#gclid ⇒ String?
The Google Click ID.
-
#host ⇒ String?
The host of the current page.
-
#iframe ⇒ Boolean?
Whether the user is in an iframe.
-
#im_ref ⇒ String?
The Impact Click ID reference.
-
#ip ⇒ String?
The IP address of the user.
-
#irclickid ⇒ String?
The Impact Click ID.
-
#is_bot ⇒ String?
Whether we have detected that the user is a bot.
-
#li_fat_id ⇒ String?
The LinkedIn Click ID.
-
#msclkid ⇒ String?
The Microsoft Click ID.
-
#ndclid ⇒ String?
The NextDoor Click ID.
-
#new_s ⇒ Boolean?
Deprecated.
-
#os_name ⇒ String?
The name of the operating system.
-
#os_version ⇒ String?
The version of the operating system.
-
#page_hash ⇒ Float?
A random set of numbers for the page load.
-
#pathname ⇒ String?
The pathname of the current page.
-
#qclid ⇒ String?
The Quora Click ID.
-
#rdt_cid ⇒ String?
The Reddit Click ID.
-
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format.
-
#referrer ⇒ String?
The referrer URL of the current page.
-
#referring_domain ⇒ String?
The referring domain of the current page.
-
#sacid ⇒ String?
The StackAdapt Tracking ID.
-
#sccid ⇒ String?
The SnapChat Click ID.
-
#screen_height ⇒ Float?
The height of the screen.
-
#screen_width ⇒ Float?
The width of the screen.
-
#session_count ⇒ Float?
The number of sessions the user has had.
-
#sid ⇒ String?
The session ID as assigned automatically by the web SDK.
- #sr ⇒ String?
-
#title ⇒ String?
The title of the current page.
-
#ttclid ⇒ String?
The TikTok Click ID.
-
#twclid ⇒ String?
The Twitter Click ID.
-
#uafvl ⇒ String?
User agent as a full list of strings.
-
#user_agent ⇒ String?
The user agent of the browser.
-
#utm_campaign ⇒ String?
The UTM Campaign.
-
#utm_content ⇒ String?
The UTM Content.
-
#utm_medium ⇒ String?
The UTM Medium.
-
#utm_name ⇒ String?
The UTM Name.
-
#utm_source ⇒ String?
The UTM Source.
-
#utm_term ⇒ String?
The UTM Term.
-
#version ⇒ String?
The version of the web SDK.
-
#wbraid ⇒ String?
The WBRAID Identifier.
-
#webview ⇒ Boolean?
Whether the user is in a webview.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OursprivacyIngest::Internal::Type::BaseModel
Instance Attribute Details
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active
151 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 151 optional :active_duration, Float, api_name: :activeDuration, nil?: true |
#ad_id ⇒ String?
The ad id for detected in the session. This is set by the web sdk automatically.
157 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 157 optional :ad_id, String, nil?: true |
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID. Ex: admitad_uid_abc123
163 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 163 optional :admitad_uid, String, nil?: true |
#adset_id ⇒ String?
The adset id for detected in the session. This is set by the web sdk automatically.
170 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 170 optional :adset_id, String, nil?: true |
#alart ⇒ String?
The AppLovin alart query parameter. Ex: alart123
176 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 176 optional :alart, String, nil?: true |
#aleid ⇒ String?
The AppLovin aleid query parameter. Ex: aleid123
182 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 182 optional :aleid, String, nil?: true |
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt). Web-only.
188 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 188 optional :axwrt, String, nil?: true |
#basis_cid ⇒ String?
The Basis DSP Click ID. Ex: basis_cid123
194 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 194 optional :basis_cid, String, nil?: true |
#browser_language ⇒ String?
The language of the browser. Ex: en-US
200 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 200 optional :browser_language, String, nil?: true |
#browser_name ⇒ String?
The name of the browser. Ex: Chrome
206 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 206 optional :browser_name, String, nil?: true |
#browser_version ⇒ String?
The version of the browser. Ex: 114.0
212 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 212 optional :browser_version, String, nil?: true |
#campaign_id ⇒ String?
The campaign id for detected in the session. This is set by the web sdk automatically.
219 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 219 optional :campaign_id, String, nil?: true |
#clickid ⇒ String?
The Click ID. Ex: clickid123
225 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 225 optional :clickid, String, nil?: true |
#clid ⇒ String?
The Generic Click ID. Ex: clid123
231 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 231 optional :clid, String, nil?: true |
#cpu_architecture ⇒ String?
The architecture of the CPU. Ex: x64
237 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 237 optional :cpu_architecture, String, nil?: true |
#current_url ⇒ String?
The full url (including query params) of the current page
243 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 243 optional :current_url, String, nil?: true |
#dclid ⇒ String?
The DoubleClick Click ID. Ex: dclid123
249 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 249 optional :dclid, String, nil?: true |
#device_model ⇒ String?
The model of the device. Ex: iPhone 13
255 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 255 optional :device_model, String, nil?: true |
#device_type ⇒ String?
The type of device the user is using. Ex: mobile
261 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 261 optional :device_type, String, nil?: true |
#device_vendor ⇒ String?
The vendor of the device. Ex: Apple
267 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 267 optional :device_vendor, String, nil?: true |
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded
273 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 273 optional :duration, Float, nil?: true |
#encoding ⇒ String?
The browsers encoding. Ex: UTF-8
279 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 279 optional :encoding, String, nil?: true |
#engine_name ⇒ String?
The name of the browser engine. Ex: Blink
285 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 285 optional :engine_name, String, nil?: true |
#engine_version ⇒ String?
The version of the browser engine. Ex: 114.0
291 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 291 optional :engine_version, String, nil?: true |
#epik ⇒ String?
The Pinterest Click ID. Ex: epik456
297 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 297 optional :epik, String, nil?: true |
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking. Ex: fb.1.1554763741205.AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
304 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 304 optional :fbc, String, nil?: true |
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks. Ex: AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
311 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 311 optional :fbclid, String, nil?: true |
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events. Ex: fb.1.1554763741205.1098115397
318 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 318 optional :fbp, String, nil?: true |
#fv ⇒ Boolean?
Deprecated
324 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 324 optional :fv, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#gad_source ⇒ String?
The Google Ad Source. Ex: google
330 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 330 optional :gad_source, String, nil?: true |
#gbraid ⇒ String?
The Google Braid ID. Ex: gbraid123
336 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 336 optional :gbraid, String, nil?: true |
#gclid ⇒ String?
The Google Click ID. Ex: gclid123
342 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 342 optional :gclid, String, nil?: true |
#host ⇒ String?
The host of the current page. Ex: example.com
348 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 348 optional :host, String, nil?: true |
#iframe ⇒ Boolean?
Whether the user is in an iframe. Ex: true
354 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 354 optional :iframe, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#im_ref ⇒ String?
The Impact Click ID reference. Ex: im_ref123
360 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 360 optional :im_ref, String, nil?: true |
#ip ⇒ String?
The IP address of the user. Ex: 127.0.0.1
366 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 366 optional :ip, String, nil?: true |
#irclickid ⇒ String?
The Impact Click ID. Ex: irclickid123
372 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 372 optional :irclickid, String, nil?: true |
#is_bot ⇒ String?
Whether we have detected that the user is a bot. This is set automatically by the Ours server primarily for events tracked through the web SDK.
379 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 379 optional :is_bot, String, nil?: true |
#li_fat_id ⇒ String?
The LinkedIn Click ID. Ex: li_fat_id123
385 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 385 optional :li_fat_id, String, nil?: true |
#msclkid ⇒ String?
The Microsoft Click ID. Ex: msclkid123
391 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 391 optional :msclkid, String, nil?: true |
#ndclid ⇒ String?
The NextDoor Click ID. Ex: ndclid123
397 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 397 optional :ndclid, String, nil?: true |
#new_s ⇒ Boolean?
Deprecated
403 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 403 optional :new_s, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#os_name ⇒ String?
The name of the operating system. Ex: Windows
409 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 409 optional :os_name, String, nil?: true |
#os_version ⇒ String?
The version of the operating system. Ex: 10.0
415 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 415 optional :os_version, String, nil?: true |
#page_hash ⇒ Float?
A random set of numbers for the page load
421 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 421 optional :page_hash, Float, nil?: true |
#pathname ⇒ String?
The pathname of the current page. Ex: /home
427 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 427 optional :pathname, String, nil?: true |
#qclid ⇒ String?
The Quora Click ID. Ex: qclid123
433 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 433 optional :qclid, String, nil?: true |
#rdt_cid ⇒ String?
The Reddit Click ID. Ex: rdt_cid123
439 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 439 optional :rdt_cid, String, nil?: true |
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format
445 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 445 optional :received_at, String, nil?: true |
#referrer ⇒ String?
The referrer URL of the current page
451 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 451 optional :referrer, String, nil?: true |
#referring_domain ⇒ String?
The referring domain of the current page
457 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 457 optional :referring_domain, String, nil?: true |
#sacid ⇒ String?
The StackAdapt Tracking ID. Ex: sacid123
463 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 463 optional :sacid, String, nil?: true |
#sccid ⇒ String?
The SnapChat Click ID. Ex: sccid123
469 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 469 optional :sccid, String, nil?: true |
#screen_height ⇒ Float?
The height of the screen. Ex: 1080
475 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 475 optional :screen_height, Float, nil?: true |
#screen_width ⇒ Float?
The width of the screen. Ex: 1920
481 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 481 optional :screen_width, Float, nil?: true |
#session_count ⇒ Float?
The number of sessions the user has had. Ex: 3
487 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 487 optional :session_count, Float, api_name: :sessionCount, nil?: true |
#sid ⇒ String?
The session ID as assigned automatically by the web SDK. This is required for session replay
494 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 494 optional :sid, String, nil?: true |
#sr ⇒ String?
499 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 499 optional :sr, String, nil?: true |
#title ⇒ String?
The title of the current page
505 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 505 optional :title, String, nil?: true |
#ttclid ⇒ String?
The TikTok Click ID. Ex: ttclid123
511 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 511 optional :ttclid, String, nil?: true |
#twclid ⇒ String?
The Twitter Click ID. Ex: twclid123
517 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 517 optional :twclid, String, nil?: true |
#uafvl ⇒ String?
User agent as a full list of strings.
523 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 523 optional :uafvl, String, nil?: true |
#user_agent ⇒ String?
The user agent of the browser
529 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 529 optional :user_agent, String, nil?: true |
#utm_campaign ⇒ String?
The UTM Campaign. The web SDK automatically captures this from the query params.
535 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 535 optional :utm_campaign, String, nil?: true |
#utm_content ⇒ String?
The UTM Content. The web SDK automatically captures this from the query params.
541 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 541 optional :utm_content, String, nil?: true |
#utm_medium ⇒ String?
The UTM Medium. The web SDK automatically captures this from the query params.
547 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 547 optional :utm_medium, String, nil?: true |
#utm_name ⇒ String?
The UTM Name. The web SDK automatically captures this from the query params.
553 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 553 optional :utm_name, String, nil?: true |
#utm_source ⇒ String?
The UTM Source. The web SDK automatically captures this from the query params.
559 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 559 optional :utm_source, String, nil?: true |
#utm_term ⇒ String?
The UTM Term. The web SDK automatically captures this from the query params.
565 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 565 optional :utm_term, String, nil?: true |
#version ⇒ String?
The version of the web SDK
571 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 571 optional :version, String, nil?: true |
#wbraid ⇒ String?
The WBRAID Identifier. The web SDK automatically captures this from the query params.
578 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 578 optional :wbraid, String, nil?: true |
#webview ⇒ Boolean?
Whether the user is in a webview. Ex: true
584 |
# File 'lib/oursprivacy_ingest/models/batch_create_params.rb', line 584 optional :webview, OursprivacyIngest::Internal::Type::Boolean, nil?: true |