Class: OursprivacyIngest::Models::TrackEventParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/oursprivacy_ingest/models/track_event_params.rb

Overview

Defined Under Namespace

Classes: DefaultProperties, IdentityContext, UserProperties

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ip:, user_agent:) ⇒ Object

End-user network context for server-side calls. Required for probabilistic identity resolution when the caller is a backend server rather than an end-user browser.

Parameters:

  • ip (String)

    The end-user IP address (not the server IP).

  • user_agent (String)

    The end-user User-Agent string (not the server UA).



# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 562

Instance Attribute Details

#default_propertiesOursprivacyIngest::Models::TrackEventParams::DefaultProperties?

These properties are used throughout the Ours app to pass known values onto destinations



28
29
30
31
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 28

optional :default_properties,
-> { OursprivacyIngest::TrackEventParams::DefaultProperties },
api_name: :defaultProperties,
nil?: true

#distinct_idString?

A unique identifier for the event. This helps prevent duplicate events.

Returns:

  • (String, nil)


37
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 37

optional :distinct_id, String, api_name: :distinctId, nil?: true

#emailString?

The email address of a user. We will associate this event with the user or create a user. Used for lookup if externalId and userId are not included in the request.

Returns:

  • (String, nil)


45
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 45

optional :email, String, nil?: true

#eventString

The name of the event you’re tracking. This must be whitelisted in the Ours dashboard.

Returns:

  • (String)


21
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 21

required :event, String

#event_propertiesHash{Symbol=>String, nil}?

Any additional event properties you want to pass along.

Returns:

  • (Hash{Symbol=>String, nil}, nil)


51
52
53
54
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 51

optional :event_properties,
OursprivacyIngest::Internal::Type::HashOf[String, nil?: true],
api_name: :eventProperties,
nil?: true

#external_idString?

The externalId (the ID in your system) of a user. We will associate this event with the user or create a user. If included in the request, email lookup is ignored.

Returns:

  • (String, nil)


62
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 62

optional :external_id, String, api_name: :externalId, nil?: true

#identity_contextOursprivacyIngest::Models::TrackEventParams::IdentityContext?

End-user network context for server-side calls. Required for probabilistic identity resolution when the caller is a backend server rather than an end-user browser.



70
71
72
73
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 70

optional :identity_context,
-> { OursprivacyIngest::TrackEventParams::IdentityContext },
api_name: :identityContext,
nil?: true

#timeFloat?

The time at which the event occurred in milliseconds since UTC epoch. The time must be in the past and within the last 7 days.

Returns:

  • (Float, nil)


80
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 80

optional :time, Float, nil?: true

#tokenString

The token for your Source. You can find this in the dashboard.

Returns:

  • (String)


14
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 14

required :token, String

#user_idString?

The Ours user id stored in local storage and cookies on your web properties. If userId is included in the request, we do not lookup the user by email or externalId.

Returns:

  • (String, nil)


88
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 88

optional :user_id, String, api_name: :userId, nil?: true

#user_propertiesOursprivacyIngest::Models::TrackEventParams::UserProperties?

Properties to set on the visitor. (optional) You can also update these properties via the identify endpoint.



95
96
97
98
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 95

optional :user_properties,
-> { OursprivacyIngest::TrackEventParams::UserProperties },
api_name: :userProperties,
nil?: true