Class: OursprivacyIngest::Models::TrackEventParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OursprivacyIngest::Models::TrackEventParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/oursprivacy_ingest/models/track_event_params.rb
Overview
Defined Under Namespace
Classes: DefaultProperties, IdentityContext, UserProperties
Instance Attribute Summary collapse
-
#default_properties ⇒ OursprivacyIngest::Models::TrackEventParams::DefaultProperties?
These properties are used throughout the Ours app to pass known values onto destinations.
-
#distinct_id ⇒ String?
A unique identifier for the event.
-
#email ⇒ String?
The email address of a user.
-
#event ⇒ String
The name of the event you’re tracking.
-
#event_properties ⇒ Hash{Symbol=>String, nil}?
Any additional event properties you want to pass along.
-
#external_id ⇒ String?
The externalId (the ID in your system) of a user.
-
#identity_context ⇒ OursprivacyIngest::Models::TrackEventParams::IdentityContext?
End-user network context for server-side calls.
-
#time ⇒ Float?
The time at which the event occurred in milliseconds since UTC epoch.
-
#token ⇒ String
The token for your Source.
-
#user_id ⇒ String?
The Ours user id stored in local storage and cookies on your web properties.
-
#user_properties ⇒ OursprivacyIngest::Models::TrackEventParams::UserProperties?
Properties to set on the visitor.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(ip:, user_agent:) ⇒ Object
constructor
End-user network context for server-side calls.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ip:, user_agent:) ⇒ Object
End-user network context for server-side calls. Required for probabilistic identity resolution when the caller is a backend server rather than an end-user browser.
|
|
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 562
|
Instance Attribute Details
#default_properties ⇒ OursprivacyIngest::Models::TrackEventParams::DefaultProperties?
These properties are used throughout the Ours app to pass known values onto destinations
28 29 30 31 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 28 optional :default_properties, -> { OursprivacyIngest::TrackEventParams::DefaultProperties }, api_name: :defaultProperties, nil?: true |
#distinct_id ⇒ String?
A unique identifier for the event. This helps prevent duplicate events.
37 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 37 optional :distinct_id, String, api_name: :distinctId, nil?: true |
#email ⇒ String?
The email address of a user. We will associate this event with the user or create a user. Used for lookup if externalId and userId are not included in the request.
45 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 45 optional :email, String, nil?: true |
#event ⇒ String
The name of the event you’re tracking. This must be whitelisted in the Ours dashboard.
21 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 21 required :event, String |
#event_properties ⇒ Hash{Symbol=>String, nil}?
Any additional event properties you want to pass along.
51 52 53 54 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 51 optional :event_properties, OursprivacyIngest::Internal::Type::HashOf[String, nil?: true], api_name: :eventProperties, nil?: true |
#external_id ⇒ String?
The externalId (the ID in your system) of a user. We will associate this event with the user or create a user. If included in the request, email lookup is ignored.
62 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 62 optional :external_id, String, api_name: :externalId, nil?: true |
#identity_context ⇒ OursprivacyIngest::Models::TrackEventParams::IdentityContext?
End-user network context for server-side calls. Required for probabilistic identity resolution when the caller is a backend server rather than an end-user browser.
70 71 72 73 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 70 optional :identity_context, -> { OursprivacyIngest::TrackEventParams::IdentityContext }, api_name: :identityContext, nil?: true |
#time ⇒ Float?
The time at which the event occurred in milliseconds since UTC epoch. The time must be in the past and within the last 7 days.
80 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 80 optional :time, Float, nil?: true |
#token ⇒ String
The token for your Source. You can find this in the dashboard.
14 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 14 required :token, String |
#user_id ⇒ String?
The Ours user id stored in local storage and cookies on your web properties. If userId is included in the request, we do not lookup the user by email or externalId.
88 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 88 optional :user_id, String, api_name: :userId, nil?: true |
#user_properties ⇒ OursprivacyIngest::Models::TrackEventParams::UserProperties?
Properties to set on the visitor. (optional) You can also update these properties via the identify endpoint.
95 96 97 98 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 95 optional :user_properties, -> { OursprivacyIngest::TrackEventParams::UserProperties }, api_name: :userProperties, nil?: true |