Class: OursprivacyIngest::Models::TrackEventParams::DefaultProperties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OursprivacyIngest::Models::TrackEventParams::DefaultProperties
- Defined in:
- lib/oursprivacy_ingest/models/track_event_params.rb
Instance Attribute Summary collapse
-
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active.
-
#ad_id ⇒ String?
The ad id for detected in the session.
-
#adset_id ⇒ String?
The adset id for detected in the session.
-
#alart ⇒ String?
The AppLovin alart query parameter.
-
#aleid ⇒ String?
The AppLovin aleid query parameter.
-
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt).
-
#basis_cid ⇒ String?
The Basis DSP Click ID.
-
#browser_language ⇒ String?
The language of the browser.
-
#browser_name ⇒ String?
The name of the browser.
-
#browser_version ⇒ String?
The version of the browser.
-
#campaign_id ⇒ String?
The campaign id for detected in the session.
-
#clickid ⇒ String?
The Click ID.
-
#clid ⇒ String?
The Generic Click ID.
-
#cpu_architecture ⇒ String?
The architecture of the CPU.
-
#current_url ⇒ String?
The full url (including query params) of the current page.
-
#dclid ⇒ String?
The DoubleClick Click ID.
-
#device_model ⇒ String?
The model of the device.
-
#device_type ⇒ String?
The type of device the user is using.
-
#device_vendor ⇒ String?
The vendor of the device.
-
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded.
-
#encoding ⇒ String?
The browsers encoding.
-
#engine_name ⇒ String?
The name of the browser engine.
-
#engine_version ⇒ String?
The version of the browser engine.
-
#epik ⇒ String?
The Pinterest Click ID.
-
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking.
-
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks.
-
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events.
-
#fv ⇒ Boolean?
Deprecated.
-
#gad_source ⇒ String?
The Google Ad Source.
-
#gbraid ⇒ String?
The Google Braid ID.
-
#gclid ⇒ String?
The Google Click ID.
-
#host ⇒ String?
The host of the current page.
-
#iframe ⇒ Boolean?
Whether the user is in an iframe.
-
#im_ref ⇒ String?
The Impact Click ID reference.
-
#ip ⇒ String?
The IP address of the user.
-
#irclickid ⇒ String?
The Impact Click ID.
-
#is_bot ⇒ String?
Whether we have detected that the user is a bot.
-
#li_fat_id ⇒ String?
The LinkedIn Click ID.
-
#msclkid ⇒ String?
The Microsoft Click ID.
-
#ndclid ⇒ String?
The NextDoor Click ID.
-
#new_s ⇒ Boolean?
Deprecated.
-
#os_name ⇒ String?
The name of the operating system.
-
#os_version ⇒ String?
The version of the operating system.
-
#page_hash ⇒ Float?
A random set of numbers for the page load.
-
#pathname ⇒ String?
The pathname of the current page.
-
#qclid ⇒ String?
The Quora Click ID.
-
#rdt_cid ⇒ String?
The Reddit Click ID.
-
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format.
-
#referrer ⇒ String?
The referrer URL of the current page.
-
#referring_domain ⇒ String?
The referring domain of the current page.
-
#sacid ⇒ String?
The StackAdapt Tracking ID.
-
#sccid ⇒ String?
The SnapChat Click ID.
-
#screen_height ⇒ Float?
The height of the screen.
-
#screen_width ⇒ Float?
The width of the screen.
-
#session_count ⇒ Float?
The number of sessions the user has had.
-
#sid ⇒ String?
The session ID as assigned automatically by the web SDK.
- #sr ⇒ String?
-
#title ⇒ String?
The title of the current page.
-
#ttclid ⇒ String?
The TikTok Click ID.
-
#twclid ⇒ String?
The Twitter Click ID.
-
#uafvl ⇒ String?
User agent as a full list of strings.
-
#user_agent ⇒ String?
The user agent of the browser.
-
#utm_campaign ⇒ String?
The UTM Campaign.
-
#utm_content ⇒ String?
The UTM Content.
-
#utm_medium ⇒ String?
The UTM Medium.
-
#utm_name ⇒ String?
The UTM Name.
-
#utm_source ⇒ String?
The UTM Source.
-
#utm_term ⇒ String?
The UTM Term.
-
#version ⇒ String?
The version of the web SDK.
-
#wbraid ⇒ String?
The WBRAID Identifier.
-
#webview ⇒ Boolean?
Whether the user is in a webview.
Instance Method Summary collapse
-
#initialize(token:, event:, default_properties: nil, distinct_id: nil, email: nil, event_properties: nil, external_id: nil, identity_context: nil, time: nil, user_id: nil, user_properties: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see OursprivacyIngest::Models::TrackEventParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, event:, default_properties: nil, distinct_id: nil, email: nil, event_properties: nil, external_id: nil, identity_context: nil, time: nil, user_id: nil, user_properties: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see OursprivacyIngest::Models::TrackEventParams for more details.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 128 class DefaultProperties < OursprivacyIngest::Internal::Type::BaseModel # @!attribute active_duration # The active time in milliseconds that the user had this tab active # # @return [Float, nil] optional :active_duration, Float, api_name: :activeDuration, nil?: true # @!attribute ad_id # The ad id for detected in the session. This is set by the web sdk automatically. # # @return [String, nil] optional :ad_id, String, nil?: true # @!attribute adset_id # The adset id for detected in the session. This is set by the web sdk # automatically. # # @return [String, nil] optional :adset_id, String, nil?: true # @!attribute alart # The AppLovin alart query parameter. Ex: alart123 # # @return [String, nil] optional :alart, String, nil?: true # @!attribute aleid # The AppLovin aleid query parameter. Ex: aleid123 # # @return [String, nil] optional :aleid, String, nil?: true # @!attribute axwrt # The AppLovin Axon pixel cookie value (\_axwrt). Web-only. # # @return [String, nil] optional :axwrt, String, nil?: true # @!attribute basis_cid # The Basis DSP Click ID. Ex: basis_cid123 # # @return [String, nil] optional :basis_cid, String, nil?: true # @!attribute browser_language # The language of the browser. Ex: en-US # # @return [String, nil] optional :browser_language, String, nil?: true # @!attribute browser_name # The name of the browser. Ex: Chrome # # @return [String, nil] optional :browser_name, String, nil?: true # @!attribute browser_version # The version of the browser. Ex: 114.0 # # @return [String, nil] optional :browser_version, String, nil?: true # @!attribute campaign_id # The campaign id for detected in the session. This is set by the web sdk # automatically. # # @return [String, nil] optional :campaign_id, String, nil?: true # @!attribute clickid # The Click ID. Ex: clickid123 # # @return [String, nil] optional :clickid, String, nil?: true # @!attribute clid # The Generic Click ID. Ex: clid123 # # @return [String, nil] optional :clid, String, nil?: true # @!attribute cpu_architecture # The architecture of the CPU. Ex: x64 # # @return [String, nil] optional :cpu_architecture, String, nil?: true # @!attribute current_url # The full url (including query params) of the current page # # @return [String, nil] optional :current_url, String, nil?: true # @!attribute dclid # The DoubleClick Click ID. Ex: dclid123 # # @return [String, nil] optional :dclid, String, nil?: true # @!attribute device_model # The model of the device. Ex: iPhone 13 # # @return [String, nil] optional :device_model, String, nil?: true # @!attribute device_type # The type of device the user is using. Ex: mobile # # @return [String, nil] optional :device_type, String, nil?: true # @!attribute device_vendor # The vendor of the device. Ex: Apple # # @return [String, nil] optional :device_vendor, String, nil?: true # @!attribute duration # The time in milliseconds since the page was loaded // script was loaded # # @return [Float, nil] optional :duration, Float, nil?: true # @!attribute encoding # The browsers encoding. Ex: UTF-8 # # @return [String, nil] optional :encoding, String, nil?: true # @!attribute engine_name # The name of the browser engine. Ex: Blink # # @return [String, nil] optional :engine_name, String, nil?: true # @!attribute engine_version # The version of the browser engine. Ex: 114.0 # # @return [String, nil] optional :engine_version, String, nil?: true # @!attribute epik # The Pinterest Click ID. Ex: epik456 # # @return [String, nil] optional :epik, String, nil?: true # @!attribute fbc # Facebook Click ID with prefix format for Conversions API tracking. Ex: # fb.1.1554763741205.AbCdEfGhIjKlMnOpQrStUvWxYz1234567890 # # @return [String, nil] optional :fbc, String, nil?: true # @!attribute fbclid # Raw Facebook Click ID query parameter without prefix from ad clicks. Ex: # AbCdEfGhIjKlMnOpQrStUvWxYz1234567890 # # @return [String, nil] optional :fbclid, String, nil?: true # @!attribute fbp # Facebook Browser ID parameter for identifying browsers and attributing events. # Ex: fb.1.1554763741205.1098115397 # # @return [String, nil] optional :fbp, String, nil?: true # @!attribute fv # Deprecated # # @return [Boolean, nil] optional :fv, OursprivacyIngest::Internal::Type::Boolean, nil?: true # @!attribute gad_source # The Google Ad Source. Ex: google # # @return [String, nil] optional :gad_source, String, nil?: true # @!attribute gbraid # The Google Braid ID. Ex: gbraid123 # # @return [String, nil] optional :gbraid, String, nil?: true # @!attribute gclid # The Google Click ID. Ex: gclid123 # # @return [String, nil] optional :gclid, String, nil?: true # @!attribute host # The host of the current page. Ex: example.com # # @return [String, nil] optional :host, String, nil?: true # @!attribute iframe # Whether the user is in an iframe. Ex: true # # @return [Boolean, nil] optional :iframe, OursprivacyIngest::Internal::Type::Boolean, nil?: true # @!attribute im_ref # The Impact Click ID reference. Ex: im_ref123 # # @return [String, nil] optional :im_ref, String, nil?: true # @!attribute ip # The IP address of the user. Ex: 127.0.0.1 # # @return [String, nil] optional :ip, String, nil?: true # @!attribute irclickid # The Impact Click ID. Ex: irclickid123 # # @return [String, nil] optional :irclickid, String, nil?: true # @!attribute is_bot # Whether we have detected that the user is a bot. This is set automatically by # the Ours server primarily for events tracked through the web SDK. # # @return [String, nil] optional :is_bot, String, nil?: true # @!attribute li_fat_id # The LinkedIn Click ID. Ex: li_fat_id123 # # @return [String, nil] optional :li_fat_id, String, nil?: true # @!attribute msclkid # The Microsoft Click ID. Ex: msclkid123 # # @return [String, nil] optional :msclkid, String, nil?: true # @!attribute ndclid # The NextDoor Click ID. Ex: ndclid123 # # @return [String, nil] optional :ndclid, String, nil?: true # @!attribute new_s # Deprecated # # @return [Boolean, nil] optional :new_s, OursprivacyIngest::Internal::Type::Boolean, nil?: true # @!attribute os_name # The name of the operating system. Ex: Windows # # @return [String, nil] optional :os_name, String, nil?: true # @!attribute os_version # The version of the operating system. Ex: 10.0 # # @return [String, nil] optional :os_version, String, nil?: true # @!attribute page_hash # A random set of numbers for the page load # # @return [Float, nil] optional :page_hash, Float, nil?: true # @!attribute pathname # The pathname of the current page. Ex: /home # # @return [String, nil] optional :pathname, String, nil?: true # @!attribute qclid # The Quora Click ID. Ex: qclid123 # # @return [String, nil] optional :qclid, String, nil?: true # @!attribute rdt_cid # The Reddit Click ID. Ex: rdt_cid123 # # @return [String, nil] optional :rdt_cid, String, nil?: true # @!attribute received_at # The time the event was received by an Ours server in ISO format # # @return [String, nil] optional :received_at, String, nil?: true # @!attribute referrer # The referrer URL of the current page # # @return [String, nil] optional :referrer, String, nil?: true # @!attribute referring_domain # The referring domain of the current page # # @return [String, nil] optional :referring_domain, String, nil?: true # @!attribute sacid # The StackAdapt Tracking ID. Ex: sacid123 # # @return [String, nil] optional :sacid, String, nil?: true # @!attribute sccid # The SnapChat Click ID. Ex: sccid123 # # @return [String, nil] optional :sccid, String, nil?: true # @!attribute screen_height # The height of the screen. Ex: 1080 # # @return [Float, nil] optional :screen_height, Float, nil?: true # @!attribute screen_width # The width of the screen. Ex: 1920 # # @return [Float, nil] optional :screen_width, Float, nil?: true # @!attribute session_count # The number of sessions the user has had. Ex: 3 # # @return [Float, nil] optional :session_count, Float, api_name: :sessionCount, nil?: true # @!attribute sid # The session ID as assigned automatically by the web SDK. This is required for # session replay # # @return [String, nil] optional :sid, String, nil?: true # @!attribute sr # # @return [String, nil] optional :sr, String, nil?: true # @!attribute title # The title of the current page # # @return [String, nil] optional :title, String, nil?: true # @!attribute ttclid # The TikTok Click ID. Ex: ttclid123 # # @return [String, nil] optional :ttclid, String, nil?: true # @!attribute twclid # The Twitter Click ID. Ex: twclid123 # # @return [String, nil] optional :twclid, String, nil?: true # @!attribute uafvl # User agent as a full list of strings. # # @return [String, nil] optional :uafvl, String, nil?: true # @!attribute user_agent # The user agent of the browser # # @return [String, nil] optional :user_agent, String, nil?: true # @!attribute utm_campaign # The UTM Campaign. The web SDK automatically captures this from the query params. # # @return [String, nil] optional :utm_campaign, String, nil?: true # @!attribute utm_content # The UTM Content. The web SDK automatically captures this from the query params. # # @return [String, nil] optional :utm_content, String, nil?: true # @!attribute utm_medium # The UTM Medium. The web SDK automatically captures this from the query params. # # @return [String, nil] optional :utm_medium, String, nil?: true # @!attribute utm_name # The UTM Name. The web SDK automatically captures this from the query params. # # @return [String, nil] optional :utm_name, String, nil?: true # @!attribute utm_source # The UTM Source. The web SDK automatically captures this from the query params. # # @return [String, nil] optional :utm_source, String, nil?: true # @!attribute utm_term # The UTM Term. The web SDK automatically captures this from the query params. # # @return [String, nil] optional :utm_term, String, nil?: true # @!attribute version # The version of the web SDK # # @return [String, nil] optional :version, String, nil?: true # @!attribute wbraid # The WBRAID Identifier. The web SDK automatically captures this from the query # params. # # @return [String, nil] optional :wbraid, String, nil?: true # @!attribute webview # Whether the user is in a webview. Ex: true # # @return [Boolean, nil] optional :webview, OursprivacyIngest::Internal::Type::Boolean, nil?: true # @!method initialize(active_duration: nil, ad_id: nil, adset_id: nil, alart: nil, aleid: nil, axwrt: nil, basis_cid: nil, browser_language: nil, browser_name: nil, browser_version: nil, campaign_id: nil, clickid: nil, clid: nil, cpu_architecture: nil, current_url: nil, dclid: nil, device_model: nil, device_type: nil, device_vendor: nil, duration: nil, encoding: nil, engine_name: nil, engine_version: nil, epik: nil, fbc: nil, fbclid: nil, fbp: nil, fv: nil, gad_source: nil, gbraid: nil, gclid: nil, host: nil, iframe: nil, im_ref: nil, ip: nil, irclickid: nil, is_bot: nil, li_fat_id: nil, msclkid: nil, ndclid: nil, new_s: nil, os_name: nil, os_version: nil, page_hash: nil, pathname: nil, qclid: nil, rdt_cid: nil, received_at: nil, referrer: nil, referring_domain: nil, sacid: nil, sccid: nil, screen_height: nil, screen_width: nil, session_count: nil, sid: nil, sr: nil, title: nil, ttclid: nil, twclid: nil, uafvl: nil, user_agent: nil, utm_campaign: nil, utm_content: nil, utm_medium: nil, utm_name: nil, utm_source: nil, utm_term: nil, version: nil, wbraid: nil, webview: nil) # Some parameter documentations has been truncated, see # {OursprivacyIngest::Models::TrackEventParams::DefaultProperties} for more # details. # # These properties are used throughout the Ours app to pass known values onto # destinations # # @param active_duration [Float, nil] The active time in milliseconds that the user had this tab active # # @param ad_id [String, nil] The ad id for detected in the session. This is set by the web sdk automatically. # # @param adset_id [String, nil] The adset id for detected in the session. This is set by the web sdk automatical # # @param alart [String, nil] The AppLovin alart query parameter. Ex: alart123 # # @param aleid [String, nil] The AppLovin aleid query parameter. Ex: aleid123 # # @param axwrt [String, nil] The AppLovin Axon pixel cookie value (\_axwrt). Web-only. # # @param basis_cid [String, nil] The Basis DSP Click ID. Ex: basis_cid123 # # @param browser_language [String, nil] The language of the browser. Ex: en-US # # @param browser_name [String, nil] The name of the browser. Ex: Chrome # # @param browser_version [String, nil] The version of the browser. Ex: 114.0 # # @param campaign_id [String, nil] The campaign id for detected in the session. This is set by the web sdk automati # # @param clickid [String, nil] The Click ID. Ex: clickid123 # # @param clid [String, nil] The Generic Click ID. Ex: clid123 # # @param cpu_architecture [String, nil] The architecture of the CPU. Ex: x64 # # @param current_url [String, nil] The full url (including query params) of the current page # # @param dclid [String, nil] The DoubleClick Click ID. Ex: dclid123 # # @param device_model [String, nil] The model of the device. Ex: iPhone 13 # # @param device_type [String, nil] The type of device the user is using. Ex: mobile # # @param device_vendor [String, nil] The vendor of the device. Ex: Apple # # @param duration [Float, nil] The time in milliseconds since the page was loaded // script was loaded # # @param encoding [String, nil] The browsers encoding. Ex: UTF-8 # # @param engine_name [String, nil] The name of the browser engine. Ex: Blink # # @param engine_version [String, nil] The version of the browser engine. Ex: 114.0 # # @param epik [String, nil] The Pinterest Click ID. Ex: epik456 # # @param fbc [String, nil] Facebook Click ID with prefix format for Conversions API tracking. Ex: fb.1.1554 # # @param fbclid [String, nil] Raw Facebook Click ID query parameter without prefix from ad clicks. Ex: AbCdEfG # # @param fbp [String, nil] Facebook Browser ID parameter for identifying browsers and attributing events. E # # @param fv [Boolean, nil] Deprecated # # @param gad_source [String, nil] The Google Ad Source. Ex: google # # @param gbraid [String, nil] The Google Braid ID. Ex: gbraid123 # # @param gclid [String, nil] The Google Click ID. Ex: gclid123 # # @param host [String, nil] The host of the current page. Ex: example.com # # @param iframe [Boolean, nil] Whether the user is in an iframe. Ex: true # # @param im_ref [String, nil] The Impact Click ID reference. Ex: im_ref123 # # @param ip [String, nil] The IP address of the user. Ex: 127.0.0.1 # # @param irclickid [String, nil] The Impact Click ID. Ex: irclickid123 # # @param is_bot [String, nil] Whether we have detected that the user is a bot. This is set automatically by th # # @param li_fat_id [String, nil] The LinkedIn Click ID. Ex: li_fat_id123 # # @param msclkid [String, nil] The Microsoft Click ID. Ex: msclkid123 # # @param ndclid [String, nil] The NextDoor Click ID. Ex: ndclid123 # # @param new_s [Boolean, nil] Deprecated # # @param os_name [String, nil] The name of the operating system. Ex: Windows # # @param os_version [String, nil] The version of the operating system. Ex: 10.0 # # @param page_hash [Float, nil] A random set of numbers for the page load # # @param pathname [String, nil] The pathname of the current page. Ex: /home # # @param qclid [String, nil] The Quora Click ID. Ex: qclid123 # # @param rdt_cid [String, nil] The Reddit Click ID. Ex: rdt_cid123 # # @param received_at [String, nil] The time the event was received by an Ours server in ISO format # # @param referrer [String, nil] The referrer URL of the current page # # @param referring_domain [String, nil] The referring domain of the current page # # @param sacid [String, nil] The StackAdapt Tracking ID. Ex: sacid123 # # @param sccid [String, nil] The SnapChat Click ID. Ex: sccid123 # # @param screen_height [Float, nil] The height of the screen. Ex: 1080 # # @param screen_width [Float, nil] The width of the screen. Ex: 1920 # # @param session_count [Float, nil] The number of sessions the user has had. Ex: 3 # # @param sid [String, nil] The session ID as assigned automatically by the web SDK. This is required for se # # @param sr [String, nil] # # @param title [String, nil] The title of the current page # # @param ttclid [String, nil] The TikTok Click ID. Ex: ttclid123 # # @param twclid [String, nil] The Twitter Click ID. Ex: twclid123 # # @param uafvl [String, nil] User agent as a full list of strings. # # @param user_agent [String, nil] The user agent of the browser # # @param utm_campaign [String, nil] The UTM Campaign. The web SDK automatically captures this from the query params. # # @param utm_content [String, nil] The UTM Content. The web SDK automatically captures this from the query params. # # @param utm_medium [String, nil] The UTM Medium. The web SDK automatically captures this from the query params. # # @param utm_name [String, nil] The UTM Name. The web SDK automatically captures this from the query params. # # @param utm_source [String, nil] The UTM Source. The web SDK automatically captures this from the query params. # # @param utm_term [String, nil] The UTM Term. The web SDK automatically captures this from the query params. # # @param version [String, nil] The version of the web SDK # # @param wbraid [String, nil] The WBRAID Identifier. The web SDK automatically captures this from the query pa # # @param webview [Boolean, nil] Whether the user is in a webview. Ex: true end |
Instance Attribute Details
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active
133 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 133 optional :active_duration, Float, api_name: :activeDuration, nil?: true |
#ad_id ⇒ String?
The ad id for detected in the session. This is set by the web sdk automatically.
139 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 139 optional :ad_id, String, nil?: true |
#adset_id ⇒ String?
The adset id for detected in the session. This is set by the web sdk automatically.
146 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 146 optional :adset_id, String, nil?: true |
#alart ⇒ String?
The AppLovin alart query parameter. Ex: alart123
152 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 152 optional :alart, String, nil?: true |
#aleid ⇒ String?
The AppLovin aleid query parameter. Ex: aleid123
158 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 158 optional :aleid, String, nil?: true |
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt). Web-only.
164 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 164 optional :axwrt, String, nil?: true |
#basis_cid ⇒ String?
The Basis DSP Click ID. Ex: basis_cid123
170 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 170 optional :basis_cid, String, nil?: true |
#browser_language ⇒ String?
The language of the browser. Ex: en-US
176 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 176 optional :browser_language, String, nil?: true |
#browser_name ⇒ String?
The name of the browser. Ex: Chrome
182 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 182 optional :browser_name, String, nil?: true |
#browser_version ⇒ String?
The version of the browser. Ex: 114.0
188 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 188 optional :browser_version, String, nil?: true |
#campaign_id ⇒ String?
The campaign id for detected in the session. This is set by the web sdk automatically.
195 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 195 optional :campaign_id, String, nil?: true |
#clickid ⇒ String?
The Click ID. Ex: clickid123
201 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 201 optional :clickid, String, nil?: true |
#clid ⇒ String?
The Generic Click ID. Ex: clid123
207 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 207 optional :clid, String, nil?: true |
#cpu_architecture ⇒ String?
The architecture of the CPU. Ex: x64
213 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 213 optional :cpu_architecture, String, nil?: true |
#current_url ⇒ String?
The full url (including query params) of the current page
219 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 219 optional :current_url, String, nil?: true |
#dclid ⇒ String?
The DoubleClick Click ID. Ex: dclid123
225 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 225 optional :dclid, String, nil?: true |
#device_model ⇒ String?
The model of the device. Ex: iPhone 13
231 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 231 optional :device_model, String, nil?: true |
#device_type ⇒ String?
The type of device the user is using. Ex: mobile
237 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 237 optional :device_type, String, nil?: true |
#device_vendor ⇒ String?
The vendor of the device. Ex: Apple
243 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 243 optional :device_vendor, String, nil?: true |
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded
249 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 249 optional :duration, Float, nil?: true |
#encoding ⇒ String?
The browsers encoding. Ex: UTF-8
255 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 255 optional :encoding, String, nil?: true |
#engine_name ⇒ String?
The name of the browser engine. Ex: Blink
261 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 261 optional :engine_name, String, nil?: true |
#engine_version ⇒ String?
The version of the browser engine. Ex: 114.0
267 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 267 optional :engine_version, String, nil?: true |
#epik ⇒ String?
The Pinterest Click ID. Ex: epik456
273 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 273 optional :epik, String, nil?: true |
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking. Ex: fb.1.1554763741205.AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
280 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 280 optional :fbc, String, nil?: true |
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks. Ex: AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
287 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 287 optional :fbclid, String, nil?: true |
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events. Ex: fb.1.1554763741205.1098115397
294 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 294 optional :fbp, String, nil?: true |
#fv ⇒ Boolean?
Deprecated
300 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 300 optional :fv, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#gad_source ⇒ String?
The Google Ad Source. Ex: google
306 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 306 optional :gad_source, String, nil?: true |
#gbraid ⇒ String?
The Google Braid ID. Ex: gbraid123
312 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 312 optional :gbraid, String, nil?: true |
#gclid ⇒ String?
The Google Click ID. Ex: gclid123
318 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 318 optional :gclid, String, nil?: true |
#host ⇒ String?
The host of the current page. Ex: example.com
324 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 324 optional :host, String, nil?: true |
#iframe ⇒ Boolean?
Whether the user is in an iframe. Ex: true
330 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 330 optional :iframe, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#im_ref ⇒ String?
The Impact Click ID reference. Ex: im_ref123
336 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 336 optional :im_ref, String, nil?: true |
#ip ⇒ String?
The IP address of the user. Ex: 127.0.0.1
342 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 342 optional :ip, String, nil?: true |
#irclickid ⇒ String?
The Impact Click ID. Ex: irclickid123
348 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 348 optional :irclickid, String, nil?: true |
#is_bot ⇒ String?
Whether we have detected that the user is a bot. This is set automatically by the Ours server primarily for events tracked through the web SDK.
355 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 355 optional :is_bot, String, nil?: true |
#li_fat_id ⇒ String?
The LinkedIn Click ID. Ex: li_fat_id123
361 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 361 optional :li_fat_id, String, nil?: true |
#msclkid ⇒ String?
The Microsoft Click ID. Ex: msclkid123
367 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 367 optional :msclkid, String, nil?: true |
#ndclid ⇒ String?
The NextDoor Click ID. Ex: ndclid123
373 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 373 optional :ndclid, String, nil?: true |
#new_s ⇒ Boolean?
Deprecated
379 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 379 optional :new_s, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#os_name ⇒ String?
The name of the operating system. Ex: Windows
385 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 385 optional :os_name, String, nil?: true |
#os_version ⇒ String?
The version of the operating system. Ex: 10.0
391 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 391 optional :os_version, String, nil?: true |
#page_hash ⇒ Float?
A random set of numbers for the page load
397 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 397 optional :page_hash, Float, nil?: true |
#pathname ⇒ String?
The pathname of the current page. Ex: /home
403 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 403 optional :pathname, String, nil?: true |
#qclid ⇒ String?
The Quora Click ID. Ex: qclid123
409 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 409 optional :qclid, String, nil?: true |
#rdt_cid ⇒ String?
The Reddit Click ID. Ex: rdt_cid123
415 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 415 optional :rdt_cid, String, nil?: true |
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format
421 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 421 optional :received_at, String, nil?: true |
#referrer ⇒ String?
The referrer URL of the current page
427 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 427 optional :referrer, String, nil?: true |
#referring_domain ⇒ String?
The referring domain of the current page
433 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 433 optional :referring_domain, String, nil?: true |
#sacid ⇒ String?
The StackAdapt Tracking ID. Ex: sacid123
439 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 439 optional :sacid, String, nil?: true |
#sccid ⇒ String?
The SnapChat Click ID. Ex: sccid123
445 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 445 optional :sccid, String, nil?: true |
#screen_height ⇒ Float?
The height of the screen. Ex: 1080
451 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 451 optional :screen_height, Float, nil?: true |
#screen_width ⇒ Float?
The width of the screen. Ex: 1920
457 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 457 optional :screen_width, Float, nil?: true |
#session_count ⇒ Float?
The number of sessions the user has had. Ex: 3
463 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 463 optional :session_count, Float, api_name: :sessionCount, nil?: true |
#sid ⇒ String?
The session ID as assigned automatically by the web SDK. This is required for session replay
470 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 470 optional :sid, String, nil?: true |
#sr ⇒ String?
475 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 475 optional :sr, String, nil?: true |
#title ⇒ String?
The title of the current page
481 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 481 optional :title, String, nil?: true |
#ttclid ⇒ String?
The TikTok Click ID. Ex: ttclid123
487 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 487 optional :ttclid, String, nil?: true |
#twclid ⇒ String?
The Twitter Click ID. Ex: twclid123
493 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 493 optional :twclid, String, nil?: true |
#uafvl ⇒ String?
User agent as a full list of strings.
499 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 499 optional :uafvl, String, nil?: true |
#user_agent ⇒ String?
The user agent of the browser
505 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 505 optional :user_agent, String, nil?: true |
#utm_campaign ⇒ String?
The UTM Campaign. The web SDK automatically captures this from the query params.
511 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 511 optional :utm_campaign, String, nil?: true |
#utm_content ⇒ String?
The UTM Content. The web SDK automatically captures this from the query params.
517 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 517 optional :utm_content, String, nil?: true |
#utm_medium ⇒ String?
The UTM Medium. The web SDK automatically captures this from the query params.
523 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 523 optional :utm_medium, String, nil?: true |
#utm_name ⇒ String?
The UTM Name. The web SDK automatically captures this from the query params.
529 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 529 optional :utm_name, String, nil?: true |
#utm_source ⇒ String?
The UTM Source. The web SDK automatically captures this from the query params.
535 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 535 optional :utm_source, String, nil?: true |
#utm_term ⇒ String?
The UTM Term. The web SDK automatically captures this from the query params.
541 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 541 optional :utm_term, String, nil?: true |
#version ⇒ String?
The version of the web SDK
547 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 547 optional :version, String, nil?: true |
#wbraid ⇒ String?
The WBRAID Identifier. The web SDK automatically captures this from the query params.
554 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 554 optional :wbraid, String, nil?: true |
#webview ⇒ Boolean?
Whether the user is in a webview. Ex: true
560 |
# File 'lib/oursprivacy_ingest/models/track_event_params.rb', line 560 optional :webview, OursprivacyIngest::Internal::Type::Boolean, nil?: true |