Class: OursprivacyIngest::Models::VisitorUpsertParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/oursprivacy_ingest/models/visitor_upsert_params.rb

Overview

Defined Under Namespace

Classes: DefaultProperties, IdentityContext, UserProperties

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(active_duration: nil, ad_id: nil, adset_id: nil, alart: nil, aleid: nil, axwrt: nil, basis_cid: nil, browser_language: nil, browser_name: nil, browser_version: nil, campaign_id: nil, clickid: nil, clid: nil, cpu_architecture: nil, current_url: nil, dclid: nil, device_model: nil, device_type: nil, device_vendor: nil, duration: nil, encoding: nil, engine_name: nil, engine_version: nil, epik: nil, fbc: nil, fbclid: nil, fbp: nil, fv: nil, gad_source: nil, gbraid: nil, gclid: nil, host: nil, iframe: nil, im_ref: nil, ip: nil, irclickid: nil, is_bot: nil, li_fat_id: nil, msclkid: nil, ndclid: nil, new_s: nil, os_name: nil, os_version: nil, page_hash: nil, pathname: nil, qclid: nil, rdt_cid: nil, received_at: nil, referrer: nil, referring_domain: nil, sacid: nil, sccid: nil, screen_height: nil, screen_width: nil, session_count: nil, sid: nil, sr: nil, title: nil, ttclid: nil, twclid: nil, uafvl: nil, user_agent: nil, utm_campaign: nil, utm_content: nil, utm_medium: nil, utm_name: nil, utm_source: nil, utm_term: nil, version: nil, wbraid: nil, webview: nil) ⇒ Object

Some parameter documentations has been truncated, see DefaultProperties for more details.

These properties are used throughout the Ours app to pass known values onto destinations

Parameters:

  • active_duration (Float, nil) (defaults to: nil)

    The active time in milliseconds that the user had this tab active

  • ad_id (String, nil) (defaults to: nil)

    The ad id for detected in the session. This is set by the web sdk automatically.

  • adset_id (String, nil) (defaults to: nil)

    The adset id for detected in the session. This is set by the web sdk automatical

  • alart (String, nil) (defaults to: nil)

    The AppLovin alart query parameter. Ex: alart123

  • aleid (String, nil) (defaults to: nil)

    The AppLovin aleid query parameter. Ex: aleid123

  • axwrt (String, nil) (defaults to: nil)

    The AppLovin Axon pixel cookie value (_axwrt). Web-only.

  • basis_cid (String, nil) (defaults to: nil)

    The Basis DSP Click ID. Ex: basis_cid123

  • browser_language (String, nil) (defaults to: nil)

    The language of the browser. Ex: en-US

  • browser_name (String, nil) (defaults to: nil)

    The name of the browser. Ex: Chrome

  • browser_version (String, nil) (defaults to: nil)

    The version of the browser. Ex: 114.0

  • campaign_id (String, nil) (defaults to: nil)

    The campaign id for detected in the session. This is set by the web sdk automati

  • clickid (String, nil) (defaults to: nil)

    The Click ID. Ex: clickid123

  • clid (String, nil) (defaults to: nil)

    The Generic Click ID. Ex: clid123

  • cpu_architecture (String, nil) (defaults to: nil)

    The architecture of the CPU. Ex: x64

  • current_url (String, nil) (defaults to: nil)

    The full url (including query params) of the current page

  • dclid (String, nil) (defaults to: nil)

    The DoubleClick Click ID. Ex: dclid123

  • device_model (String, nil) (defaults to: nil)

    The model of the device. Ex: iPhone 13

  • device_type (String, nil) (defaults to: nil)

    The type of device the user is using. Ex: mobile

  • device_vendor (String, nil) (defaults to: nil)

    The vendor of the device. Ex: Apple

  • duration (Float, nil) (defaults to: nil)

    The time in milliseconds since the page was loaded // script was loaded

  • encoding (String, nil) (defaults to: nil)

    The browsers encoding. Ex: UTF-8

  • engine_name (String, nil) (defaults to: nil)

    The name of the browser engine. Ex: Blink

  • engine_version (String, nil) (defaults to: nil)

    The version of the browser engine. Ex: 114.0

  • epik (String, nil) (defaults to: nil)

    The Pinterest Click ID. Ex: epik456

  • fbc (String, nil) (defaults to: nil)

    Facebook Click ID with prefix format for Conversions API tracking. Ex: fb.1.1554

  • fbclid (String, nil) (defaults to: nil)

    Raw Facebook Click ID query parameter without prefix from ad clicks. Ex: AbCdEfG

  • fbp (String, nil) (defaults to: nil)

    Facebook Browser ID parameter for identifying browsers and attributing events. E

  • fv (Boolean, nil) (defaults to: nil)

    Deprecated

  • gad_source (String, nil) (defaults to: nil)

    The Google Ad Source. Ex: google

  • gbraid (String, nil) (defaults to: nil)

    The Google Braid ID. Ex: gbraid123

  • gclid (String, nil) (defaults to: nil)

    The Google Click ID. Ex: gclid123

  • host (String, nil) (defaults to: nil)

    The host of the current page. Ex: example.com

  • iframe (Boolean, nil) (defaults to: nil)

    Whether the user is in an iframe. Ex: true

  • im_ref (String, nil) (defaults to: nil)

    The Impact Click ID reference. Ex: im_ref123

  • ip (String, nil) (defaults to: nil)

    The IP address of the user. Ex: 127.0.0.1

  • irclickid (String, nil) (defaults to: nil)

    The Impact Click ID. Ex: irclickid123

  • is_bot (String, nil) (defaults to: nil)

    Whether we have detected that the user is a bot. This is set automatically by th

  • li_fat_id (String, nil) (defaults to: nil)

    The LinkedIn Click ID. Ex: li_fat_id123

  • msclkid (String, nil) (defaults to: nil)

    The Microsoft Click ID. Ex: msclkid123

  • ndclid (String, nil) (defaults to: nil)

    The NextDoor Click ID. Ex: ndclid123

  • new_s (Boolean, nil) (defaults to: nil)

    Deprecated

  • os_name (String, nil) (defaults to: nil)

    The name of the operating system. Ex: Windows

  • os_version (String, nil) (defaults to: nil)

    The version of the operating system. Ex: 10.0

  • page_hash (Float, nil) (defaults to: nil)

    A random set of numbers for the page load

  • pathname (String, nil) (defaults to: nil)

    The pathname of the current page. Ex: /home

  • qclid (String, nil) (defaults to: nil)

    The Quora Click ID. Ex: qclid123

  • rdt_cid (String, nil) (defaults to: nil)

    The Reddit Click ID. Ex: rdt_cid123

  • received_at (String, nil) (defaults to: nil)

    The time the event was received by an Ours server in ISO format

  • referrer (String, nil) (defaults to: nil)

    The referrer URL of the current page

  • referring_domain (String, nil) (defaults to: nil)

    The referring domain of the current page

  • sacid (String, nil) (defaults to: nil)

    The StackAdapt Tracking ID. Ex: sacid123

  • sccid (String, nil) (defaults to: nil)

    The SnapChat Click ID. Ex: sccid123

  • screen_height (Float, nil) (defaults to: nil)

    The height of the screen. Ex: 1080

  • screen_width (Float, nil) (defaults to: nil)

    The width of the screen. Ex: 1920

  • session_count (Float, nil) (defaults to: nil)

    The number of sessions the user has had. Ex: 3

  • sid (String, nil) (defaults to: nil)

    The session ID as assigned automatically by the web SDK. This is required for se

  • sr (String, nil) (defaults to: nil)
  • title (String, nil) (defaults to: nil)

    The title of the current page

  • ttclid (String, nil) (defaults to: nil)

    The TikTok Click ID. Ex: ttclid123

  • twclid (String, nil) (defaults to: nil)

    The Twitter Click ID. Ex: twclid123

  • uafvl (String, nil) (defaults to: nil)

    User agent as a full list of strings.

  • user_agent (String, nil) (defaults to: nil)

    The user agent of the browser

  • utm_campaign (String, nil) (defaults to: nil)

    The UTM Campaign. The web SDK automatically captures this from the query params.

  • utm_content (String, nil) (defaults to: nil)

    The UTM Content. The web SDK automatically captures this from the query params.

  • utm_medium (String, nil) (defaults to: nil)

    The UTM Medium. The web SDK automatically captures this from the query params.

  • utm_name (String, nil) (defaults to: nil)

    The UTM Name. The web SDK automatically captures this from the query params.

  • utm_source (String, nil) (defaults to: nil)

    The UTM Source. The web SDK automatically captures this from the query params.

  • utm_term (String, nil) (defaults to: nil)

    The UTM Term. The web SDK automatically captures this from the query params.

  • version (String, nil) (defaults to: nil)

    The version of the web SDK

  • wbraid (String, nil) (defaults to: nil)

    The WBRAID Identifier. The web SDK automatically captures this from the query pa

  • webview (Boolean, nil) (defaults to: nil)

    Whether the user is in a webview. Ex: true



# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 378

Instance Attribute Details

#default_propertiesOursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties?

These properties are used throughout the Ours app to pass known values onto destinations



31
32
33
34
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 31

optional :default_properties,
-> { OursprivacyIngest::VisitorUpsertParams::DefaultProperties },
api_name: :defaultProperties,
nil?: true

#emailString?

The email address of a user. We will associate this event with the user or create a user. Used for lookup if externalId and userId are not included in the request.

Returns:

  • (String, nil)


42
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 42

optional :email, String, nil?: true

#external_idString?

The externalId (the ID in your system) of a user. We will associate this event with the user or create a user. If included in the request, email lookup is ignored.

Returns:

  • (String, nil)


50
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 50

optional :external_id, String, api_name: :externalId, nil?: true

#identity_contextOursprivacyIngest::Models::VisitorUpsertParams::IdentityContext?

End-user network context for server-side calls. Required for probabilistic identity resolution when the caller is a backend server rather than an end-user browser.



58
59
60
61
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 58

optional :identity_context,
-> { OursprivacyIngest::VisitorUpsertParams::IdentityContext },
api_name: :identityContext,
nil?: true

#tokenString

The token for your Source. You can find this in the dashboard.

Returns:

  • (String)


14
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 14

required :token, String

#user_idString?

The Ours user id stored in local storage and cookies on your web properties. If userId is included in the request, we do not lookup the user by email or externalId.

Returns:

  • (String, nil)


69
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 69

optional :user_id, String, api_name: :userId, nil?: true

#user_propertiesOursprivacyIngest::Models::VisitorUpsertParams::UserProperties

User properties to associate with this user. The existing user properties will be updated. And all future events will have these properties associated with them.



22
23
24
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 22

required :user_properties,
-> { OursprivacyIngest::VisitorUpsertParams::UserProperties },
api_name: :userProperties