Class: OursprivacyIngest::Models::VisitorUpsertParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OursprivacyIngest::Models::VisitorUpsertParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/oursprivacy_ingest/models/visitor_upsert_params.rb
Overview
Defined Under Namespace
Classes: DefaultProperties, IdentityContext, UserProperties
Instance Attribute Summary collapse
-
#default_properties ⇒ OursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties?
These properties are used throughout the Ours app to pass known values onto destinations.
-
#email ⇒ String?
The email address of a user.
-
#external_id ⇒ String?
The externalId (the ID in your system) of a user.
-
#identity_context ⇒ OursprivacyIngest::Models::VisitorUpsertParams::IdentityContext?
End-user network context for server-side calls.
-
#token ⇒ String
The token for your Source.
-
#user_id ⇒ String?
The Ours user id stored in local storage and cookies on your web properties.
-
#user_properties ⇒ OursprivacyIngest::Models::VisitorUpsertParams::UserProperties
User properties to associate with this user.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(active_duration: nil, ad_id: nil, adset_id: nil, alart: nil, aleid: nil, axwrt: nil, basis_cid: nil, browser_language: nil, browser_name: nil, browser_version: nil, campaign_id: nil, clickid: nil, clid: nil, cpu_architecture: nil, current_url: nil, dclid: nil, device_model: nil, device_type: nil, device_vendor: nil, duration: nil, encoding: nil, engine_name: nil, engine_version: nil, epik: nil, fbc: nil, fbclid: nil, fbp: nil, fv: nil, gad_source: nil, gbraid: nil, gclid: nil, host: nil, iframe: nil, im_ref: nil, ip: nil, irclickid: nil, is_bot: nil, li_fat_id: nil, msclkid: nil, ndclid: nil, new_s: nil, os_name: nil, os_version: nil, page_hash: nil, pathname: nil, qclid: nil, rdt_cid: nil, received_at: nil, referrer: nil, referring_domain: nil, sacid: nil, sccid: nil, screen_height: nil, screen_width: nil, session_count: nil, sid: nil, sr: nil, title: nil, ttclid: nil, twclid: nil, uafvl: nil, user_agent: nil, utm_campaign: nil, utm_content: nil, utm_medium: nil, utm_name: nil, utm_source: nil, utm_term: nil, version: nil, wbraid: nil, webview: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see DefaultProperties for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(active_duration: nil, ad_id: nil, adset_id: nil, alart: nil, aleid: nil, axwrt: nil, basis_cid: nil, browser_language: nil, browser_name: nil, browser_version: nil, campaign_id: nil, clickid: nil, clid: nil, cpu_architecture: nil, current_url: nil, dclid: nil, device_model: nil, device_type: nil, device_vendor: nil, duration: nil, encoding: nil, engine_name: nil, engine_version: nil, epik: nil, fbc: nil, fbclid: nil, fbp: nil, fv: nil, gad_source: nil, gbraid: nil, gclid: nil, host: nil, iframe: nil, im_ref: nil, ip: nil, irclickid: nil, is_bot: nil, li_fat_id: nil, msclkid: nil, ndclid: nil, new_s: nil, os_name: nil, os_version: nil, page_hash: nil, pathname: nil, qclid: nil, rdt_cid: nil, received_at: nil, referrer: nil, referring_domain: nil, sacid: nil, sccid: nil, screen_height: nil, screen_width: nil, session_count: nil, sid: nil, sr: nil, title: nil, ttclid: nil, twclid: nil, uafvl: nil, user_agent: nil, utm_campaign: nil, utm_content: nil, utm_medium: nil, utm_name: nil, utm_source: nil, utm_term: nil, version: nil, wbraid: nil, webview: nil) ⇒ Object
Some parameter documentations has been truncated, see DefaultProperties for more details.
These properties are used throughout the Ours app to pass known values onto destinations
|
|
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 378
|
Instance Attribute Details
#default_properties ⇒ OursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties?
These properties are used throughout the Ours app to pass known values onto destinations
31 32 33 34 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 31 optional :default_properties, -> { OursprivacyIngest::VisitorUpsertParams::DefaultProperties }, api_name: :defaultProperties, nil?: true |
#email ⇒ String?
The email address of a user. We will associate this event with the user or create a user. Used for lookup if externalId and userId are not included in the request.
42 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 42 optional :email, String, nil?: true |
#external_id ⇒ String?
The externalId (the ID in your system) of a user. We will associate this event with the user or create a user. If included in the request, email lookup is ignored.
50 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 50 optional :external_id, String, api_name: :externalId, nil?: true |
#identity_context ⇒ OursprivacyIngest::Models::VisitorUpsertParams::IdentityContext?
End-user network context for server-side calls. Required for probabilistic identity resolution when the caller is a backend server rather than an end-user browser.
58 59 60 61 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 58 optional :identity_context, -> { OursprivacyIngest::VisitorUpsertParams::IdentityContext }, api_name: :identityContext, nil?: true |
#token ⇒ String
The token for your Source. You can find this in the dashboard.
14 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 14 required :token, String |
#user_id ⇒ String?
The Ours user id stored in local storage and cookies on your web properties. If userId is included in the request, we do not lookup the user by email or externalId.
69 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 69 optional :user_id, String, api_name: :userId, nil?: true |
#user_properties ⇒ OursprivacyIngest::Models::VisitorUpsertParams::UserProperties
User properties to associate with this user. The existing user properties will be updated. And all future events will have these properties associated with them.
22 23 24 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 22 required :user_properties, -> { OursprivacyIngest::VisitorUpsertParams::UserProperties }, api_name: :userProperties |