Class: OursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties
- Defined in:
- lib/oursprivacy_ingest/models/visitor_upsert_params.rb
Instance Attribute Summary collapse
-
#_ef_transaction_id ⇒ String?
The Everflow affiliate Click (Transaction) ID, captured from the ‘_ef_transaction_id` URL parameter.
-
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active.
-
#ad_id ⇒ String?
The ad id for detected in the session.
-
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID.
-
#adset_id ⇒ String?
The adset id for detected in the session.
-
#alart ⇒ String?
The AppLovin alart query parameter.
-
#aleid ⇒ String?
The AppLovin aleid query parameter.
-
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt).
-
#basis_cid ⇒ String?
The Basis DSP Click ID.
-
#beeswax_auction_id ⇒ String?
The Beeswax (FreeWheel Buyer Cloud) auction ID, captured from the ‘{AUCTION_ID}` macro on creative click URLs.
-
#browser_language ⇒ String?
The language of the browser.
-
#browser_name ⇒ String?
The name of the browser.
-
#browser_version ⇒ String?
The version of the browser.
-
#campaign_id ⇒ String?
The campaign id for detected in the session.
-
#clickid ⇒ String?
The Click ID.
-
#clid ⇒ String?
The Generic Click ID.
-
#cpu_architecture ⇒ String?
The architecture of the CPU.
-
#current_url ⇒ String?
The full url (including query params) of the current page.
-
#dclid ⇒ String?
The DoubleClick Click ID.
-
#device_model ⇒ String?
The model of the device.
-
#device_type ⇒ String?
The type of device the user is using.
-
#device_vendor ⇒ String?
The vendor of the device.
-
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded.
-
#encoding ⇒ String?
The browsers encoding.
-
#engine_name ⇒ String?
The name of the browser engine.
-
#engine_version ⇒ String?
The version of the browser engine.
-
#epik ⇒ String?
The Pinterest Click ID.
-
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking.
-
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks.
-
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events.
-
#fv ⇒ Boolean?
Deprecated.
-
#gad_source ⇒ String?
The Google Ad Source.
-
#gbraid ⇒ String?
The Google Braid ID.
-
#gclid ⇒ String?
The Google Click ID.
-
#host ⇒ String?
The host of the current page.
-
#iframe ⇒ Boolean?
Whether the user is in an iframe.
-
#im_ref ⇒ String?
The Impact Click ID reference.
-
#ip ⇒ String?
The IP address of the user.
-
#irclickid ⇒ String?
The Impact Click ID.
-
#is_bot ⇒ String?
Whether we have detected that the user is a bot.
-
#li_fat_id ⇒ String?
The LinkedIn Click ID.
-
#msclkid ⇒ String?
The Microsoft Click ID.
-
#ndclid ⇒ String?
The NextDoor Click ID.
-
#new_s ⇒ Boolean?
Deprecated.
-
#ob_click_id ⇒ String?
The Outbrain click ID, captured from the ‘ob_click_id` URL parameter (Outbrain `{ob_click_id}` macro) on the landing page.
-
#oppref ⇒ String?
The OpenAI Ads privacy-preserving reference, captured from the ‘oppref` URL parameter on landing pages (the OpenAI Pixel also stores it in a `__oppref` cookie).
-
#os_name ⇒ String?
The name of the operating system.
-
#os_version ⇒ String?
The version of the operating system.
-
#page_hash ⇒ Float?
A random set of numbers for the page load.
-
#pathname ⇒ String?
The pathname of the current page.
-
#qclid ⇒ String?
The Quora Click ID.
-
#rdt_cid ⇒ String?
The Reddit Click ID.
-
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format.
-
#referrer ⇒ String?
The referrer URL of the current page.
-
#referring_domain ⇒ String?
The referring domain of the current page.
-
#sacid ⇒ String?
The StackAdapt Tracking ID.
-
#sccid ⇒ String?
The SnapChat Click ID.
-
#screen_height ⇒ Float?
The height of the screen.
-
#screen_width ⇒ Float?
The width of the screen.
-
#session_count ⇒ Float?
The number of sessions the user has had.
-
#sid ⇒ String?
The session ID as assigned automatically by the web SDK.
- #sr ⇒ String?
-
#title ⇒ String?
The title of the current page.
-
#ttclid ⇒ String?
The TikTok Click ID.
-
#twclid ⇒ String?
The Twitter Click ID.
-
#uafvl ⇒ String?
User agent as a full list of strings.
-
#user_agent ⇒ String?
The user agent of the browser.
-
#utm_campaign ⇒ String?
The UTM Campaign.
-
#utm_content ⇒ String?
The UTM Content.
-
#utm_medium ⇒ String?
The UTM Medium.
-
#utm_name ⇒ String?
The UTM Name.
-
#utm_source ⇒ String?
The UTM Source.
-
#utm_term ⇒ String?
The UTM Term.
-
#version ⇒ String?
The version of the web SDK.
-
#viant_click_id ⇒ String?
The Viant (Adelphic) Click ID, captured from the ‘viant_click_id` URL parameter (Viant `$ADELPHIC_CLICKID` macro).
-
#viant_impression_id ⇒ String?
The Viant (Adelphic) Impression ID, captured from the ‘viant_impression_id` URL parameter (Viant `$ADELPHIC_IMPRESSIONID` macro).
-
#wbraid ⇒ String?
The WBRAID Identifier.
-
#webview ⇒ Boolean?
Whether the user is in a webview.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OursprivacyIngest::Internal::Type::BaseModel
Instance Attribute Details
#_ef_transaction_id ⇒ String?
The Everflow affiliate Click (Transaction) ID, captured from the ‘_ef_transaction_id` URL parameter. Ex: ef_click_abc123
556 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 556 optional :_ef_transaction_id, String, nil?: true |
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active
562 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 562 optional :active_duration, Float, api_name: :activeDuration, nil?: true |
#ad_id ⇒ String?
The ad id for detected in the session. This is set by the web sdk automatically.
568 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 568 optional :ad_id, String, nil?: true |
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID. Ex: admitad_uid_abc123
574 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 574 optional :admitad_uid, String, nil?: true |
#adset_id ⇒ String?
The adset id for detected in the session. This is set by the web sdk automatically.
581 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 581 optional :adset_id, String, nil?: true |
#alart ⇒ String?
The AppLovin alart query parameter. Ex: alart123
587 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 587 optional :alart, String, nil?: true |
#aleid ⇒ String?
The AppLovin aleid query parameter. Ex: aleid123
593 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 593 optional :aleid, String, nil?: true |
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt). Web-only.
599 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 599 optional :axwrt, String, nil?: true |
#basis_cid ⇒ String?
The Basis DSP Click ID. Ex: basis_cid123
605 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 605 optional :basis_cid, String, nil?: true |
#beeswax_auction_id ⇒ String?
The Beeswax (FreeWheel Buyer Cloud) auction ID, captured from the ‘{AUCTION_ID}` macro on creative click URLs. Ex: bx-auc-abc123
612 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 612 optional :beeswax_auction_id, String, nil?: true |
#browser_language ⇒ String?
The language of the browser. Ex: en-US
618 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 618 optional :browser_language, String, nil?: true |
#browser_name ⇒ String?
The name of the browser. Ex: Chrome
624 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 624 optional :browser_name, String, nil?: true |
#browser_version ⇒ String?
The version of the browser. Ex: 114.0
630 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 630 optional :browser_version, String, nil?: true |
#campaign_id ⇒ String?
The campaign id for detected in the session. This is set by the web sdk automatically.
637 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 637 optional :campaign_id, String, nil?: true |
#clickid ⇒ String?
The Click ID. Ex: clickid123
643 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 643 optional :clickid, String, nil?: true |
#clid ⇒ String?
The Generic Click ID. Ex: clid123
649 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 649 optional :clid, String, nil?: true |
#cpu_architecture ⇒ String?
The architecture of the CPU. Ex: x64
655 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 655 optional :cpu_architecture, String, nil?: true |
#current_url ⇒ String?
The full url (including query params) of the current page
661 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 661 optional :current_url, String, nil?: true |
#dclid ⇒ String?
The DoubleClick Click ID. Ex: dclid123
667 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 667 optional :dclid, String, nil?: true |
#device_model ⇒ String?
The model of the device. Ex: iPhone 13
673 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 673 optional :device_model, String, nil?: true |
#device_type ⇒ String?
The type of device the user is using. Ex: mobile
679 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 679 optional :device_type, String, nil?: true |
#device_vendor ⇒ String?
The vendor of the device. Ex: Apple
685 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 685 optional :device_vendor, String, nil?: true |
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded
691 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 691 optional :duration, Float, nil?: true |
#encoding ⇒ String?
The browsers encoding. Ex: UTF-8
697 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 697 optional :encoding, String, nil?: true |
#engine_name ⇒ String?
The name of the browser engine. Ex: Blink
703 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 703 optional :engine_name, String, nil?: true |
#engine_version ⇒ String?
The version of the browser engine. Ex: 114.0
709 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 709 optional :engine_version, String, nil?: true |
#epik ⇒ String?
The Pinterest Click ID. Ex: epik456
715 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 715 optional :epik, String, nil?: true |
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking. Ex: fb.1.1554763741205.AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
722 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 722 optional :fbc, String, nil?: true |
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks. Ex: AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
729 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 729 optional :fbclid, String, nil?: true |
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events. Ex: fb.1.1554763741205.1098115397
736 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 736 optional :fbp, String, nil?: true |
#fv ⇒ Boolean?
Deprecated
742 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 742 optional :fv, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#gad_source ⇒ String?
The Google Ad Source. Ex: google
748 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 748 optional :gad_source, String, nil?: true |
#gbraid ⇒ String?
The Google Braid ID. Ex: gbraid123
754 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 754 optional :gbraid, String, nil?: true |
#gclid ⇒ String?
The Google Click ID. Ex: gclid123
760 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 760 optional :gclid, String, nil?: true |
#host ⇒ String?
The host of the current page. Ex: example.com
766 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 766 optional :host, String, nil?: true |
#iframe ⇒ Boolean?
Whether the user is in an iframe. Ex: true
772 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 772 optional :iframe, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#im_ref ⇒ String?
The Impact Click ID reference. Ex: im_ref123
778 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 778 optional :im_ref, String, nil?: true |
#ip ⇒ String?
The IP address of the user. Ex: 127.0.0.1
784 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 784 optional :ip, String, nil?: true |
#irclickid ⇒ String?
The Impact Click ID. Ex: irclickid123
790 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 790 optional :irclickid, String, nil?: true |
#is_bot ⇒ String?
Whether we have detected that the user is a bot. This is set automatically by the Ours server primarily for events tracked through the web SDK.
797 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 797 optional :is_bot, String, nil?: true |
#li_fat_id ⇒ String?
The LinkedIn Click ID. Ex: li_fat_id123
803 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 803 optional :li_fat_id, String, nil?: true |
#msclkid ⇒ String?
The Microsoft Click ID. Ex: msclkid123
809 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 809 optional :msclkid, String, nil?: true |
#ndclid ⇒ String?
The NextDoor Click ID. Ex: ndclid123
815 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 815 optional :ndclid, String, nil?: true |
#new_s ⇒ Boolean?
Deprecated
821 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 821 optional :new_s, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#ob_click_id ⇒ String?
The Outbrain click ID, captured from the ‘ob_click_id` URL parameter (Outbrain `{ob_click_id}` macro) on the landing page. Ex: ob_click_abc123
828 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 828 optional :ob_click_id, String, nil?: true |
#oppref ⇒ String?
The OpenAI Ads privacy-preserving reference, captured from the ‘oppref` URL parameter on landing pages (the OpenAI Pixel also stores it in a `__oppref` cookie). Sent to OpenAI Ads on Conversions API events for attribution. Ex: oppref_abc
837 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 837 optional :oppref, String, nil?: true |
#os_name ⇒ String?
The name of the operating system. Ex: Windows
843 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 843 optional :os_name, String, nil?: true |
#os_version ⇒ String?
The version of the operating system. Ex: 10.0
849 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 849 optional :os_version, String, nil?: true |
#page_hash ⇒ Float?
A random set of numbers for the page load
855 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 855 optional :page_hash, Float, nil?: true |
#pathname ⇒ String?
The pathname of the current page. Ex: /home
861 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 861 optional :pathname, String, nil?: true |
#qclid ⇒ String?
The Quora Click ID. Ex: qclid123
867 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 867 optional :qclid, String, nil?: true |
#rdt_cid ⇒ String?
The Reddit Click ID. Ex: rdt_cid123
873 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 873 optional :rdt_cid, String, nil?: true |
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format
879 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 879 optional :received_at, String, nil?: true |
#referrer ⇒ String?
The referrer URL of the current page
885 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 885 optional :referrer, String, nil?: true |
#referring_domain ⇒ String?
The referring domain of the current page
891 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 891 optional :referring_domain, String, nil?: true |
#sacid ⇒ String?
The StackAdapt Tracking ID. Ex: sacid123
897 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 897 optional :sacid, String, nil?: true |
#sccid ⇒ String?
The SnapChat Click ID. Ex: sccid123
903 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 903 optional :sccid, String, nil?: true |
#screen_height ⇒ Float?
The height of the screen. Ex: 1080
909 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 909 optional :screen_height, Float, nil?: true |
#screen_width ⇒ Float?
The width of the screen. Ex: 1920
915 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 915 optional :screen_width, Float, nil?: true |
#session_count ⇒ Float?
The number of sessions the user has had. Ex: 3
921 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 921 optional :session_count, Float, api_name: :sessionCount, nil?: true |
#sid ⇒ String?
The session ID as assigned automatically by the web SDK. This is required for session replay
928 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 928 optional :sid, String, nil?: true |
#sr ⇒ String?
933 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 933 optional :sr, String, nil?: true |
#title ⇒ String?
The title of the current page
939 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 939 optional :title, String, nil?: true |
#ttclid ⇒ String?
The TikTok Click ID. Ex: ttclid123
945 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 945 optional :ttclid, String, nil?: true |
#twclid ⇒ String?
The Twitter Click ID. Ex: twclid123
951 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 951 optional :twclid, String, nil?: true |
#uafvl ⇒ String?
User agent as a full list of strings.
957 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 957 optional :uafvl, String, nil?: true |
#user_agent ⇒ String?
The user agent of the browser
963 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 963 optional :user_agent, String, nil?: true |
#utm_campaign ⇒ String?
The UTM Campaign. The web SDK automatically captures this from the query params.
969 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 969 optional :utm_campaign, String, nil?: true |
#utm_content ⇒ String?
The UTM Content. The web SDK automatically captures this from the query params.
975 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 975 optional :utm_content, String, nil?: true |
#utm_medium ⇒ String?
The UTM Medium. The web SDK automatically captures this from the query params.
981 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 981 optional :utm_medium, String, nil?: true |
#utm_name ⇒ String?
The UTM Name. The web SDK automatically captures this from the query params.
987 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 987 optional :utm_name, String, nil?: true |
#utm_source ⇒ String?
The UTM Source. The web SDK automatically captures this from the query params.
993 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 993 optional :utm_source, String, nil?: true |
#utm_term ⇒ String?
The UTM Term. The web SDK automatically captures this from the query params.
999 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 999 optional :utm_term, String, nil?: true |
#version ⇒ String?
The version of the web SDK
1005 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 1005 optional :version, String, nil?: true |
#viant_click_id ⇒ String?
The Viant (Adelphic) Click ID, captured from the ‘viant_click_id` URL parameter (Viant `$ADELPHIC_CLICKID` macro). Sent as `xid` on Viant postbacks. Ex: viant_click_abc123
1013 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 1013 optional :viant_click_id, String, nil?: true |
#viant_impression_id ⇒ String?
The Viant (Adelphic) Impression ID, captured from the ‘viant_impression_id` URL parameter (Viant `$ADELPHIC_IMPRESSIONID` macro). Sent as `imp_id` on Viant postbacks for post-view attribution. Ex: viant_imp_abc123
1021 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 1021 optional :viant_impression_id, String, nil?: true |
#wbraid ⇒ String?
The WBRAID Identifier. The web SDK automatically captures this from the query params.
1028 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 1028 optional :wbraid, String, nil?: true |
#webview ⇒ Boolean?
Whether the user is in a webview. Ex: true
1034 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 1034 optional :webview, OursprivacyIngest::Internal::Type::Boolean, nil?: true |