Class: OursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties
- Defined in:
- lib/oursprivacy_ingest/models/visitor_upsert_params.rb
Instance Attribute Summary collapse
-
#_ef_transaction_id ⇒ String?
The Everflow affiliate Click (Transaction) ID, captured from the ‘_ef_transaction_id` URL parameter.
-
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active.
-
#ad_id ⇒ String?
The ad id for detected in the session.
-
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID.
-
#adset_id ⇒ String?
The adset id for detected in the session.
-
#alart ⇒ String?
The AppLovin alart query parameter.
-
#aleid ⇒ String?
The AppLovin aleid query parameter.
-
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt).
-
#basis_cid ⇒ String?
The Basis DSP Click ID.
-
#beeswax_auction_id ⇒ String?
The Beeswax (FreeWheel Buyer Cloud) auction ID, captured from the ‘{AUCTION_ID}` macro on creative click URLs.
-
#browser_language ⇒ String?
The language of the browser.
-
#browser_name ⇒ String?
The name of the browser.
-
#browser_version ⇒ String?
The version of the browser.
-
#campaign_id ⇒ String?
The campaign id for detected in the session.
-
#clickid ⇒ String?
The Click ID.
-
#clid ⇒ String?
The Generic Click ID.
-
#cpu_architecture ⇒ String?
The architecture of the CPU.
-
#current_url ⇒ String?
The full url (including query params) of the current page.
-
#dclid ⇒ String?
The DoubleClick Click ID.
-
#device_model ⇒ String?
The model of the device.
-
#device_type ⇒ String?
The type of device the user is using.
-
#device_vendor ⇒ String?
The vendor of the device.
-
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded.
-
#encoding ⇒ String?
The browsers encoding.
-
#engine_name ⇒ String?
The name of the browser engine.
-
#engine_version ⇒ String?
The version of the browser engine.
-
#epik ⇒ String?
The Pinterest Click ID.
-
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking.
-
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks.
-
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events.
-
#fv ⇒ Boolean?
Deprecated.
-
#gad_source ⇒ String?
The Google Ad Source.
-
#gbraid ⇒ String?
The Google Braid ID.
-
#gclid ⇒ String?
The Google Click ID.
-
#host ⇒ String?
The host of the current page.
-
#iframe ⇒ Boolean?
Whether the user is in an iframe.
-
#im_ref ⇒ String?
The Impact Click ID reference.
-
#ip ⇒ String?
The IP address of the user.
-
#irclickid ⇒ String?
The Impact Click ID.
-
#is_bot ⇒ String?
Whether we have detected that the user is a bot.
-
#li_fat_id ⇒ String?
The LinkedIn Click ID.
-
#msclkid ⇒ String?
The Microsoft Click ID.
-
#ndclid ⇒ String?
The NextDoor Click ID.
-
#new_s ⇒ Boolean?
Deprecated.
-
#os_name ⇒ String?
The name of the operating system.
-
#os_version ⇒ String?
The version of the operating system.
-
#page_hash ⇒ Float?
A random set of numbers for the page load.
-
#pathname ⇒ String?
The pathname of the current page.
-
#qclid ⇒ String?
The Quora Click ID.
-
#rdt_cid ⇒ String?
The Reddit Click ID.
-
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format.
-
#referrer ⇒ String?
The referrer URL of the current page.
-
#referring_domain ⇒ String?
The referring domain of the current page.
-
#sacid ⇒ String?
The StackAdapt Tracking ID.
-
#sccid ⇒ String?
The SnapChat Click ID.
-
#screen_height ⇒ Float?
The height of the screen.
-
#screen_width ⇒ Float?
The width of the screen.
-
#session_count ⇒ Float?
The number of sessions the user has had.
-
#sid ⇒ String?
The session ID as assigned automatically by the web SDK.
- #sr ⇒ String?
-
#title ⇒ String?
The title of the current page.
-
#ttclid ⇒ String?
The TikTok Click ID.
-
#twclid ⇒ String?
The Twitter Click ID.
-
#uafvl ⇒ String?
User agent as a full list of strings.
-
#user_agent ⇒ String?
The user agent of the browser.
-
#utm_campaign ⇒ String?
The UTM Campaign.
-
#utm_content ⇒ String?
The UTM Content.
-
#utm_medium ⇒ String?
The UTM Medium.
-
#utm_name ⇒ String?
The UTM Name.
-
#utm_source ⇒ String?
The UTM Source.
-
#utm_term ⇒ String?
The UTM Term.
-
#version ⇒ String?
The version of the web SDK.
-
#wbraid ⇒ String?
The WBRAID Identifier.
-
#webview ⇒ Boolean?
Whether the user is in a webview.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OursprivacyIngest::Internal::Type::BaseModel
Instance Attribute Details
#_ef_transaction_id ⇒ String?
The Everflow affiliate Click (Transaction) ID, captured from the ‘_ef_transaction_id` URL parameter. Ex: ef_click_abc123
528 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 528 optional :_ef_transaction_id, String, nil?: true |
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active
534 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 534 optional :active_duration, Float, api_name: :activeDuration, nil?: true |
#ad_id ⇒ String?
The ad id for detected in the session. This is set by the web sdk automatically.
540 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 540 optional :ad_id, String, nil?: true |
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID. Ex: admitad_uid_abc123
546 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 546 optional :admitad_uid, String, nil?: true |
#adset_id ⇒ String?
The adset id for detected in the session. This is set by the web sdk automatically.
553 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 553 optional :adset_id, String, nil?: true |
#alart ⇒ String?
The AppLovin alart query parameter. Ex: alart123
559 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 559 optional :alart, String, nil?: true |
#aleid ⇒ String?
The AppLovin aleid query parameter. Ex: aleid123
565 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 565 optional :aleid, String, nil?: true |
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt). Web-only.
571 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 571 optional :axwrt, String, nil?: true |
#basis_cid ⇒ String?
The Basis DSP Click ID. Ex: basis_cid123
577 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 577 optional :basis_cid, String, nil?: true |
#beeswax_auction_id ⇒ String?
The Beeswax (FreeWheel Buyer Cloud) auction ID, captured from the ‘{AUCTION_ID}` macro on creative click URLs. Ex: bx-auc-abc123
584 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 584 optional :beeswax_auction_id, String, nil?: true |
#browser_language ⇒ String?
The language of the browser. Ex: en-US
590 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 590 optional :browser_language, String, nil?: true |
#browser_name ⇒ String?
The name of the browser. Ex: Chrome
596 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 596 optional :browser_name, String, nil?: true |
#browser_version ⇒ String?
The version of the browser. Ex: 114.0
602 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 602 optional :browser_version, String, nil?: true |
#campaign_id ⇒ String?
The campaign id for detected in the session. This is set by the web sdk automatically.
609 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 609 optional :campaign_id, String, nil?: true |
#clickid ⇒ String?
The Click ID. Ex: clickid123
615 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 615 optional :clickid, String, nil?: true |
#clid ⇒ String?
The Generic Click ID. Ex: clid123
621 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 621 optional :clid, String, nil?: true |
#cpu_architecture ⇒ String?
The architecture of the CPU. Ex: x64
627 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 627 optional :cpu_architecture, String, nil?: true |
#current_url ⇒ String?
The full url (including query params) of the current page
633 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 633 optional :current_url, String, nil?: true |
#dclid ⇒ String?
The DoubleClick Click ID. Ex: dclid123
639 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 639 optional :dclid, String, nil?: true |
#device_model ⇒ String?
The model of the device. Ex: iPhone 13
645 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 645 optional :device_model, String, nil?: true |
#device_type ⇒ String?
The type of device the user is using. Ex: mobile
651 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 651 optional :device_type, String, nil?: true |
#device_vendor ⇒ String?
The vendor of the device. Ex: Apple
657 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 657 optional :device_vendor, String, nil?: true |
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded
663 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 663 optional :duration, Float, nil?: true |
#encoding ⇒ String?
The browsers encoding. Ex: UTF-8
669 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 669 optional :encoding, String, nil?: true |
#engine_name ⇒ String?
The name of the browser engine. Ex: Blink
675 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 675 optional :engine_name, String, nil?: true |
#engine_version ⇒ String?
The version of the browser engine. Ex: 114.0
681 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 681 optional :engine_version, String, nil?: true |
#epik ⇒ String?
The Pinterest Click ID. Ex: epik456
687 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 687 optional :epik, String, nil?: true |
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking. Ex: fb.1.1554763741205.AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
694 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 694 optional :fbc, String, nil?: true |
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks. Ex: AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
701 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 701 optional :fbclid, String, nil?: true |
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events. Ex: fb.1.1554763741205.1098115397
708 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 708 optional :fbp, String, nil?: true |
#fv ⇒ Boolean?
Deprecated
714 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 714 optional :fv, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#gad_source ⇒ String?
The Google Ad Source. Ex: google
720 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 720 optional :gad_source, String, nil?: true |
#gbraid ⇒ String?
The Google Braid ID. Ex: gbraid123
726 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 726 optional :gbraid, String, nil?: true |
#gclid ⇒ String?
The Google Click ID. Ex: gclid123
732 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 732 optional :gclid, String, nil?: true |
#host ⇒ String?
The host of the current page. Ex: example.com
738 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 738 optional :host, String, nil?: true |
#iframe ⇒ Boolean?
Whether the user is in an iframe. Ex: true
744 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 744 optional :iframe, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#im_ref ⇒ String?
The Impact Click ID reference. Ex: im_ref123
750 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 750 optional :im_ref, String, nil?: true |
#ip ⇒ String?
The IP address of the user. Ex: 127.0.0.1
756 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 756 optional :ip, String, nil?: true |
#irclickid ⇒ String?
The Impact Click ID. Ex: irclickid123
762 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 762 optional :irclickid, String, nil?: true |
#is_bot ⇒ String?
Whether we have detected that the user is a bot. This is set automatically by the Ours server primarily for events tracked through the web SDK.
769 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 769 optional :is_bot, String, nil?: true |
#li_fat_id ⇒ String?
The LinkedIn Click ID. Ex: li_fat_id123
775 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 775 optional :li_fat_id, String, nil?: true |
#msclkid ⇒ String?
The Microsoft Click ID. Ex: msclkid123
781 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 781 optional :msclkid, String, nil?: true |
#ndclid ⇒ String?
The NextDoor Click ID. Ex: ndclid123
787 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 787 optional :ndclid, String, nil?: true |
#new_s ⇒ Boolean?
Deprecated
793 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 793 optional :new_s, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#os_name ⇒ String?
The name of the operating system. Ex: Windows
799 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 799 optional :os_name, String, nil?: true |
#os_version ⇒ String?
The version of the operating system. Ex: 10.0
805 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 805 optional :os_version, String, nil?: true |
#page_hash ⇒ Float?
A random set of numbers for the page load
811 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 811 optional :page_hash, Float, nil?: true |
#pathname ⇒ String?
The pathname of the current page. Ex: /home
817 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 817 optional :pathname, String, nil?: true |
#qclid ⇒ String?
The Quora Click ID. Ex: qclid123
823 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 823 optional :qclid, String, nil?: true |
#rdt_cid ⇒ String?
The Reddit Click ID. Ex: rdt_cid123
829 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 829 optional :rdt_cid, String, nil?: true |
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format
835 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 835 optional :received_at, String, nil?: true |
#referrer ⇒ String?
The referrer URL of the current page
841 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 841 optional :referrer, String, nil?: true |
#referring_domain ⇒ String?
The referring domain of the current page
847 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 847 optional :referring_domain, String, nil?: true |
#sacid ⇒ String?
The StackAdapt Tracking ID. Ex: sacid123
853 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 853 optional :sacid, String, nil?: true |
#sccid ⇒ String?
The SnapChat Click ID. Ex: sccid123
859 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 859 optional :sccid, String, nil?: true |
#screen_height ⇒ Float?
The height of the screen. Ex: 1080
865 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 865 optional :screen_height, Float, nil?: true |
#screen_width ⇒ Float?
The width of the screen. Ex: 1920
871 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 871 optional :screen_width, Float, nil?: true |
#session_count ⇒ Float?
The number of sessions the user has had. Ex: 3
877 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 877 optional :session_count, Float, api_name: :sessionCount, nil?: true |
#sid ⇒ String?
The session ID as assigned automatically by the web SDK. This is required for session replay
884 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 884 optional :sid, String, nil?: true |
#sr ⇒ String?
889 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 889 optional :sr, String, nil?: true |
#title ⇒ String?
The title of the current page
895 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 895 optional :title, String, nil?: true |
#ttclid ⇒ String?
The TikTok Click ID. Ex: ttclid123
901 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 901 optional :ttclid, String, nil?: true |
#twclid ⇒ String?
The Twitter Click ID. Ex: twclid123
907 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 907 optional :twclid, String, nil?: true |
#uafvl ⇒ String?
User agent as a full list of strings.
913 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 913 optional :uafvl, String, nil?: true |
#user_agent ⇒ String?
The user agent of the browser
919 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 919 optional :user_agent, String, nil?: true |
#utm_campaign ⇒ String?
The UTM Campaign. The web SDK automatically captures this from the query params.
925 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 925 optional :utm_campaign, String, nil?: true |
#utm_content ⇒ String?
The UTM Content. The web SDK automatically captures this from the query params.
931 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 931 optional :utm_content, String, nil?: true |
#utm_medium ⇒ String?
The UTM Medium. The web SDK automatically captures this from the query params.
937 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 937 optional :utm_medium, String, nil?: true |
#utm_name ⇒ String?
The UTM Name. The web SDK automatically captures this from the query params.
943 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 943 optional :utm_name, String, nil?: true |
#utm_source ⇒ String?
The UTM Source. The web SDK automatically captures this from the query params.
949 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 949 optional :utm_source, String, nil?: true |
#utm_term ⇒ String?
The UTM Term. The web SDK automatically captures this from the query params.
955 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 955 optional :utm_term, String, nil?: true |
#version ⇒ String?
The version of the web SDK
961 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 961 optional :version, String, nil?: true |
#wbraid ⇒ String?
The WBRAID Identifier. The web SDK automatically captures this from the query params.
968 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 968 optional :wbraid, String, nil?: true |
#webview ⇒ Boolean?
Whether the user is in a webview. Ex: true
974 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 974 optional :webview, OursprivacyIngest::Internal::Type::Boolean, nil?: true |