Class: OursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties
- Defined in:
- lib/oursprivacy_ingest/models/visitor_upsert_params.rb
Instance Attribute Summary collapse
-
#_ef_transaction_id ⇒ String?
The Everflow affiliate Click (Transaction) ID, captured from the ‘_ef_transaction_id` URL parameter.
-
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active.
-
#ad_id ⇒ String?
The ad id for detected in the session.
-
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID.
-
#adset_id ⇒ String?
The adset id for detected in the session.
-
#alart ⇒ String?
The AppLovin alart query parameter.
-
#aleid ⇒ String?
The AppLovin aleid query parameter.
-
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt).
-
#basis_cid ⇒ String?
The Basis DSP Click ID.
-
#browser_language ⇒ String?
The language of the browser.
-
#browser_name ⇒ String?
The name of the browser.
-
#browser_version ⇒ String?
The version of the browser.
-
#campaign_id ⇒ String?
The campaign id for detected in the session.
-
#clickid ⇒ String?
The Click ID.
-
#clid ⇒ String?
The Generic Click ID.
-
#cpu_architecture ⇒ String?
The architecture of the CPU.
-
#current_url ⇒ String?
The full url (including query params) of the current page.
-
#dclid ⇒ String?
The DoubleClick Click ID.
-
#device_model ⇒ String?
The model of the device.
-
#device_type ⇒ String?
The type of device the user is using.
-
#device_vendor ⇒ String?
The vendor of the device.
-
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded.
-
#encoding ⇒ String?
The browsers encoding.
-
#engine_name ⇒ String?
The name of the browser engine.
-
#engine_version ⇒ String?
The version of the browser engine.
-
#epik ⇒ String?
The Pinterest Click ID.
-
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking.
-
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks.
-
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events.
-
#fv ⇒ Boolean?
Deprecated.
-
#gad_source ⇒ String?
The Google Ad Source.
-
#gbraid ⇒ String?
The Google Braid ID.
-
#gclid ⇒ String?
The Google Click ID.
-
#host ⇒ String?
The host of the current page.
-
#iframe ⇒ Boolean?
Whether the user is in an iframe.
-
#im_ref ⇒ String?
The Impact Click ID reference.
-
#ip ⇒ String?
The IP address of the user.
-
#irclickid ⇒ String?
The Impact Click ID.
-
#is_bot ⇒ String?
Whether we have detected that the user is a bot.
-
#li_fat_id ⇒ String?
The LinkedIn Click ID.
-
#msclkid ⇒ String?
The Microsoft Click ID.
-
#ndclid ⇒ String?
The NextDoor Click ID.
-
#new_s ⇒ Boolean?
Deprecated.
-
#os_name ⇒ String?
The name of the operating system.
-
#os_version ⇒ String?
The version of the operating system.
-
#page_hash ⇒ Float?
A random set of numbers for the page load.
-
#pathname ⇒ String?
The pathname of the current page.
-
#qclid ⇒ String?
The Quora Click ID.
-
#rdt_cid ⇒ String?
The Reddit Click ID.
-
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format.
-
#referrer ⇒ String?
The referrer URL of the current page.
-
#referring_domain ⇒ String?
The referring domain of the current page.
-
#sacid ⇒ String?
The StackAdapt Tracking ID.
-
#sccid ⇒ String?
The SnapChat Click ID.
-
#screen_height ⇒ Float?
The height of the screen.
-
#screen_width ⇒ Float?
The width of the screen.
-
#session_count ⇒ Float?
The number of sessions the user has had.
-
#sid ⇒ String?
The session ID as assigned automatically by the web SDK.
- #sr ⇒ String?
-
#title ⇒ String?
The title of the current page.
-
#ttclid ⇒ String?
The TikTok Click ID.
-
#twclid ⇒ String?
The Twitter Click ID.
-
#uafvl ⇒ String?
User agent as a full list of strings.
-
#user_agent ⇒ String?
The user agent of the browser.
-
#utm_campaign ⇒ String?
The UTM Campaign.
-
#utm_content ⇒ String?
The UTM Content.
-
#utm_medium ⇒ String?
The UTM Medium.
-
#utm_name ⇒ String?
The UTM Name.
-
#utm_source ⇒ String?
The UTM Source.
-
#utm_term ⇒ String?
The UTM Term.
-
#version ⇒ String?
The version of the web SDK.
-
#wbraid ⇒ String?
The WBRAID Identifier.
-
#webview ⇒ Boolean?
Whether the user is in a webview.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OursprivacyIngest::Internal::Type::BaseModel
Instance Attribute Details
#_ef_transaction_id ⇒ String?
The Everflow affiliate Click (Transaction) ID, captured from the ‘_ef_transaction_id` URL parameter. Ex: ef_click_abc123
521 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 521 optional :_ef_transaction_id, String, nil?: true |
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active
527 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 527 optional :active_duration, Float, api_name: :activeDuration, nil?: true |
#ad_id ⇒ String?
The ad id for detected in the session. This is set by the web sdk automatically.
533 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 533 optional :ad_id, String, nil?: true |
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID. Ex: admitad_uid_abc123
539 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 539 optional :admitad_uid, String, nil?: true |
#adset_id ⇒ String?
The adset id for detected in the session. This is set by the web sdk automatically.
546 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 546 optional :adset_id, String, nil?: true |
#alart ⇒ String?
The AppLovin alart query parameter. Ex: alart123
552 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 552 optional :alart, String, nil?: true |
#aleid ⇒ String?
The AppLovin aleid query parameter. Ex: aleid123
558 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 558 optional :aleid, String, nil?: true |
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt). Web-only.
564 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 564 optional :axwrt, String, nil?: true |
#basis_cid ⇒ String?
The Basis DSP Click ID. Ex: basis_cid123
570 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 570 optional :basis_cid, String, nil?: true |
#browser_language ⇒ String?
The language of the browser. Ex: en-US
576 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 576 optional :browser_language, String, nil?: true |
#browser_name ⇒ String?
The name of the browser. Ex: Chrome
582 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 582 optional :browser_name, String, nil?: true |
#browser_version ⇒ String?
The version of the browser. Ex: 114.0
588 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 588 optional :browser_version, String, nil?: true |
#campaign_id ⇒ String?
The campaign id for detected in the session. This is set by the web sdk automatically.
595 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 595 optional :campaign_id, String, nil?: true |
#clickid ⇒ String?
The Click ID. Ex: clickid123
601 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 601 optional :clickid, String, nil?: true |
#clid ⇒ String?
The Generic Click ID. Ex: clid123
607 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 607 optional :clid, String, nil?: true |
#cpu_architecture ⇒ String?
The architecture of the CPU. Ex: x64
613 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 613 optional :cpu_architecture, String, nil?: true |
#current_url ⇒ String?
The full url (including query params) of the current page
619 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 619 optional :current_url, String, nil?: true |
#dclid ⇒ String?
The DoubleClick Click ID. Ex: dclid123
625 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 625 optional :dclid, String, nil?: true |
#device_model ⇒ String?
The model of the device. Ex: iPhone 13
631 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 631 optional :device_model, String, nil?: true |
#device_type ⇒ String?
The type of device the user is using. Ex: mobile
637 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 637 optional :device_type, String, nil?: true |
#device_vendor ⇒ String?
The vendor of the device. Ex: Apple
643 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 643 optional :device_vendor, String, nil?: true |
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded
649 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 649 optional :duration, Float, nil?: true |
#encoding ⇒ String?
The browsers encoding. Ex: UTF-8
655 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 655 optional :encoding, String, nil?: true |
#engine_name ⇒ String?
The name of the browser engine. Ex: Blink
661 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 661 optional :engine_name, String, nil?: true |
#engine_version ⇒ String?
The version of the browser engine. Ex: 114.0
667 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 667 optional :engine_version, String, nil?: true |
#epik ⇒ String?
The Pinterest Click ID. Ex: epik456
673 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 673 optional :epik, String, nil?: true |
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking. Ex: fb.1.1554763741205.AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
680 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 680 optional :fbc, String, nil?: true |
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks. Ex: AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
687 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 687 optional :fbclid, String, nil?: true |
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events. Ex: fb.1.1554763741205.1098115397
694 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 694 optional :fbp, String, nil?: true |
#fv ⇒ Boolean?
Deprecated
700 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 700 optional :fv, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#gad_source ⇒ String?
The Google Ad Source. Ex: google
706 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 706 optional :gad_source, String, nil?: true |
#gbraid ⇒ String?
The Google Braid ID. Ex: gbraid123
712 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 712 optional :gbraid, String, nil?: true |
#gclid ⇒ String?
The Google Click ID. Ex: gclid123
718 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 718 optional :gclid, String, nil?: true |
#host ⇒ String?
The host of the current page. Ex: example.com
724 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 724 optional :host, String, nil?: true |
#iframe ⇒ Boolean?
Whether the user is in an iframe. Ex: true
730 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 730 optional :iframe, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#im_ref ⇒ String?
The Impact Click ID reference. Ex: im_ref123
736 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 736 optional :im_ref, String, nil?: true |
#ip ⇒ String?
The IP address of the user. Ex: 127.0.0.1
742 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 742 optional :ip, String, nil?: true |
#irclickid ⇒ String?
The Impact Click ID. Ex: irclickid123
748 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 748 optional :irclickid, String, nil?: true |
#is_bot ⇒ String?
Whether we have detected that the user is a bot. This is set automatically by the Ours server primarily for events tracked through the web SDK.
755 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 755 optional :is_bot, String, nil?: true |
#li_fat_id ⇒ String?
The LinkedIn Click ID. Ex: li_fat_id123
761 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 761 optional :li_fat_id, String, nil?: true |
#msclkid ⇒ String?
The Microsoft Click ID. Ex: msclkid123
767 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 767 optional :msclkid, String, nil?: true |
#ndclid ⇒ String?
The NextDoor Click ID. Ex: ndclid123
773 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 773 optional :ndclid, String, nil?: true |
#new_s ⇒ Boolean?
Deprecated
779 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 779 optional :new_s, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#os_name ⇒ String?
The name of the operating system. Ex: Windows
785 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 785 optional :os_name, String, nil?: true |
#os_version ⇒ String?
The version of the operating system. Ex: 10.0
791 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 791 optional :os_version, String, nil?: true |
#page_hash ⇒ Float?
A random set of numbers for the page load
797 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 797 optional :page_hash, Float, nil?: true |
#pathname ⇒ String?
The pathname of the current page. Ex: /home
803 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 803 optional :pathname, String, nil?: true |
#qclid ⇒ String?
The Quora Click ID. Ex: qclid123
809 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 809 optional :qclid, String, nil?: true |
#rdt_cid ⇒ String?
The Reddit Click ID. Ex: rdt_cid123
815 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 815 optional :rdt_cid, String, nil?: true |
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format
821 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 821 optional :received_at, String, nil?: true |
#referrer ⇒ String?
The referrer URL of the current page
827 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 827 optional :referrer, String, nil?: true |
#referring_domain ⇒ String?
The referring domain of the current page
833 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 833 optional :referring_domain, String, nil?: true |
#sacid ⇒ String?
The StackAdapt Tracking ID. Ex: sacid123
839 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 839 optional :sacid, String, nil?: true |
#sccid ⇒ String?
The SnapChat Click ID. Ex: sccid123
845 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 845 optional :sccid, String, nil?: true |
#screen_height ⇒ Float?
The height of the screen. Ex: 1080
851 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 851 optional :screen_height, Float, nil?: true |
#screen_width ⇒ Float?
The width of the screen. Ex: 1920
857 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 857 optional :screen_width, Float, nil?: true |
#session_count ⇒ Float?
The number of sessions the user has had. Ex: 3
863 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 863 optional :session_count, Float, api_name: :sessionCount, nil?: true |
#sid ⇒ String?
The session ID as assigned automatically by the web SDK. This is required for session replay
870 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 870 optional :sid, String, nil?: true |
#sr ⇒ String?
875 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 875 optional :sr, String, nil?: true |
#title ⇒ String?
The title of the current page
881 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 881 optional :title, String, nil?: true |
#ttclid ⇒ String?
The TikTok Click ID. Ex: ttclid123
887 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 887 optional :ttclid, String, nil?: true |
#twclid ⇒ String?
The Twitter Click ID. Ex: twclid123
893 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 893 optional :twclid, String, nil?: true |
#uafvl ⇒ String?
User agent as a full list of strings.
899 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 899 optional :uafvl, String, nil?: true |
#user_agent ⇒ String?
The user agent of the browser
905 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 905 optional :user_agent, String, nil?: true |
#utm_campaign ⇒ String?
The UTM Campaign. The web SDK automatically captures this from the query params.
911 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 911 optional :utm_campaign, String, nil?: true |
#utm_content ⇒ String?
The UTM Content. The web SDK automatically captures this from the query params.
917 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 917 optional :utm_content, String, nil?: true |
#utm_medium ⇒ String?
The UTM Medium. The web SDK automatically captures this from the query params.
923 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 923 optional :utm_medium, String, nil?: true |
#utm_name ⇒ String?
The UTM Name. The web SDK automatically captures this from the query params.
929 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 929 optional :utm_name, String, nil?: true |
#utm_source ⇒ String?
The UTM Source. The web SDK automatically captures this from the query params.
935 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 935 optional :utm_source, String, nil?: true |
#utm_term ⇒ String?
The UTM Term. The web SDK automatically captures this from the query params.
941 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 941 optional :utm_term, String, nil?: true |
#version ⇒ String?
The version of the web SDK
947 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 947 optional :version, String, nil?: true |
#wbraid ⇒ String?
The WBRAID Identifier. The web SDK automatically captures this from the query params.
954 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 954 optional :wbraid, String, nil?: true |
#webview ⇒ Boolean?
Whether the user is in a webview. Ex: true
960 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 960 optional :webview, OursprivacyIngest::Internal::Type::Boolean, nil?: true |