Class: OursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties
- Defined in:
- lib/oursprivacy_ingest/models/visitor_upsert_params.rb
Instance Attribute Summary collapse
-
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active.
-
#ad_id ⇒ String?
The ad id for detected in the session.
-
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID.
-
#adset_id ⇒ String?
The adset id for detected in the session.
-
#alart ⇒ String?
The AppLovin alart query parameter.
-
#aleid ⇒ String?
The AppLovin aleid query parameter.
-
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt).
-
#basis_cid ⇒ String?
The Basis DSP Click ID.
-
#browser_language ⇒ String?
The language of the browser.
-
#browser_name ⇒ String?
The name of the browser.
-
#browser_version ⇒ String?
The version of the browser.
-
#campaign_id ⇒ String?
The campaign id for detected in the session.
-
#clickid ⇒ String?
The Click ID.
-
#clid ⇒ String?
The Generic Click ID.
-
#cpu_architecture ⇒ String?
The architecture of the CPU.
-
#current_url ⇒ String?
The full url (including query params) of the current page.
-
#dclid ⇒ String?
The DoubleClick Click ID.
-
#device_model ⇒ String?
The model of the device.
-
#device_type ⇒ String?
The type of device the user is using.
-
#device_vendor ⇒ String?
The vendor of the device.
-
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded.
-
#encoding ⇒ String?
The browsers encoding.
-
#engine_name ⇒ String?
The name of the browser engine.
-
#engine_version ⇒ String?
The version of the browser engine.
-
#epik ⇒ String?
The Pinterest Click ID.
-
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking.
-
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks.
-
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events.
-
#fv ⇒ Boolean?
Deprecated.
-
#gad_source ⇒ String?
The Google Ad Source.
-
#gbraid ⇒ String?
The Google Braid ID.
-
#gclid ⇒ String?
The Google Click ID.
-
#host ⇒ String?
The host of the current page.
-
#iframe ⇒ Boolean?
Whether the user is in an iframe.
-
#im_ref ⇒ String?
The Impact Click ID reference.
-
#ip ⇒ String?
The IP address of the user.
-
#irclickid ⇒ String?
The Impact Click ID.
-
#is_bot ⇒ String?
Whether we have detected that the user is a bot.
-
#li_fat_id ⇒ String?
The LinkedIn Click ID.
-
#msclkid ⇒ String?
The Microsoft Click ID.
-
#ndclid ⇒ String?
The NextDoor Click ID.
-
#new_s ⇒ Boolean?
Deprecated.
-
#os_name ⇒ String?
The name of the operating system.
-
#os_version ⇒ String?
The version of the operating system.
-
#page_hash ⇒ Float?
A random set of numbers for the page load.
-
#pathname ⇒ String?
The pathname of the current page.
-
#qclid ⇒ String?
The Quora Click ID.
-
#rdt_cid ⇒ String?
The Reddit Click ID.
-
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format.
-
#referrer ⇒ String?
The referrer URL of the current page.
-
#referring_domain ⇒ String?
The referring domain of the current page.
-
#sacid ⇒ String?
The StackAdapt Tracking ID.
-
#sccid ⇒ String?
The SnapChat Click ID.
-
#screen_height ⇒ Float?
The height of the screen.
-
#screen_width ⇒ Float?
The width of the screen.
-
#session_count ⇒ Float?
The number of sessions the user has had.
-
#sid ⇒ String?
The session ID as assigned automatically by the web SDK.
- #sr ⇒ String?
-
#title ⇒ String?
The title of the current page.
-
#ttclid ⇒ String?
The TikTok Click ID.
-
#twclid ⇒ String?
The Twitter Click ID.
-
#uafvl ⇒ String?
User agent as a full list of strings.
-
#user_agent ⇒ String?
The user agent of the browser.
-
#utm_campaign ⇒ String?
The UTM Campaign.
-
#utm_content ⇒ String?
The UTM Content.
-
#utm_medium ⇒ String?
The UTM Medium.
-
#utm_name ⇒ String?
The UTM Name.
-
#utm_source ⇒ String?
The UTM Source.
-
#utm_term ⇒ String?
The UTM Term.
-
#version ⇒ String?
The version of the web SDK.
-
#wbraid ⇒ String?
The WBRAID Identifier.
-
#webview ⇒ Boolean?
Whether the user is in a webview.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OursprivacyIngest::Internal::Type::BaseModel
Instance Attribute Details
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active
513 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 513 optional :active_duration, Float, api_name: :activeDuration, nil?: true |
#ad_id ⇒ String?
The ad id for detected in the session. This is set by the web sdk automatically.
519 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 519 optional :ad_id, String, nil?: true |
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID. Ex: admitad_uid_abc123
525 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 525 optional :admitad_uid, String, nil?: true |
#adset_id ⇒ String?
The adset id for detected in the session. This is set by the web sdk automatically.
532 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 532 optional :adset_id, String, nil?: true |
#alart ⇒ String?
The AppLovin alart query parameter. Ex: alart123
538 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 538 optional :alart, String, nil?: true |
#aleid ⇒ String?
The AppLovin aleid query parameter. Ex: aleid123
544 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 544 optional :aleid, String, nil?: true |
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt). Web-only.
550 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 550 optional :axwrt, String, nil?: true |
#basis_cid ⇒ String?
The Basis DSP Click ID. Ex: basis_cid123
556 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 556 optional :basis_cid, String, nil?: true |
#browser_language ⇒ String?
The language of the browser. Ex: en-US
562 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 562 optional :browser_language, String, nil?: true |
#browser_name ⇒ String?
The name of the browser. Ex: Chrome
568 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 568 optional :browser_name, String, nil?: true |
#browser_version ⇒ String?
The version of the browser. Ex: 114.0
574 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 574 optional :browser_version, String, nil?: true |
#campaign_id ⇒ String?
The campaign id for detected in the session. This is set by the web sdk automatically.
581 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 581 optional :campaign_id, String, nil?: true |
#clickid ⇒ String?
The Click ID. Ex: clickid123
587 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 587 optional :clickid, String, nil?: true |
#clid ⇒ String?
The Generic Click ID. Ex: clid123
593 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 593 optional :clid, String, nil?: true |
#cpu_architecture ⇒ String?
The architecture of the CPU. Ex: x64
599 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 599 optional :cpu_architecture, String, nil?: true |
#current_url ⇒ String?
The full url (including query params) of the current page
605 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 605 optional :current_url, String, nil?: true |
#dclid ⇒ String?
The DoubleClick Click ID. Ex: dclid123
611 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 611 optional :dclid, String, nil?: true |
#device_model ⇒ String?
The model of the device. Ex: iPhone 13
617 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 617 optional :device_model, String, nil?: true |
#device_type ⇒ String?
The type of device the user is using. Ex: mobile
623 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 623 optional :device_type, String, nil?: true |
#device_vendor ⇒ String?
The vendor of the device. Ex: Apple
629 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 629 optional :device_vendor, String, nil?: true |
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded
635 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 635 optional :duration, Float, nil?: true |
#encoding ⇒ String?
The browsers encoding. Ex: UTF-8
641 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 641 optional :encoding, String, nil?: true |
#engine_name ⇒ String?
The name of the browser engine. Ex: Blink
647 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 647 optional :engine_name, String, nil?: true |
#engine_version ⇒ String?
The version of the browser engine. Ex: 114.0
653 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 653 optional :engine_version, String, nil?: true |
#epik ⇒ String?
The Pinterest Click ID. Ex: epik456
659 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 659 optional :epik, String, nil?: true |
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking. Ex: fb.1.1554763741205.AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
666 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 666 optional :fbc, String, nil?: true |
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks. Ex: AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
673 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 673 optional :fbclid, String, nil?: true |
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events. Ex: fb.1.1554763741205.1098115397
680 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 680 optional :fbp, String, nil?: true |
#fv ⇒ Boolean?
Deprecated
686 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 686 optional :fv, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#gad_source ⇒ String?
The Google Ad Source. Ex: google
692 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 692 optional :gad_source, String, nil?: true |
#gbraid ⇒ String?
The Google Braid ID. Ex: gbraid123
698 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 698 optional :gbraid, String, nil?: true |
#gclid ⇒ String?
The Google Click ID. Ex: gclid123
704 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 704 optional :gclid, String, nil?: true |
#host ⇒ String?
The host of the current page. Ex: example.com
710 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 710 optional :host, String, nil?: true |
#iframe ⇒ Boolean?
Whether the user is in an iframe. Ex: true
716 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 716 optional :iframe, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#im_ref ⇒ String?
The Impact Click ID reference. Ex: im_ref123
722 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 722 optional :im_ref, String, nil?: true |
#ip ⇒ String?
The IP address of the user. Ex: 127.0.0.1
728 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 728 optional :ip, String, nil?: true |
#irclickid ⇒ String?
The Impact Click ID. Ex: irclickid123
734 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 734 optional :irclickid, String, nil?: true |
#is_bot ⇒ String?
Whether we have detected that the user is a bot. This is set automatically by the Ours server primarily for events tracked through the web SDK.
741 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 741 optional :is_bot, String, nil?: true |
#li_fat_id ⇒ String?
The LinkedIn Click ID. Ex: li_fat_id123
747 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 747 optional :li_fat_id, String, nil?: true |
#msclkid ⇒ String?
The Microsoft Click ID. Ex: msclkid123
753 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 753 optional :msclkid, String, nil?: true |
#ndclid ⇒ String?
The NextDoor Click ID. Ex: ndclid123
759 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 759 optional :ndclid, String, nil?: true |
#new_s ⇒ Boolean?
Deprecated
765 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 765 optional :new_s, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#os_name ⇒ String?
The name of the operating system. Ex: Windows
771 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 771 optional :os_name, String, nil?: true |
#os_version ⇒ String?
The version of the operating system. Ex: 10.0
777 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 777 optional :os_version, String, nil?: true |
#page_hash ⇒ Float?
A random set of numbers for the page load
783 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 783 optional :page_hash, Float, nil?: true |
#pathname ⇒ String?
The pathname of the current page. Ex: /home
789 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 789 optional :pathname, String, nil?: true |
#qclid ⇒ String?
The Quora Click ID. Ex: qclid123
795 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 795 optional :qclid, String, nil?: true |
#rdt_cid ⇒ String?
The Reddit Click ID. Ex: rdt_cid123
801 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 801 optional :rdt_cid, String, nil?: true |
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format
807 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 807 optional :received_at, String, nil?: true |
#referrer ⇒ String?
The referrer URL of the current page
813 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 813 optional :referrer, String, nil?: true |
#referring_domain ⇒ String?
The referring domain of the current page
819 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 819 optional :referring_domain, String, nil?: true |
#sacid ⇒ String?
The StackAdapt Tracking ID. Ex: sacid123
825 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 825 optional :sacid, String, nil?: true |
#sccid ⇒ String?
The SnapChat Click ID. Ex: sccid123
831 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 831 optional :sccid, String, nil?: true |
#screen_height ⇒ Float?
The height of the screen. Ex: 1080
837 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 837 optional :screen_height, Float, nil?: true |
#screen_width ⇒ Float?
The width of the screen. Ex: 1920
843 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 843 optional :screen_width, Float, nil?: true |
#session_count ⇒ Float?
The number of sessions the user has had. Ex: 3
849 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 849 optional :session_count, Float, api_name: :sessionCount, nil?: true |
#sid ⇒ String?
The session ID as assigned automatically by the web SDK. This is required for session replay
856 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 856 optional :sid, String, nil?: true |
#sr ⇒ String?
861 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 861 optional :sr, String, nil?: true |
#title ⇒ String?
The title of the current page
867 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 867 optional :title, String, nil?: true |
#ttclid ⇒ String?
The TikTok Click ID. Ex: ttclid123
873 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 873 optional :ttclid, String, nil?: true |
#twclid ⇒ String?
The Twitter Click ID. Ex: twclid123
879 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 879 optional :twclid, String, nil?: true |
#uafvl ⇒ String?
User agent as a full list of strings.
885 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 885 optional :uafvl, String, nil?: true |
#user_agent ⇒ String?
The user agent of the browser
891 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 891 optional :user_agent, String, nil?: true |
#utm_campaign ⇒ String?
The UTM Campaign. The web SDK automatically captures this from the query params.
897 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 897 optional :utm_campaign, String, nil?: true |
#utm_content ⇒ String?
The UTM Content. The web SDK automatically captures this from the query params.
903 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 903 optional :utm_content, String, nil?: true |
#utm_medium ⇒ String?
The UTM Medium. The web SDK automatically captures this from the query params.
909 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 909 optional :utm_medium, String, nil?: true |
#utm_name ⇒ String?
The UTM Name. The web SDK automatically captures this from the query params.
915 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 915 optional :utm_name, String, nil?: true |
#utm_source ⇒ String?
The UTM Source. The web SDK automatically captures this from the query params.
921 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 921 optional :utm_source, String, nil?: true |
#utm_term ⇒ String?
The UTM Term. The web SDK automatically captures this from the query params.
927 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 927 optional :utm_term, String, nil?: true |
#version ⇒ String?
The version of the web SDK
933 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 933 optional :version, String, nil?: true |
#wbraid ⇒ String?
The WBRAID Identifier. The web SDK automatically captures this from the query params.
940 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 940 optional :wbraid, String, nil?: true |
#webview ⇒ Boolean?
Whether the user is in a webview. Ex: true
946 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 946 optional :webview, OursprivacyIngest::Internal::Type::Boolean, nil?: true |