Class: OursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OursprivacyIngest::Models::VisitorUpsertParams::DefaultProperties
- Defined in:
- lib/oursprivacy_ingest/models/visitor_upsert_params.rb
Instance Attribute Summary collapse
-
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active.
-
#ad_id ⇒ String?
The ad id for detected in the session.
-
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID.
-
#adset_id ⇒ String?
The adset id for detected in the session.
-
#alart ⇒ String?
The AppLovin alart query parameter.
-
#aleid ⇒ String?
The AppLovin aleid query parameter.
-
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt).
-
#basis_cid ⇒ String?
The Basis DSP Click ID.
-
#browser_language ⇒ String?
The language of the browser.
-
#browser_name ⇒ String?
The name of the browser.
-
#browser_version ⇒ String?
The version of the browser.
-
#campaign_id ⇒ String?
The campaign id for detected in the session.
-
#clickid ⇒ String?
The Click ID.
-
#clid ⇒ String?
The Generic Click ID.
-
#cpu_architecture ⇒ String?
The architecture of the CPU.
-
#current_url ⇒ String?
The full url (including query params) of the current page.
-
#dclid ⇒ String?
The DoubleClick Click ID.
-
#device_model ⇒ String?
The model of the device.
-
#device_type ⇒ String?
The type of device the user is using.
-
#device_vendor ⇒ String?
The vendor of the device.
-
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded.
-
#encoding ⇒ String?
The browsers encoding.
-
#engine_name ⇒ String?
The name of the browser engine.
-
#engine_version ⇒ String?
The version of the browser engine.
-
#epik ⇒ String?
The Pinterest Click ID.
-
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking.
-
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks.
-
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events.
-
#fv ⇒ Boolean?
Deprecated.
-
#gad_source ⇒ String?
The Google Ad Source.
-
#gbraid ⇒ String?
The Google Braid ID.
-
#gclid ⇒ String?
The Google Click ID.
-
#host ⇒ String?
The host of the current page.
-
#iframe ⇒ Boolean?
Whether the user is in an iframe.
-
#im_ref ⇒ String?
The Impact Click ID reference.
-
#ip ⇒ String?
The IP address of the user.
-
#irclickid ⇒ String?
The Impact Click ID.
-
#is_bot ⇒ String?
Whether we have detected that the user is a bot.
-
#li_fat_id ⇒ String?
The LinkedIn Click ID.
-
#msclkid ⇒ String?
The Microsoft Click ID.
-
#ndclid ⇒ String?
The NextDoor Click ID.
-
#new_s ⇒ Boolean?
Deprecated.
-
#os_name ⇒ String?
The name of the operating system.
-
#os_version ⇒ String?
The version of the operating system.
-
#page_hash ⇒ Float?
A random set of numbers for the page load.
-
#pathname ⇒ String?
The pathname of the current page.
-
#qclid ⇒ String?
The Quora Click ID.
-
#rdt_cid ⇒ String?
The Reddit Click ID.
-
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format.
-
#referrer ⇒ String?
The referrer URL of the current page.
-
#referring_domain ⇒ String?
The referring domain of the current page.
-
#sacid ⇒ String?
The StackAdapt Tracking ID.
-
#sccid ⇒ String?
The SnapChat Click ID.
-
#screen_height ⇒ Float?
The height of the screen.
-
#screen_width ⇒ Float?
The width of the screen.
-
#session_count ⇒ Float?
The number of sessions the user has had.
-
#sid ⇒ String?
The session ID as assigned automatically by the web SDK.
- #sr ⇒ String?
-
#title ⇒ String?
The title of the current page.
-
#ttclid ⇒ String?
The TikTok Click ID.
-
#twclid ⇒ String?
The Twitter Click ID.
-
#uafvl ⇒ String?
User agent as a full list of strings.
-
#user_agent ⇒ String?
The user agent of the browser.
-
#utm_campaign ⇒ String?
The UTM Campaign.
-
#utm_content ⇒ String?
The UTM Content.
-
#utm_medium ⇒ String?
The UTM Medium.
-
#utm_name ⇒ String?
The UTM Name.
-
#utm_source ⇒ String?
The UTM Source.
-
#utm_term ⇒ String?
The UTM Term.
-
#version ⇒ String?
The version of the web SDK.
-
#wbraid ⇒ String?
The WBRAID Identifier.
-
#webview ⇒ Boolean?
Whether the user is in a webview.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OursprivacyIngest::Internal::Type::BaseModel
Instance Attribute Details
#active_duration ⇒ Float?
The active time in milliseconds that the user had this tab active
510 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 510 optional :active_duration, Float, api_name: :activeDuration, nil?: true |
#ad_id ⇒ String?
The ad id for detected in the session. This is set by the web sdk automatically.
516 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 516 optional :ad_id, String, nil?: true |
#admitad_uid ⇒ String?
The Admitad (Mitgo) affiliate Click ID. Ex: admitad_uid_abc123
522 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 522 optional :admitad_uid, String, nil?: true |
#adset_id ⇒ String?
The adset id for detected in the session. This is set by the web sdk automatically.
529 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 529 optional :adset_id, String, nil?: true |
#alart ⇒ String?
The AppLovin alart query parameter. Ex: alart123
535 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 535 optional :alart, String, nil?: true |
#aleid ⇒ String?
The AppLovin aleid query parameter. Ex: aleid123
541 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 541 optional :aleid, String, nil?: true |
#axwrt ⇒ String?
The AppLovin Axon pixel cookie value (_axwrt). Web-only.
547 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 547 optional :axwrt, String, nil?: true |
#basis_cid ⇒ String?
The Basis DSP Click ID. Ex: basis_cid123
553 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 553 optional :basis_cid, String, nil?: true |
#browser_language ⇒ String?
The language of the browser. Ex: en-US
559 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 559 optional :browser_language, String, nil?: true |
#browser_name ⇒ String?
The name of the browser. Ex: Chrome
565 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 565 optional :browser_name, String, nil?: true |
#browser_version ⇒ String?
The version of the browser. Ex: 114.0
571 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 571 optional :browser_version, String, nil?: true |
#campaign_id ⇒ String?
The campaign id for detected in the session. This is set by the web sdk automatically.
578 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 578 optional :campaign_id, String, nil?: true |
#clickid ⇒ String?
The Click ID. Ex: clickid123
584 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 584 optional :clickid, String, nil?: true |
#clid ⇒ String?
The Generic Click ID. Ex: clid123
590 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 590 optional :clid, String, nil?: true |
#cpu_architecture ⇒ String?
The architecture of the CPU. Ex: x64
596 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 596 optional :cpu_architecture, String, nil?: true |
#current_url ⇒ String?
The full url (including query params) of the current page
602 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 602 optional :current_url, String, nil?: true |
#dclid ⇒ String?
The DoubleClick Click ID. Ex: dclid123
608 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 608 optional :dclid, String, nil?: true |
#device_model ⇒ String?
The model of the device. Ex: iPhone 13
614 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 614 optional :device_model, String, nil?: true |
#device_type ⇒ String?
The type of device the user is using. Ex: mobile
620 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 620 optional :device_type, String, nil?: true |
#device_vendor ⇒ String?
The vendor of the device. Ex: Apple
626 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 626 optional :device_vendor, String, nil?: true |
#duration ⇒ Float?
The time in milliseconds since the page was loaded // script was loaded
632 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 632 optional :duration, Float, nil?: true |
#encoding ⇒ String?
The browsers encoding. Ex: UTF-8
638 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 638 optional :encoding, String, nil?: true |
#engine_name ⇒ String?
The name of the browser engine. Ex: Blink
644 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 644 optional :engine_name, String, nil?: true |
#engine_version ⇒ String?
The version of the browser engine. Ex: 114.0
650 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 650 optional :engine_version, String, nil?: true |
#epik ⇒ String?
The Pinterest Click ID. Ex: epik456
656 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 656 optional :epik, String, nil?: true |
#fbc ⇒ String?
Facebook Click ID with prefix format for Conversions API tracking. Ex: fb.1.1554763741205.AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
663 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 663 optional :fbc, String, nil?: true |
#fbclid ⇒ String?
Raw Facebook Click ID query parameter without prefix from ad clicks. Ex: AbCdEfGhIjKlMnOpQrStUvWxYz1234567890
670 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 670 optional :fbclid, String, nil?: true |
#fbp ⇒ String?
Facebook Browser ID parameter for identifying browsers and attributing events. Ex: fb.1.1554763741205.1098115397
677 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 677 optional :fbp, String, nil?: true |
#fv ⇒ Boolean?
Deprecated
683 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 683 optional :fv, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#gad_source ⇒ String?
The Google Ad Source. Ex: google
689 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 689 optional :gad_source, String, nil?: true |
#gbraid ⇒ String?
The Google Braid ID. Ex: gbraid123
695 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 695 optional :gbraid, String, nil?: true |
#gclid ⇒ String?
The Google Click ID. Ex: gclid123
701 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 701 optional :gclid, String, nil?: true |
#host ⇒ String?
The host of the current page. Ex: example.com
707 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 707 optional :host, String, nil?: true |
#iframe ⇒ Boolean?
Whether the user is in an iframe. Ex: true
713 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 713 optional :iframe, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#im_ref ⇒ String?
The Impact Click ID reference. Ex: im_ref123
719 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 719 optional :im_ref, String, nil?: true |
#ip ⇒ String?
The IP address of the user. Ex: 127.0.0.1
725 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 725 optional :ip, String, nil?: true |
#irclickid ⇒ String?
The Impact Click ID. Ex: irclickid123
731 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 731 optional :irclickid, String, nil?: true |
#is_bot ⇒ String?
Whether we have detected that the user is a bot. This is set automatically by the Ours server primarily for events tracked through the web SDK.
738 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 738 optional :is_bot, String, nil?: true |
#li_fat_id ⇒ String?
The LinkedIn Click ID. Ex: li_fat_id123
744 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 744 optional :li_fat_id, String, nil?: true |
#msclkid ⇒ String?
The Microsoft Click ID. Ex: msclkid123
750 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 750 optional :msclkid, String, nil?: true |
#ndclid ⇒ String?
The NextDoor Click ID. Ex: ndclid123
756 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 756 optional :ndclid, String, nil?: true |
#new_s ⇒ Boolean?
Deprecated
762 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 762 optional :new_s, OursprivacyIngest::Internal::Type::Boolean, nil?: true |
#os_name ⇒ String?
The name of the operating system. Ex: Windows
768 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 768 optional :os_name, String, nil?: true |
#os_version ⇒ String?
The version of the operating system. Ex: 10.0
774 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 774 optional :os_version, String, nil?: true |
#page_hash ⇒ Float?
A random set of numbers for the page load
780 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 780 optional :page_hash, Float, nil?: true |
#pathname ⇒ String?
The pathname of the current page. Ex: /home
786 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 786 optional :pathname, String, nil?: true |
#qclid ⇒ String?
The Quora Click ID. Ex: qclid123
792 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 792 optional :qclid, String, nil?: true |
#rdt_cid ⇒ String?
The Reddit Click ID. Ex: rdt_cid123
798 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 798 optional :rdt_cid, String, nil?: true |
#received_at ⇒ String?
The time the event was received by an Ours server in ISO format
804 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 804 optional :received_at, String, nil?: true |
#referrer ⇒ String?
The referrer URL of the current page
810 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 810 optional :referrer, String, nil?: true |
#referring_domain ⇒ String?
The referring domain of the current page
816 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 816 optional :referring_domain, String, nil?: true |
#sacid ⇒ String?
The StackAdapt Tracking ID. Ex: sacid123
822 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 822 optional :sacid, String, nil?: true |
#sccid ⇒ String?
The SnapChat Click ID. Ex: sccid123
828 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 828 optional :sccid, String, nil?: true |
#screen_height ⇒ Float?
The height of the screen. Ex: 1080
834 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 834 optional :screen_height, Float, nil?: true |
#screen_width ⇒ Float?
The width of the screen. Ex: 1920
840 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 840 optional :screen_width, Float, nil?: true |
#session_count ⇒ Float?
The number of sessions the user has had. Ex: 3
846 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 846 optional :session_count, Float, api_name: :sessionCount, nil?: true |
#sid ⇒ String?
The session ID as assigned automatically by the web SDK. This is required for session replay
853 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 853 optional :sid, String, nil?: true |
#sr ⇒ String?
858 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 858 optional :sr, String, nil?: true |
#title ⇒ String?
The title of the current page
864 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 864 optional :title, String, nil?: true |
#ttclid ⇒ String?
The TikTok Click ID. Ex: ttclid123
870 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 870 optional :ttclid, String, nil?: true |
#twclid ⇒ String?
The Twitter Click ID. Ex: twclid123
876 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 876 optional :twclid, String, nil?: true |
#uafvl ⇒ String?
User agent as a full list of strings.
882 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 882 optional :uafvl, String, nil?: true |
#user_agent ⇒ String?
The user agent of the browser
888 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 888 optional :user_agent, String, nil?: true |
#utm_campaign ⇒ String?
The UTM Campaign. The web SDK automatically captures this from the query params.
894 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 894 optional :utm_campaign, String, nil?: true |
#utm_content ⇒ String?
The UTM Content. The web SDK automatically captures this from the query params.
900 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 900 optional :utm_content, String, nil?: true |
#utm_medium ⇒ String?
The UTM Medium. The web SDK automatically captures this from the query params.
906 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 906 optional :utm_medium, String, nil?: true |
#utm_name ⇒ String?
The UTM Name. The web SDK automatically captures this from the query params.
912 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 912 optional :utm_name, String, nil?: true |
#utm_source ⇒ String?
The UTM Source. The web SDK automatically captures this from the query params.
918 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 918 optional :utm_source, String, nil?: true |
#utm_term ⇒ String?
The UTM Term. The web SDK automatically captures this from the query params.
924 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 924 optional :utm_term, String, nil?: true |
#version ⇒ String?
The version of the web SDK
930 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 930 optional :version, String, nil?: true |
#wbraid ⇒ String?
The WBRAID Identifier. The web SDK automatically captures this from the query params.
937 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 937 optional :wbraid, String, nil?: true |
#webview ⇒ Boolean?
Whether the user is in a webview. Ex: true
943 |
# File 'lib/oursprivacy_ingest/models/visitor_upsert_params.rb', line 943 optional :webview, OursprivacyIngest::Internal::Type::Boolean, nil?: true |